@@ -165,9 +165,9 @@ public:
                       << "SVG" << "ICNS" << "GIF" << "MNG" << "TIF"
                       << "TIFF" << "BMP" << "XPM" << "MRW" << "DNG"
                       << "RAF"  << "CR2" << "MEF" << "RAW" << "ORF"
-                      << "NEF" ;
+                      << "NEF" << "PEF" << "PXM" ;
 
-        m_canSave << "BMP" << "JPG" << "JPEG" << "PNG" << "PBM"
+        m_canSave << "BMP" << "JPG" << "JPEG" << "PNG"
                   << "PGM" << "PPM" << "PNM" << "WBMP" << "WEBP"
                   << "SVG" << "TGA" << "XPM" << "ICO" << "J2C"
                   << "J2K" << "JNG" << "JP2" ;
@@ -312,6 +312,12 @@ UNIONIMAGESHARED_EXPORT QDateTime string2DateTime(const QString &time)
 UNIONIMAGESHARED_EXPORT QMap<QString, QString> getMetaData(FREE_IMAGE_MDMODEL model, FIBITMAP *dib)
 {
     QMap<QString, QString> mdMap;  // key-data
+
+    //有时候会存在tag为野指针的情况，根据FreeImage的demo，需要加这个进行预判断
+    if (FreeImage_GetMetadataCount(model, dib) == 0) {
+        return mdMap;
+    }
+
     FITAG *tag = nullptr;
     FIMETADATA *mdhandle = nullptr;
     mdhandle = FreeImage_FindFirstMetadata(model, dib, &tag);
@@ -533,7 +539,7 @@ UNIONIMAGESHARED_EXPORT FIBITMAP *readFile2FIBITMAP(const QString &path, int fla
 UNIONIMAGESHARED_EXPORT bool canSave(const QString &path)
 {
     QFileInfo info(path);
-    if (!info.exists() || !QFile::permissions(path).testFlag(QFile::WriteUser)) {
+    if (!info.exists() || !QFile::permissions(path).testFlag(QFile::WriteOwner) || !QFile::permissions(path).testFlag(QFile::ReadOwner)) {
         return false;
     }
     QImageReader r(path);
@@ -543,7 +549,7 @@ UNIONIMAGESHARED_EXPORT bool canSave(const QString &path)
     FREE_IMAGE_FORMAT fif = FIF_UNKNOWN;
     // Try to guess the file format from the file extension
     fif = FreeImage_GetFIFFromFilename(path.toUtf8().data());
-    if (fif != FIF_UNKNOWN) {
+    if (fif != FIF_UNKNOWN && info.suffix().toUpper() != "PBM") {
         // Check that the dib can be saved in this format
         if (union_image_private.m_canSave.contains(union_image_private.m_freeiamge_formats.key(fif))) {
             return true;
@@ -614,8 +620,13 @@ UNIONIMAGESHARED_EXPORT bool loadStaticImageFromFile(const QString &path, QImage
     if (f == FIF_TIFF) {
         file_suffix_upper = "TIFF";
     }
+    bool usingQimage = false;
+    if (f == FIF_RAW && path.endsWith(".PEF")) {
+        usingQimage = true;
+        file_suffix_upper = "";
+    }
     QString file_suffix_lower = file_suffix_upper.toLower();
-    if (union_image_private.m_qtSupported.contains(file_suffix_upper)) {
+    if (usingQimage || union_image_private.m_qtSupported.contains(file_suffix_upper)) {
         QImageReader reader;
         QImage res_qt;
         reader.setFileName(path);
@@ -1248,7 +1259,7 @@ private:
     FREE_IMAGE_FORMAT currentFormat = FIF_UNKNOWN;
     int currentIndex = 0;
     int frames = 0;
-    char padding[4];
+    char padding[4] = { 0 };
 };
 
 UnionMovieImage::UnionMovieImage(): d_ptr(new UnionMovieImagePrivate(this))
