@@ -53,6 +53,7 @@
 #include "leftlistwidget.h"
 #include <QRunnable>
 #include <QThreadPool>
+#include <DComboBox>
 
 //#define GIO_COMPILATION
 #undef signals
@@ -91,7 +92,6 @@ public:
     ~AlbumView() override;
 
     bool imageImported(bool success) override;
-    bool imageGeted(QStringList &filelist, QString path) override;
     bool imageMountImported(QStringList &filelist) override;
 
     void iniWaitDiolag();
@@ -99,10 +99,12 @@ public:
     void restorePicNum();
     void updatePicNum();
     void updateRightView();
-    void updateAlbumView(const QString &album);
+    void updateAlbumView(int UID);
     void updateDeviceLeftList();
     void setCurrentItemType(int type);
     void leftTabClicked();
+    void onAddNewNotifyDir(const QString &dirPath);
+    bool checkIfNotified(const QString &dirPath);
 private:
     void initConnections();
     void initLeftView();
@@ -131,6 +133,8 @@ private:
     void onSlideShowFav(const QString &path);
     //幻灯片播放
     void onSlideShowCustom(const QString &path);
+    //幻灯片播放，真实实现
+    void runSlideShow(const QString &path, ThumbnailListView *listView);
 
     void dragEnterEvent(QDragEnterEvent *e) override;
     void dropEvent(QDropEvent *event) override;
@@ -145,11 +149,13 @@ private:
     const QList<QExplicitlySharedDataPointer<DGioMount> > getVfsMountList();
 
     void initExternalDevice();
+    //更新外部设备的显示
     void updateExternalDevice(QExplicitlySharedDataPointer<DGioMount> mount, QString strPath = QString());
     bool findPicturePathByPhone(QString &path);
     void updateImportComboBox();
     void importAllBtnClicked();
     void importSelectBtnClicked();
+    void importFromMountDevice(const QStringList &paths);
 
     void initLeftMenu();
     void importComboBoxChange(QString strText);
@@ -163,8 +169,8 @@ private slots:
     void onTrashRecoveryBtnClicked();
     void onUpdataAlbumRightTitle(const QString &titlename);
     void onUnMountSignal(const QString &unMountPath);          //手动卸载设备
-    void onCreateNewAlbumFromDialog(const QString &newalbumname);
-    void onCreateNewAlbumFrom(const QString &albumname);
+    void onCreateNewAlbumFromDialog(const QString &newalbumname, int UID);
+    void onCreateNewAlbumFrom(const QString &albumname, int UID);
     void onLeftListDropEvent(QModelIndex dropIndex);
     void onKeyDelete();
     void onKeyF2();
@@ -173,10 +179,10 @@ private slots:
     void onWaitDialogClose();
     void onWaitDialogIgnore();
     // change lambda to normal slt
-    void onRepeatImportingTheSamePhotos(QStringList importPaths, QStringList duplicatePaths, const QString &albumName);
+    void onRepeatImportingTheSamePhotos(QStringList importPaths, QStringList duplicatePaths, int UID);
     void ongMouseMove();
     void onSelectAll();
-    void onInsertedIntoAlbum(const QString &albumname, QStringList pathlist);
+    void onInsertedIntoAlbum(int UID, QStringList pathlist);
     void onFileSystemAdded(const QString &dbusPath);
     void onBlockDeviceAdded(const QString &blks);
     void onThemeTypeChanged(DGuiApplicationHelper::ColorType themeType);
@@ -195,9 +201,14 @@ private slots:
     void sltSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
     //最近删除中有变化
     void onTrashInfosChanged();
+    //删除描述语自适应变化
+    void adaptiveTrashDescritionLabel();
+    //默认导入路径已被销毁
+    void onMonitorDestroyed(int UID);
 public:
     int m_iAlubmPicsNum;
     QString m_currentAlbum;
+    int m_currentUID;
     QString m_currentType;
     AblumType m_currentItemType = photosType;
     int m_selPicNum;
@@ -209,14 +220,10 @@ public:
     DWidget *m_pRightWidget;
 
     ThumbnailListView *m_pRightPhoneThumbnailList;       //设备相关列表
-    QMap<QString, QStringList> m_phoneNameAndPathlist;
-    //LMH0424
-    QStringList m_pictrueallPathlist;
 
     DWidget *m_pwidget;
 
     ThumbnailListView *m_customThumbnailList = nullptr;               //自定义
-    DBImgInfoList m_allTrashInfos;                                    //最近删除中的数据
     ThumbnailListView *m_pRightTrashThumbnailList = nullptr;          //最近删除
     ThumbnailListView *m_favoriteThumbnailList = nullptr;             //我的收藏
 
@@ -258,6 +265,7 @@ private:
     BatchOperateWidget *m_trashBatchOperateWidget = nullptr;
     DWidget *m_pTrashWidget = nullptr;                                //最近删除外层界面
     NoResultWidget *m_trashNoResultWidget = nullptr;
+    QString m_trashNoticeFullStr;
     //手机照片导入窗体
     DWidget *m_importByPhoneWidget;
     DComboBox *m_importByPhoneComboBox;
@@ -265,8 +273,6 @@ private:
     DSuggestButton *m_importSelectByPhoneBtn;
     QList<QExplicitlySharedDataPointer<DGioMount>> m_mounts;     //外部设备挂载
 
-    DBImgInfoList m_curThumbnaiItemList_info;
-    QStringList m_curThumbnaiItemList_str;
     int m_mountPicNum;
 
     QMap<QUrl, QString> durlAndNameMap;
