@@ -33,7 +33,8 @@
 #include <QHBoxLayout>
 #include <DFontSizeManager>
 #include <DStyledItemDelegate>
-
+#include <QScroller>
+#include <QScrollBar>
 namespace {
 const int OPE_MODE_ADDNEWALBUM = 0;
 const int OPE_MODE_RENAMEALBUM = 1;
@@ -58,6 +59,11 @@ LeftListView::LeftListView(QWidget *parent)
     , m_ItemCurrentType(COMMON_STR_RECENT_IMPORTED)
     , m_pMenu(nullptr)
 {
+    //右侧菜单栏支持滑动
+//    QScroller::grabGesture(viewport());
+    QScrollBar *m_bar = new QScrollBar();
+//    QScroller::grabGesture(viewport());
+    this->setVerticalScrollBar(m_bar);
     m_ItemCurrentDataType = 0;
     initUI();
     initMenu();
@@ -66,18 +72,29 @@ LeftListView::LeftListView(QWidget *parent)
 
 void LeftListView::initConnections()
 {
-    connect(m_pPhotoLibListView, &DListWidget::pressed, this, &LeftListView::onPhotoLibListViewPressed);
-    connect(m_pCustomizeListView, &DListWidget::pressed, this, &LeftListView::onCustomListViewPressed);
-    connect(m_pMountListWidget, &DListWidget::pressed, this, &LeftListView::onMountListViewPressed);
-    connect(m_pPhotoLibListView, &DListWidget::currentItemChanged, this, &LeftListView::onPhotoLibListViewCurrentItemChanged);
-    connect(m_pCustomizeListView, &DListWidget::currentItemChanged, this, &LeftListView::onCustomizeListViewCurrentItemChanged);
-    connect(m_pMountListWidget, &DListWidget::currentItemChanged, this, &LeftListView::onMountListWidgetCurrentItemChanged);
+    connect(m_pPhotoLibListView, &LeftListWidget::pressed, this, &LeftListView::onPhotoLibListViewPressed);
+    connect(m_pCustomizeListView, &LeftListWidget::pressed, this, &LeftListView::onCustomListViewPressed);
+    connect(m_pMountListWidget, &LeftListWidget::pressed, this, &LeftListView::onMountListViewPressed);
+    connect(m_pPhotoLibListView, &LeftListWidget::sigMouseReleaseEvent, this, &LeftListView::onPhotoLibListViewPressed);
+    connect(m_pCustomizeListView, &LeftListWidget::sigMouseReleaseEvent, this, &LeftListView::onCustomListViewPressed);
+    connect(m_pMountListWidget, &LeftListWidget::sigMouseReleaseEvent, this, &LeftListView::onMountListViewPressed);
+
+
     connect(m_pCustomizeListView, &QListView::customContextMenuRequested, this, &LeftListView::showMenu);
     connect(m_pMenu, &DMenu::triggered, this, &LeftListView::onMenuClicked);
     connect(m_pAddListBtn, &DPushButton::clicked, this, &LeftListView::onAddListBtnClicked);
     connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged, this, &LeftListView::onApplicationHelperThemeTypeChanged);
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &LeftListView::onGuiApplicationHelperThemeTypeChanged);
     connect(m_pMountListWidget, &LeftListWidget::sigMousePressIsNoValid, this, &LeftListView::onMousePressIsNoValid);
+
+    connect(m_pPhotoLibListView, &LeftListWidget::sigMouseMoveEvent, this, &LeftListView::onMouseMove);
+    connect(m_pCustomizeListView, &LeftListWidget::sigMouseMoveEvent, this, &LeftListView::onMouseMove);
+    connect(m_pMountListWidget, &LeftListWidget::sigMouseMoveEvent, this, &LeftListView::onMouseMove);
+
+
+    connect(m_pPhotoLibListView, &DListWidget::currentItemChanged, this, &LeftListView::onPhotoLibListViewCurrentItemChanged);
+    connect(m_pCustomizeListView, &DListWidget::currentItemChanged, this, &LeftListView::onCustomizeListViewCurrentItemChanged);
+    connect(m_pMountListWidget, &DListWidget::currentItemChanged, this, &LeftListView::onMountListWidgetCurrentItemChanged);
 }
 
 void LeftListView::initUI()
@@ -126,7 +143,7 @@ void LeftListView::initUI()
     QListWidgetItem *pListWidgetItem1 = new QListWidgetItem(m_pPhotoLibListView);
     pListWidgetItem1->setSizeHint(QSize(LEFT_VIEW_LISTITEM_WIDTH_160, LEFT_VIEW_LISTITEM_HEIGHT_40));
 
-    AlbumLeftTabItem *pAlbumLeftTabItem1 = new AlbumLeftTabItem(COMMON_STR_RECENT_IMPORTED);
+    AlbumLeftTabItem *pAlbumLeftTabItem1 = new AlbumLeftTabItem(COMMON_STR_RECENT_IMPORTED, -1);
     pAlbumLeftTabItem1->setFixedWidth(LEFT_VIEW_LISTITEM_WIDTH_160);
     pAlbumLeftTabItem1->setFixedHeight(LEFT_VIEW_LISTITEM_HEIGHT_40);
 
@@ -136,7 +153,7 @@ void LeftListView::initUI()
     // 最新删除
     QListWidgetItem *pListWidgetItem2 = new QListWidgetItem(m_pPhotoLibListView);
     pListWidgetItem2->setSizeHint(QSize(LEFT_VIEW_LISTITEM_WIDTH_160, LEFT_VIEW_LISTITEM_HEIGHT_40));
-    AlbumLeftTabItem *pAlbumLeftTabItem2 = new AlbumLeftTabItem(COMMON_STR_TRASH);
+    AlbumLeftTabItem *pAlbumLeftTabItem2 = new AlbumLeftTabItem(COMMON_STR_TRASH, -1);
     pAlbumLeftTabItem2->setFixedWidth(LEFT_VIEW_LISTITEM_WIDTH_160);
     pAlbumLeftTabItem2->setFixedHeight(LEFT_VIEW_LISTITEM_HEIGHT_40);
     m_pPhotoLibListView->setItemWidget(pListWidgetItem2, pAlbumLeftTabItem2);
@@ -144,7 +161,7 @@ void LeftListView::initUI()
     // 我的收藏
     QListWidgetItem *pListWidgetItem3 = new QListWidgetItem(m_pPhotoLibListView);
     pListWidgetItem3->setSizeHint(QSize(LEFT_VIEW_LISTITEM_WIDTH_160, LEFT_VIEW_LISTITEM_HEIGHT_40));
-    AlbumLeftTabItem *pAlbumLeftTabItem3 = new AlbumLeftTabItem(COMMON_STR_FAVORITES);
+    AlbumLeftTabItem *pAlbumLeftTabItem3 = new AlbumLeftTabItem(COMMON_STR_FAVORITES, DBManager::SpUID::u_Favorite);
     pAlbumLeftTabItem3->setFixedWidth(LEFT_VIEW_LISTITEM_WIDTH_160);
     pAlbumLeftTabItem3->setFixedHeight(LEFT_VIEW_LISTITEM_HEIGHT_40);
     m_pPhotoLibListView->setItemWidget(pListWidgetItem3, pAlbumLeftTabItem3);
@@ -190,12 +207,25 @@ void LeftListView::initUI()
     m_pCustomizeListView->setFrameShape(DListWidget::NoFrame);
     m_pCustomizeListView->setContextMenuPolicy(Qt::CustomContextMenu);
 
-    QStringList allAlbumNames = DBManager::instance()->getAllAlbumNames();
-    for (auto albumName : allAlbumNames) {
+    //自动导入路径
+    auto autoImportAlbumNames = DBManager::instance()->getAllAlbumNames(AutoImport);
+    for (auto albumName : autoImportAlbumNames) {
         QListWidgetItem *pListWidgetItem = new QListWidgetItem(m_pCustomizeListView, 1);
         pListWidgetItem->setSizeHint(QSize(LEFT_VIEW_LISTITEM_WIDTH_160 /*+ 8*/, LEFT_VIEW_LISTITEM_HEIGHT_40));
 
-        AlbumLeftTabItem *pAlbumLeftTabItem = new AlbumLeftTabItem(albumName, COMMON_STR_CREATEALBUM);
+        AlbumLeftTabItem *pAlbumLeftTabItem = new AlbumLeftTabItem(albumName.second, albumName.first, "AutoImport");
+        pAlbumLeftTabItem->setFixedWidth(LEFT_VIEW_LISTITEM_WIDTH_160 /*+ 8*/);
+        pAlbumLeftTabItem->setFixedHeight(LEFT_VIEW_LISTITEM_HEIGHT_40);
+        m_pCustomizeListView->setItemWidget(pListWidgetItem, pAlbumLeftTabItem);
+    }
+
+    //自定义相册
+    auto customAlbumNames = DBManager::instance()->getAllAlbumNames(Custom);
+    for (auto albumName : customAlbumNames) {
+        QListWidgetItem *pListWidgetItem = new QListWidgetItem(m_pCustomizeListView, 1);
+        pListWidgetItem->setSizeHint(QSize(LEFT_VIEW_LISTITEM_WIDTH_160 /*+ 8*/, LEFT_VIEW_LISTITEM_HEIGHT_40));
+
+        AlbumLeftTabItem *pAlbumLeftTabItem = new AlbumLeftTabItem(albumName.second, albumName.first, COMMON_STR_CREATEALBUM);
         pAlbumLeftTabItem->setFixedWidth(LEFT_VIEW_LISTITEM_WIDTH_160 /*+ 8*/);
         pAlbumLeftTabItem->setFixedHeight(LEFT_VIEW_LISTITEM_HEIGHT_40);
         m_pCustomizeListView->setItemWidget(pListWidgetItem, pAlbumLeftTabItem);
@@ -248,7 +278,7 @@ void LeftListView::updatePhotoListView()
     QListWidgetItem *pListWidgetItem1 = new QListWidgetItem(m_pPhotoLibListView);
     pListWidgetItem1->setSizeHint(QSize(LEFT_VIEW_LISTITEM_WIDTH_160, LEFT_VIEW_LISTITEM_HEIGHT_40));
 
-    AlbumLeftTabItem *pAlbumLeftTabItem1 = new AlbumLeftTabItem(COMMON_STR_RECENT_IMPORTED);
+    AlbumLeftTabItem *pAlbumLeftTabItem1 = new AlbumLeftTabItem(COMMON_STR_RECENT_IMPORTED, -1);
     pAlbumLeftTabItem1->setFixedWidth(LEFT_VIEW_LISTITEM_WIDTH_160);
     pAlbumLeftTabItem1->setFixedHeight(LEFT_VIEW_LISTITEM_HEIGHT_40);
     m_pPhotoLibListView->setItemWidget(pListWidgetItem1, pAlbumLeftTabItem1);
@@ -257,7 +287,7 @@ void LeftListView::updatePhotoListView()
     QListWidgetItem *pListWidgetItem2 = new QListWidgetItem(m_pPhotoLibListView);
     pListWidgetItem2->setSizeHint(QSize(LEFT_VIEW_LISTITEM_WIDTH_160, LEFT_VIEW_LISTITEM_HEIGHT_40));
 
-    AlbumLeftTabItem *pAlbumLeftTabItem2 = new AlbumLeftTabItem(COMMON_STR_TRASH);
+    AlbumLeftTabItem *pAlbumLeftTabItem2 = new AlbumLeftTabItem(COMMON_STR_TRASH, -1);
     pAlbumLeftTabItem2->setFixedWidth(LEFT_VIEW_LISTITEM_WIDTH_160);
     pAlbumLeftTabItem2->setFixedHeight(LEFT_VIEW_LISTITEM_HEIGHT_40);
     m_pPhotoLibListView->setItemWidget(pListWidgetItem2, pAlbumLeftTabItem2);
@@ -266,7 +296,7 @@ void LeftListView::updatePhotoListView()
     QListWidgetItem *pListWidgetItem3 = new QListWidgetItem(m_pPhotoLibListView);
     pListWidgetItem3->setSizeHint(QSize(LEFT_VIEW_LISTITEM_WIDTH_160, LEFT_VIEW_LISTITEM_HEIGHT_40));
 
-    AlbumLeftTabItem *pAlbumLeftTabItem3 = new AlbumLeftTabItem(COMMON_STR_FAVORITES);
+    AlbumLeftTabItem *pAlbumLeftTabItem3 = new AlbumLeftTabItem(COMMON_STR_FAVORITES, DBManager::SpUID::u_Favorite);
     pAlbumLeftTabItem3->setFixedWidth(LEFT_VIEW_LISTITEM_WIDTH_160);
     pAlbumLeftTabItem3->setFixedHeight(LEFT_VIEW_LISTITEM_HEIGHT_40);
     m_pPhotoLibListView->setItemWidget(pListWidgetItem3, pAlbumLeftTabItem3);
@@ -279,12 +309,12 @@ void LeftListView::updatePhotoListView()
 void LeftListView::updateCustomizeListView()
 {
     m_pCustomizeListView->clear();
-    QStringList allAlbumNames = DBManager::instance()->getAllAlbumNames();
+    auto allAlbumNames = DBManager::instance()->getAllAlbumNames();
     for (auto albumName : allAlbumNames) {
         QListWidgetItem *pListWidgetItem = new QListWidgetItem(m_pCustomizeListView);
         pListWidgetItem->setSizeHint(QSize(LEFT_VIEW_LISTITEM_WIDTH_160, LEFT_VIEW_LISTITEM_HEIGHT_40));
 
-        AlbumLeftTabItem *pAlbumLeftTabItem = new AlbumLeftTabItem(albumName);
+        AlbumLeftTabItem *pAlbumLeftTabItem = new AlbumLeftTabItem(albumName.second, albumName.first, "");
         pAlbumLeftTabItem->setFixedWidth(LEFT_VIEW_LISTITEM_WIDTH_160);
         pAlbumLeftTabItem->setFixedHeight(LEFT_VIEW_LISTITEM_HEIGHT_40);
         m_pCustomizeListView->setItemWidget(pListWidgetItem, pAlbumLeftTabItem);
@@ -318,6 +348,10 @@ void LeftListView::showMenu(const QPoint &pos)
 {
     if (!m_pCustomizeListView->indexAt(pos).isValid()) {
         return;
+    } else {
+        //直接右键点击index时，概率无法收到鼠标press事件，怀疑Qt BUG，这里通过pos判断index有效后手动切换过去
+        m_pCustomizeListView->setCurrentIndex(m_pCustomizeListView->indexAt(pos));
+        emit m_pCustomizeListView->pressed(m_pCustomizeListView->indexAt(pos));
     }
     m_pMenu->setVisible(true);
     foreach (QAction *action, m_MenuActionMap.values()) {
@@ -325,14 +359,27 @@ void LeftListView::showMenu(const QPoint &pos)
         action->setEnabled(true);
     }
 
-    if (0 < DBManager::instance()->getItemsCountByAlbum(m_ItemCurrentName, ItemTypeVideo)) {
+    auto dbType = DBManager::instance()->getAlbumDBTypeFromUID(m_currentUID);
+
+    if (dbType == AutoImport) { //自动导入路径不可重命名和新建相册
+        m_MenuActionMap.value(tr("Rename"))->setVisible(false);
+        m_MenuActionMap.value(tr("New album"))->setVisible(false);
+
+        //默认自动导入路径删除
+        if (DBManager::isDefaultAutoImportDB(m_currentUID)) {
+            m_MenuActionMap.value(tr("Delete"))->setVisible(false);
+        }
+    }
+
+    if (0 < DBManager::instance()->getItemsCountByAlbum(m_currentUID, ItemTypeVideo)) {//隐藏导出
         m_MenuActionMap.value(tr("Export"))->setVisible(false);
     }
 
-    if (0 == DBManager::instance()->getItemsCountByAlbum(m_ItemCurrentName, ItemTypePic)) {
+    if (0 == DBManager::instance()->getItemsCountByAlbum(m_currentUID, ItemTypePic)) {//隐藏幻灯片和导出
         m_MenuActionMap.value(tr("Slide show"))->setVisible(false);
         m_MenuActionMap.value(tr("Export"))->setVisible(false);
     }
+
     m_pMenu->popup(QCursor::pos());
 }
 
@@ -341,7 +388,7 @@ void LeftListView::onMenuClicked(QAction *action)
     const int id = action->property("MenuID").toInt();
     switch (MenuItemId(id)) {
     case IdStartSlideShow: {
-        auto imagelist = DBManager::instance()->getInfosByAlbum(m_ItemCurrentName);
+        auto imagelist = DBManager::instance()->getInfosByAlbum(m_currentUID);
         QStringList paths;
         for (auto image : imagelist) {
             paths << image.filePath;
@@ -355,10 +402,15 @@ void LeftListView::onMenuClicked(QAction *action)
     case IdCreateAlbum: {
         QListWidgetItem *pListWidgetItem = new QListWidgetItem();
         pListWidgetItem->setSizeHint(QSize(LEFT_VIEW_LISTITEM_WIDTH_160, LEFT_VIEW_LISTITEM_HEIGHT_40));
-        m_pCustomizeListView->insertItem(m_pCustomizeListView->currentRow() + 1, pListWidgetItem);
-        AlbumLeftTabItem *pAlbumLeftTabItem = new AlbumLeftTabItem(getNewAlbumName());
+        m_pCustomizeListView->insertItem(m_pCustomizeListView->count(), pListWidgetItem);
+
+        //手动创建相册获取UID，使用UID初始化AlbumLeftTabItem，后面相册名字随便改，但UID不会变
+        auto albumDefaultName = getNewAlbumName();
+        int UID = DBManager::instance()->createAlbum(albumDefaultName, {});
+        AlbumLeftTabItem *pAlbumLeftTabItem = new AlbumLeftTabItem(albumDefaultName, UID);
+
         m_pCustomizeListView->setItemWidget(pListWidgetItem, pAlbumLeftTabItem);
-        m_pCustomizeListView->setCurrentRow(m_pCustomizeListView->currentRow() + 1);
+        m_pCustomizeListView->setCurrentRow(m_pCustomizeListView->count() - 1);
         AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pCustomizeListView->itemWidget(m_pCustomizeListView->currentItem()));
         item->m_opeMode = OPE_MODE_ADDNEWALBUM;
         item->editAlbumEdit();
@@ -372,7 +424,7 @@ void LeftListView::onMenuClicked(QAction *action)
         break;
     }
     case IdExport: {
-        Exporter::instance()->exportAlbum(DBManager::instance()->getPathsByAlbum(m_ItemCurrentName), m_ItemCurrentName);
+        Exporter::instance()->exportAlbum(DBManager::instance()->getPathsByAlbum(m_currentUID), m_ItemCurrentName);
         break;
     }
     case IdDeleteAlbum: {
@@ -381,9 +433,15 @@ void LeftListView::onMenuClicked(QAction *action)
         deletDialg = new AlbumDeleteDialog;
         connect(deletDialg, &AlbumDeleteDialog::deleteAlbum, this, [ = ]() {
             QString str = pTabItem->m_albumNameStr;
-            QStringList paths = DBManager::instance()->getPathsByAlbum(pTabItem->m_albumNameStr);
-            ImageEngineApi::instance()->moveImagesToTrash(paths);
-            DBManager::instance()->removeAlbum(pTabItem->m_albumNameStr);
+            auto dbType = DBManager::instance()->getAlbumDBTypeFromUID(pTabItem->m_UID);
+
+            if (dbType == AutoImport) { //自动导入删除步骤
+                DBManager::instance()->removeCustomAutoImportPath(pTabItem->m_UID);
+            } else { //常规相册删除步骤
+                QStringList paths = DBManager::instance()->getPathsByAlbum(pTabItem->m_UID);
+                ImageEngineApi::instance()->moveImagesToTrash(paths);
+                DBManager::instance()->removeAlbum(pTabItem->m_UID);
+            }
 
             if (1 < m_pCustomizeListView->count()) {
                 delete item;
@@ -416,6 +474,8 @@ void LeftListView::onUpdateLeftListview()
 
 void LeftListView::onPhotoLibListViewPressed(const QModelIndex &index)
 {
+    //release重新初始化m_posY值
+    m_posY = 0;
     Q_UNUSED(index);
     qDebug() << "m_pPhotoLibListView, &DListWidget::pressed";
     m_pCustomizeListView->clearSelection();
@@ -425,7 +485,7 @@ void LeftListView::onPhotoLibListViewPressed(const QModelIndex &index)
     if (pitem) {
         AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pPhotoLibListView->itemWidget(m_pPhotoLibListView->currentItem()));
         auto list = m_pPhotoLibListView->selectedItems();  //当前选中项
-        if (QGuiApplication::queryKeyboardModifiers() & Qt::ControlModifier && list.isEmpty()) { //ctrl取消选中
+        if (list.isEmpty()) { //ctrl取消选中
             item->oriAlbumStatus();
         } else {
             item->newAlbumStatus(); //选中状态
@@ -439,6 +499,7 @@ void LeftListView::onPhotoLibListViewPressed(const QModelIndex &index)
         } else {
             m_ItemCurrentName = COMMON_STR_FAVORITES;
             m_ItemCurrentType = COMMON_STR_FAVORITES;
+            m_currentUID = DBManager::u_Favorite;
         }
         m_ItemCurrentDataType = pitem->type(); //default 0
     }
@@ -450,8 +511,11 @@ void LeftListView::onPhotoLibListViewPressed(const QModelIndex &index)
 
 void LeftListView::onCustomListViewPressed(const QModelIndex &index)
 {
+    //release重新初始化m_posY值
+    m_posY = 0;
     Q_UNUSED(index);
     qDebug() << "m_pCustomizeListView, &DListWidget::pressed";
+
     m_pPhotoLibListView->clearSelection();
     m_pMountListWidget->clearSelection();
     updateAlbumItemsColor();
@@ -459,13 +523,14 @@ void LeftListView::onCustomListViewPressed(const QModelIndex &index)
     if (plitem) {
         AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pCustomizeListView->itemWidget(m_pCustomizeListView->currentItem()));
         auto list = m_pCustomizeListView->selectedItems(); //当前选中项
-        if (QGuiApplication::queryKeyboardModifiers() & Qt::ControlModifier && list.isEmpty()) { //ctrl取消选中
+        if (list.isEmpty()) { //ctrl取消选中
             item->oriAlbumStatus();
         } else {
             item->newAlbumStatus();
         }
         m_ItemCurrentName = item->m_albumNameStr;
         m_ItemCurrentDataType = plitem->type(); //default 0
+        m_currentUID = item->m_UID;
     }
     m_ItemCurrentType = COMMON_STR_CUSTOM;
     m_pPhotoLibListView->setFocusPolicy(Qt::NoFocus);
@@ -476,6 +541,8 @@ void LeftListView::onCustomListViewPressed(const QModelIndex &index)
 
 void LeftListView::onMountListViewPressed(const QModelIndex &index)
 {
+    //release重新初始化m_posY值
+    m_posY = 0;
     Q_UNUSED(index);
     qDebug() << "------" << __FUNCTION__ << "---size = " << m_pMountListWidget->count();
     m_pPhotoLibListView->clearSelection();
@@ -486,13 +553,14 @@ void LeftListView::onMountListViewPressed(const QModelIndex &index)
         AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pMountListWidget->itemWidget(m_pMountListWidget->currentItem()));
         if (item) {
             auto list = m_pMountListWidget->selectedItems(); //当前选中项
-            if (QGuiApplication::queryKeyboardModifiers() & Qt::ControlModifier) { //ctrl取消选中
+            if (list.isEmpty()) { //ctrl取消选中
                 item->oriAlbumStatus();
             } else {
                 item->newAlbumStatus();
             }
             m_ItemCurrentName = item->m_albumNameStr;
             m_ItemCurrentDataType = plitem->type(); //default 0
+            m_currentUID = item->m_UID;
         }
     }
     m_ItemCurrentType = ALBUM_PATHTYPE_BY_PHONE;
@@ -509,7 +577,11 @@ void LeftListView::onPhotoLibListViewCurrentItemChanged()
     updateAlbumItemsColor();
     if (m_pPhotoLibListView->currentItem()) {
         AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pPhotoLibListView->itemWidget(m_pPhotoLibListView->currentItem()));
-        item->newAlbumStatus();
+        if (!m_pPhotoLibListView->selectedItems().isEmpty()) {
+            item->newAlbumStatus();
+        } else {
+            item->oriAlbumStatus();
+        }
         if (COMMON_STR_RECENT_IMPORTED == item->m_albumNameStr) {
             m_ItemCurrentName = COMMON_STR_RECENT_IMPORTED;
             m_ItemCurrentType = COMMON_STR_RECENT_IMPORTED;
@@ -519,6 +591,7 @@ void LeftListView::onPhotoLibListViewCurrentItemChanged()
         } else {
             m_ItemCurrentName = COMMON_STR_FAVORITES;
             m_ItemCurrentType = COMMON_STR_FAVORITES;
+            m_currentUID = DBManager::u_Favorite;
         }
     }
 }
@@ -531,8 +604,13 @@ void LeftListView::onCustomizeListViewCurrentItemChanged()
         updateAlbumItemsColor();
         if (m_pCustomizeListView->currentItem()) {
             AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pCustomizeListView->itemWidget(m_pCustomizeListView->currentItem()));
-            item->newAlbumStatus();
+            if (!m_pCustomizeListView->selectedItems().isEmpty()) {
+                item->newAlbumStatus();
+            } else {
+                item->oriAlbumStatus();
+            }
             m_ItemCurrentName = item->m_albumNameStr;
+            m_currentUID = item->m_UID;
         }
         m_ItemCurrentType = COMMON_STR_CUSTOM;
     }
@@ -546,10 +624,13 @@ void LeftListView::onMountListWidgetCurrentItemChanged()
         updateAlbumItemsColor();
         if (m_pMountListWidget->currentItem()) {
             AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pMountListWidget->itemWidget(m_pMountListWidget->currentItem()));
-            if (nullptr != item) {
+            if (!m_pMountListWidget->selectedItems().isEmpty()) {
                 item->newAlbumStatus();
-                m_ItemCurrentName = item->m_albumNameStr;
+            } else {
+                item->oriAlbumStatus();
             }
+            m_ItemCurrentName = item->m_albumNameStr;
+            m_currentUID = item->m_UID;
         }
         m_ItemCurrentType = ALBUM_PATHTYPE_BY_PHONE;
     }
@@ -562,30 +643,29 @@ void LeftListView::onAddListBtnClicked()
 
 void LeftListView::onApplicationHelperThemeTypeChanged()
 {
-    if (COMMON_STR_RECENT_IMPORTED == m_ItemCurrentType) {
+    if (COMMON_STR_RECENT_IMPORTED == m_ItemCurrentType || COMMON_STR_TRASH == m_ItemCurrentType || COMMON_STR_FAVORITES == m_ItemCurrentType) {
         AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pPhotoLibListView->itemWidget(m_pPhotoLibListView->currentItem()));
-        item->newAlbumStatus();
-        item->oriAlbumStatus();
-    }
-    if (COMMON_STR_TRASH == m_ItemCurrentType) {
-        AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pPhotoLibListView->itemWidget(m_pPhotoLibListView->currentItem()));
-        item->newAlbumStatus();
-        item->oriAlbumStatus();
-    }
-    if (COMMON_STR_FAVORITES == m_ItemCurrentType) {
-        AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pPhotoLibListView->itemWidget(m_pPhotoLibListView->currentItem()));
-        item->newAlbumStatus();
-        item->oriAlbumStatus();
+        if (item != nullptr && !m_pPhotoLibListView->selectedItems().isEmpty()) {
+            item->newAlbumStatus();
+        } else {
+            item->oriAlbumStatus();
+        }
     }
     if (COMMON_STR_CUSTOM == m_ItemCurrentType) {
         AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pCustomizeListView->itemWidget(m_pCustomizeListView->currentItem()));
-        item->newAlbumStatus();
-        item->oriAlbumStatus();
+        if (!m_pCustomizeListView->selectedItems().isEmpty()) {
+            item->newAlbumStatus();
+        } else {
+            item->oriAlbumStatus();
+        }
     }
     if (ALBUM_PATHTYPE_BY_PHONE == m_ItemCurrentType) {
         AlbumLeftTabItem *item = dynamic_cast<AlbumLeftTabItem *>(m_pMountListWidget->itemWidget(m_pMountListWidget->currentItem()));
-        item->newAlbumStatus();
-        item->oriAlbumStatus();
+        if (!m_pMountListWidget->selectedItems().isEmpty()) {
+            item->newAlbumStatus();
+        } else {
+            item->oriAlbumStatus();
+        }
     }
 }
 
@@ -611,7 +691,21 @@ void LeftListView::onMousePressIsNoValid()
     setFocusPolicy(Qt::ClickFocus);
 }
 
+void LeftListView::onMouseMove()
+{
+    //手动判断滑动进而滑动
+    if (m_posY != 0) {
+        int y = QCursor::pos().y() - m_posY;
+        int value = y * this->verticalScrollBar()->maximum()  / this->verticalScrollBar()->size().height();
+        if (this->verticalScrollBar()->value() != value) {
+            this->verticalScrollBar()->setValue(this->verticalScrollBar()->value() - value * 4);
+            m_posY = QCursor::pos().y();
+        }
+    } else {
+        m_posY = QCursor::pos().y();
+    }
 
+}
 
 QString LeftListView::getNewAlbumName()
 {
@@ -623,6 +717,11 @@ QString LeftListView::getItemCurrentName()
     return m_ItemCurrentName;
 }
 
+int LeftListView::getItemCurrentUID()
+{
+    return m_currentUID;
+}
+
 QString LeftListView::getItemCurrentType()
 {
     return m_ItemCurrentType;
@@ -667,3 +766,9 @@ void LeftListView::resizeEvent(QResizeEvent *e)
     int deviceHeight = m_pMountListWidget->count() * LEFT_VIEW_LISTITEM_HEIGHT_40;
     m_pMountListWidget->setFixedHeight(deviceHeight);
 }
+
+void LeftListView::mousePressEvent(QMouseEvent *e)
+{
+    m_pCustomizeListView->SaveRename(e->pos());
+    DWidget::mousePressEvent(e);
+}
