@@ -50,6 +50,7 @@
 
 DWIDGET_USE_NAMESPACE
 
+class ImageViewer;
 class NoResultWidget;
 class BatchOperateWidget;
 class AllPicView : public DWidget, public ImageEngineImportObject
@@ -84,13 +85,13 @@ public slots:
     void slotNoPicOrNoVideo(bool isNoResult);
     void updateStackedWidget();
     // 监控到新文件
-    void monitorHaveNewFile(QStringList list);
+    void monitorHaveNewFile(QStringList fileAdd, QStringList fileDelete, QString album, int UID);
 
 private slots:
     //所有照片
 
     void updatePicsIntoThumbnailViewWithCache();
-    void onRepeatImportingTheSamePhotos(QStringList importPaths, QStringList duplicatePaths, const QString &albumName);
+    void onRepeatImportingTheSamePhotos(QStringList importPaths, QStringList duplicatePaths, int UID);
     //打开图片
     void onOpenImage(int row, const QString &path, bool bFullScreen);
     //幻灯片播放
@@ -98,7 +99,7 @@ private slots:
     void onImportViewImportBtnClicked();
     void onImportFailedToView();
     //图片刷新后更新
-    void onImgRemoved(const DBImgInfoList &infos);
+    void onImgRemoved();
     //缩略图选中项改变
     void sltSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
 
@@ -121,6 +122,7 @@ private:
     QWidget *m_SuspensionWidget = nullptr;
     BatchOperateWidget *m_batchOperateWidget = nullptr;
     DCommandLinkButton *m_suspensionChose = nullptr;
+//    ImageViewer *m_ImageViewer = nullptr;
 public:
     ThumbnailListView *getThumbnailListView();
     /**
