@@ -130,7 +130,7 @@ void ImportTimeLineView::themeChangeSlot(DGuiApplicationHelper::ColorType themeT
     m_pImportTitle->setPalette(ppal_light2);
     //add end 3975
 
-    DPalette pal1 = DApplicationHelper::instance()->palette(m_NumLabel);
+    DPalette pal1 = DApplicationHelper::instance()->palette(m_DateNumLabel);
     QColor color_BT1 = pal1.color(DPalette::BrightText);
     if (themeType == DGuiApplicationHelper::LightType) {
         color_BT1.setAlphaF(0.5);
@@ -139,32 +139,17 @@ void ImportTimeLineView::themeChangeSlot(DGuiApplicationHelper::ColorType themeT
         color_BT1.setAlphaF(0.75);
         pal1.setBrush(DPalette::Text, color_BT1);
     }
-    m_NumLabel->setForegroundRole(DPalette::Text);
-    m_DateLabel->setForegroundRole(DPalette::Text);
-    m_DateLabel->setPalette(pal1);
-    m_NumLabel->setPalette(pal1);
-    //todo
-//    for (int i = 1; i < m_mainListWidget->count(); i++) {
-//        TimelineItem *item = static_cast<TimelineItem *>(m_mainListWidget->itemWidget(m_mainListWidget->item(i)));
-//        QList<DLabel *> pLabelList = item->findChildren<DLabel *>();
-//        if (pLabelList.size() < 2) {
-//            break;
-//        }
-//        DPalette pal = DApplicationHelper::instance()->palette(pLabelList[1]);
-//        QColor color_BT = pal.color(DPalette::BrightText);
-//        DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
-//        if (themeType == DGuiApplicationHelper::LightType) {
-//            color_BT.setAlphaF(0.5);
-//            pal.setBrush(DPalette::Text, color_BT);
-//        } else if (themeType == DGuiApplicationHelper::DarkType) {
-//            color_BT.setAlphaF(0.75);
-//            pal.setBrush(DPalette::Text, color_BT);
-//        }
-//        pLabelList[1]->setForegroundRole(DPalette::Text);
-//        pLabelList[0]->setForegroundRole(DPalette::Text);
-//        pLabelList[0]->setPalette(pal);
-//        pLabelList[1]->setPalette(pal);
-//    }
+    m_DateNumLabel->setForegroundRole(DPalette::Text);
+    m_DateNumLabel->setPalette(pal1);
+
+    //BUG#101474 顶部遮罩条样式刷新
+    DPalette ppal_TitleItem = DApplicationHelper::instance()->palette(m_TitleItem);
+    ppal_TitleItem.setBrush(DPalette::Background, ppal_TitleItem.color(DPalette::Base));
+    QGraphicsOpacityEffect *opacityEffect_TitleItem = new QGraphicsOpacityEffect;
+    opacityEffect_TitleItem->setOpacity(0.95);
+    m_TitleItem->setPalette(ppal_TitleItem);
+    m_TitleItem->setGraphicsEffect(opacityEffect_TitleItem);
+    m_TitleItem->setAutoFillBackground(true);
 }
 
 ThumbnailListView *ImportTimeLineView::getListView()
@@ -179,14 +164,15 @@ void ImportTimeLineView::updateSize()
     m_pImportTitle->raise();//图层上移
     m_choseBtnItem->setFixedSize(width() - 15, ChoseBtn_HEIGHT);
     m_choseBtnItem->move(0, m_TitleItem->geometry().bottom());
+    updateDateNumLabel();
 }
 
-void ImportTimeLineView::onRepeatImportingTheSamePhotos(QStringList importPaths, QStringList duplicatePaths, const QString &albumName)
+void ImportTimeLineView::onRepeatImportingTheSamePhotos(QStringList importPaths, QStringList duplicatePaths, int UID)
 {
     Q_UNUSED(importPaths)
     // 导入的照片重复照片提示
-    if (duplicatePaths.size() > 0 && albumName.length() < 1 && dApp->getMainWindow()->getCurrentViewType() == 2) {
-        m_importTimeLineListView->selectDuplicatePhotos(duplicatePaths);
+    if (duplicatePaths.size() > 0 && UID == -1 && dApp->getMainWindow()->getCurrentViewType() == 2) {
+        m_importTimeLineListView->selectPhotos(duplicatePaths);
     }
 }
 
@@ -199,8 +185,7 @@ void ImportTimeLineView::onSuspensionChoseBtnClicked()
     } else {
         m_suspensionChoseBtn->setText(QObject::tr("Select"));
     }
-    QString date_str = m_DateLabel->text();
-    m_importTimeLineListView->timeLimeFloatBtnClicked(date_str, isSelect);
+    m_importTimeLineListView->timeLimeFloatBtnClicked(dateFullStr, isSelect);
 }
 
 void ImportTimeLineView::slotBatchSelectChanged(bool isBatchSelect)
@@ -218,8 +203,7 @@ void ImportTimeLineView::slotNoPicOrNoVideo(bool isNoResult)
 {
     m_noResultWidget->setVisible(isNoResult);
     m_importTimeLineListView->setVisible(!isNoResult);
-    m_DateLabel->setVisible(!isNoResult);
-    m_NumLabel->setVisible(!isNoResult);
+    m_DateNumLabel->setVisible(!isNoResult);
     m_pImportTitle->setVisible(!isNoResult);
     emit sigNoPicOrNoVideo(isNoResult);
 }
@@ -247,12 +231,13 @@ void ImportTimeLineView::initTimeLineViewWidget()
     palcolor.setBrush(DPalette::Base, palcolor.color(DPalette::Window));
     m_timeLineViewWidget->setPalette(palcolor);
 
-    m_importTimeLineListView = new ThumbnailListView(ThumbnailDelegate::AlbumViewImportTimeLineViewType, COMMON_STR_RECENT_IMPORTED);
+    m_importTimeLineListView = new ThumbnailListView(ThumbnailDelegate::AlbumViewImportTimeLineViewType, -1, COMMON_STR_RECENT_IMPORTED);
     m_importTimeLineListView->setEditTriggers(QAbstractItemView::NoEditTriggers);
     m_importTimeLineListView->setContextMenuPolicy(Qt::CustomContextMenu);
     m_importTimeLineListView->setContentsMargins(0, 0, 0, 0);
     m_importTimeLineListView->setFocusPolicy(Qt::NoFocus);
     m_importTimeLineListView->m_imageType = COMMON_STR_RECENT_IMPORTED;
+    m_importTimeLineListView->m_currentUID = -1;
     m_mainLayout->addWidget(m_importTimeLineListView);
     //初始化筛选无结果窗口
     m_noResultWidget = new NoResultWidget(this);
@@ -289,19 +274,15 @@ void ImportTimeLineView::initTimeLineViewWidget()
     m_TitleItem->setGraphicsEffect(opacityEffect_TitleItem);
     m_TitleItem->setAutoFillBackground(true);
     //时间数量
-    m_DateLabel = new DLabel();
-    DFontSizeManager::instance()->bind(m_DateLabel, DFontSizeManager::T6, QFont::Medium);
-    m_DateLabel->setForegroundRole(DPalette::Text);
-
-    m_NumLabel = new DLabel();
-    DFontSizeManager::instance()->bind(m_NumLabel, DFontSizeManager::T6, QFont::Medium);
-    m_NumLabel->setForegroundRole(DPalette::Text);
+    m_DateNumLabel = new DLabel();
+    DFontSizeManager::instance()->bind(m_DateNumLabel, DFontSizeManager::T6, QFont::Medium);
+    m_DateNumLabel->setForegroundRole(DPalette::Text);
 
     QFont ft6 = DFontSizeManager::instance()->get(DFontSizeManager::T6);
     ft6.setFamily("SourceHanSansSC");
     ft6.setWeight(QFont::Medium);
     DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
-    DPalette pal = DApplicationHelper::instance()->palette(m_NumLabel);
+    DPalette pal = DApplicationHelper::instance()->palette(m_DateNumLabel);
     QColor color_BT = pal.color(DPalette::BrightText);
     if (themeType == DGuiApplicationHelper::LightType) {
         color_BT.setAlphaF(0.5);
@@ -310,20 +291,14 @@ void ImportTimeLineView::initTimeLineViewWidget()
     } else if (themeType == DGuiApplicationHelper::DarkType) {
         color_BT.setAlphaF(0.75);
         pal.setBrush(DPalette::Text, color_BT);
-        m_NumLabel->setForegroundRole(DPalette::Text);
-        m_NumLabel->setPalette(pal);
+        m_DateNumLabel->setForegroundRole(DPalette::Text);
+        m_DateNumLabel->setPalette(pal);
     }
-    m_NumLabel->setForegroundRole(DPalette::Text);
-    m_DateLabel->setForegroundRole(DPalette::Text);
-    m_DateLabel->setPalette(pal);
-    m_NumLabel->setPalette(pal);
-
-    m_NumLabel->setFont(ft6);
-    m_DateLabel->setFont(ft6);
+    m_DateNumLabel->setForegroundRole(DPalette::Text);
+    m_DateNumLabel->setFont(ft6);
     //end xiaolong
 
-    TitleLayout->addWidget(m_DateLabel);
-    TitleLayout->addWidget(m_NumLabel);
+    TitleLayout->addWidget(m_DateNumLabel);
     QSpacerItem *spacerItem = new QSpacerItem(10, 10, QSizePolicy::Expanding, QSizePolicy::Expanding);
     TitleLayout->addSpacerItem(spacerItem);
     m_TitleItem->move(0, 0);
@@ -406,20 +381,22 @@ void ImportTimeLineView::clearAndStartLayout()
 void ImportTimeLineView::addTimelineLayout()
 {
     m_importTimeLineListView->clearAll();
+    DBImgInfoList importList;
+
     for (int timelineIndex = 0; timelineIndex < m_timelines.size(); timelineIndex++) {
         //获取当前时间照片
         DBImgInfoList ImgInfoList = DBManager::instance()->getInfosByImportTimeline(m_timelines.at(timelineIndex));
 
         //加时间线标题
-        QString data, num;
+        QString date, num;
         QStringList dateTimeList = m_timelines.at(timelineIndex).split(" ");
         QStringList datelist = dateTimeList.at(0).split(".");
         if (datelist.count() > 2) {
             if (dateTimeList.count() == 2) {
-                data = QString(QObject::tr("Imported on") + QObject::tr(" %1-%2-%3 %4"))
+                date = QString(QObject::tr("Imported on") + QObject::tr(" %1-%2-%3 %4"))
                        .arg(datelist[0]).arg(datelist[1]).arg(datelist[2]).arg(dateTimeList[1]);
             } else {
-                data = QString(QObject::tr("Imported on ") + QObject::tr("%1/%2/%3"))
+                date = QString(QObject::tr("Imported on ") + QObject::tr("%1/%2/%3"))
                        .arg(datelist[0]).arg(datelist[1]).arg(datelist[2]);
             }
         }
@@ -445,21 +422,45 @@ void ImportTimeLineView::addTimelineLayout()
         }
 
         if (timelineIndex == 0) {
-            m_DateLabel->setText(data);
-            m_NumLabel->setText(num);
             //加空白栏
+            int height = 0;
             if (!m_choseBtnItem->isHidden()) {
-                m_importTimeLineListView->insertBlankOrTitleItem(ItemTypeBlank, data, num, (title_HEIGHT + ChoseBtn_HEIGHT));
+                height = title_HEIGHT + ChoseBtn_HEIGHT;
             } else {
-                m_importTimeLineListView->insertBlankOrTitleItem(ItemTypeBlank, data, num, (title_HEIGHT));
+                height = title_HEIGHT;
             }
+            dateFullStr = date;
+            numFullStr = num;
+
+            DBImgInfo info;
+            info.itemType = ItemTypeBlank;
+            info.imgWidth = this->width();
+            m_importTimeLineListView->m_blankItemHeight = height;
+            info.imgHeight = height;
+            info.date = date;
+            info.num = num;
+            importList.append(info);
         } else {
             //加已导入时间线标题
-            m_importTimeLineListView->insertBlankOrTitleItem(ItemTypeImportTimeLineTitle, data, num, 40);
+            DBImgInfo info;
+            info.itemType = ItemTypeImportTimeLineTitle;
+            info.imgWidth = this->width();
+            info.imgHeight = 40;
+            info.date = date;
+            info.num = num;
+            importList.append(info);
         }
         //加当前时间下的图片
-        m_importTimeLineListView->insertThumbnailByImgInfos(ImgInfoList);
+        for (auto &eachInfo : ImgInfoList) {
+            //存入当前所属时间线的日期和照片数量信息
+            eachInfo.date = date;
+            eachInfo.num = num;
+        }
+        importList.append(ImgInfoList);
     }
+
+    m_importTimeLineListView->insertThumbnails(importList);
+    updateDateNumLabel();
 }
 
 void ImportTimeLineView::getFatherStatusBar(DSlider *s)
@@ -470,21 +471,22 @@ void ImportTimeLineView::getFatherStatusBar(DSlider *s)
 void ImportTimeLineView::slotTimeLineDataAndNum(QString data, QString num, QString text)
 {
     if (!data.isEmpty()) {
-        m_DateLabel->setText(data);
+        dateFullStr = data;
     }
     if (!num.isEmpty()) {
-        m_NumLabel->setText(num);
+        numFullStr = num;
     }
     m_suspensionChoseBtn->setText(text);
+    updateDateNumLabel();
 }
 
 void ImportTimeLineView::onOpenImage(int row, const QString &path, bool bFullScreen)
 {
     SignalManager::ViewInfo info;
     info.album = "";
-    info.lastPanel = nullptr;
+//    info.lastPanel = nullptr;  //todo imageviewer
     info.fullScreen = bFullScreen;
-    auto imagelist = m_importTimeLineListView->getFileList(row);
+    auto imagelist = m_importTimeLineListView->getFileList(row, ItemType::ItemTypePic);
     if (imagelist.size() > 0) {
         info.paths << imagelist;
         info.path = path;
@@ -495,15 +497,18 @@ void ImportTimeLineView::onOpenImage(int row, const QString &path, bool bFullScr
     info.dBImgInfos = m_importTimeLineListView->getAllFileInfo(row);
     info.viewType = COMMON_STR_RECENT_IMPORTED;
     info.viewMainWindowID = VIEW_MAINWINDOW_ALBUM;
-    emit dApp->signalM->viewImage(info);
-    emit dApp->signalM->showImageView(VIEW_MAINWINDOW_ALBUM);
+    if (bFullScreen) {
+        emit dApp->signalM->sigViewImage(info, Operation_FullScreen);
+    } else {
+        emit dApp->signalM->sigViewImage(info, Operation_NoOperation);
+    }
 }
 
 void ImportTimeLineView::onSlideShow(QString path)
 {
     SignalManager::ViewInfo info;
     info.album = "";
-    info.lastPanel = nullptr;
+//    info.lastPanel = nullptr;  //todo imageviewer
 
     auto photolist = m_importTimeLineListView->selectedPaths();
     if (photolist.size() > 1) {
@@ -521,7 +526,6 @@ void ImportTimeLineView::onSlideShow(QString path)
     info.viewType = COMMON_STR_RECENT_IMPORTED;
     info.viewMainWindowID = VIEW_MAINWINDOW_ALBUM;
     emit dApp->signalM->startSlideShow(info);
-    emit dApp->signalM->showSlidePanel(VIEW_MAINWINDOW_ALBUM);
 }
 
 void ImportTimeLineView::resizeEvent(QResizeEvent *ev)
@@ -545,7 +549,7 @@ void ImportTimeLineView::dropEvent(QDropEvent *event)
     if (urls.isEmpty()) {
         return;
     }
-    ImageEngineApi::instance()->ImportImagesFromUrlList(urls, nullptr, this);
+    ImageEngineApi::instance()->ImportImagesFromUrlList(urls, nullptr, -1, this);
     event->accept();
 }
 
@@ -572,3 +576,16 @@ void ImportTimeLineView::clearAllSelection()
     m_importTimeLineListView->clearSelection();
     m_suspensionChoseBtn->setText(QObject::tr("Select"));
 }
+
+void ImportTimeLineView::updateDateNumLabel()
+{
+    auto fullStr = dateFullStr + "  " + numFullStr;
+    auto resultStr = utils::base::reorganizationStr(m_DateNumLabel->font(), fullStr, m_pImportTitle->x() - 19);
+    m_DateNumLabel->setText(resultStr);
+
+    if (resultStr != fullStr) {
+        m_DateNumLabel->setToolTip(fullStr);
+    } else {
+        m_DateNumLabel->setToolTip("");
+    }
+}
