@@ -37,6 +37,7 @@
 #include <QApplication>
 #include <DFontSizeManager>
 #include <DGuiApplicationHelper>
+#include <timelinedatewidget.h>
 
 #include "imageengineapi.h"
 #include "imagedataservice.h"
@@ -54,10 +55,10 @@ ThumbnailDelegate::ThumbnailDelegate(DelegateType type, QObject *parent)
     , selectedPixmapLight(utils::base::renderSVG(":/resources/images/other/select_active.svg", QSize(28, 28)))
     , selectedPixmapDark(utils::base::renderSVG(":/images/logo/resources/images/other/select_active_dark.svg", QSize(28, 28)))
     , m_delegatetype(type)
+    , m_default(utils::base::renderSVG(":/icons/deepin/builtin/icons/light/picture_default_light.svg", QSize(60, 45)))
+    , m_videoDefault(utils::base::renderSVG(":/icons/deepin/builtin/icons/light/video_default_light.svg", QSize(60, 45)))
+    , m_damagePixmap(utils::image::getDamagePixmap(DApplicationHelper::instance()->themeType() == DApplicationHelper::LightType))
 {
-    m_default = utils::base::renderSVG(":/icons/deepin/builtin/icons/light/picture_default_light.svg", QSize(60, 45));
-    m_videoDefault = utils::base::renderSVG(":/icons/deepin/builtin/icons/light/video_default_light.svg", QSize(60, 45));
-    m_damagePixmap = utils::image::getDamagePixmap(DApplicationHelper::instance()->themeType() == DApplicationHelper::LightType);
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this,
             &ThumbnailDelegate::onThemeTypeChanged);
 }
@@ -134,7 +135,7 @@ void ThumbnailDelegate::drawImgAndVideo(QPainter *painter, const QStyleOptionVie
     }
 
     QRect pixmapRect;
-    QImage img = ImageDataService::instance()->getThumnailImageByPath(data.filePath);
+    QImage img = ImageDataService::instance()->getThumnailImageByPathRealTime(data.filePath, COMMON_STR_TRASH == m_imageTypeStr);
     if (img.isNull()) {
         pixmapRect.setX(backgroundRect.x() + backgroundRect.width() / 2 - NotSupportedOrDamagedWidth / 2);
         pixmapRect.setY(backgroundRect.y() + backgroundRect.height() / 2 - NotSupportedOrDamagedHeigh / 2);
@@ -142,7 +143,7 @@ void ThumbnailDelegate::drawImgAndVideo(QPainter *painter, const QStyleOptionVie
         pixmapRect.setHeight(NotSupportedOrDamagedHeigh);
     } else {
         pixmapRect.setX(backgroundRect.x() + 8);
-        pixmapRect.setY(backgroundRect.y() + 8);;
+        pixmapRect.setY(backgroundRect.y() + 8);
         pixmapRect.setWidth(backgroundRect.width() - 16);
         pixmapRect.setHeight(backgroundRect.height() - 16);
     }
@@ -164,10 +165,9 @@ void ThumbnailDelegate::drawImgAndVideo(QPainter *painter, const QStyleOptionVie
     bp1.addRoundedRect(pixmapRect, utils::common::BORDER_RADIUS, utils::common::BORDER_RADIUS);
     painter->setClipPath(bp1);
 
-    if (!ImageDataService::instance()->imageIsLoaded(data.filePath)) {
+    if (!ImageDataService::instance()->imageIsLoaded(data.filePath, COMMON_STR_TRASH == m_imageTypeStr)) {
         painter->drawPixmap(pixmapRect, m_default);
     } else {
-        QImage img = ImageDataService::instance()->getThumnailImageByPath(data.filePath);
         if (img.isNull()) {
             if (data.itemType == ItemTypeVideo) {
                 painter->drawPixmap(pixmapRect, m_videoDefault);
@@ -185,8 +185,7 @@ void ThumbnailDelegate::drawImgAndVideo(QPainter *painter, const QStyleOptionVie
         DGuiApplicationHelper::ColorType themeType3 = DGuiApplicationHelper::instance()->themeType();
         if (themeType3 == DGuiApplicationHelper::LightType) {
             selectedPixmap = selectedPixmapLight;
-        }
-        if (themeType3 == DGuiApplicationHelper::DarkType) {
+        } else if (themeType3 == DGuiApplicationHelper::DarkType) {
             selectedPixmap = selectedPixmapDark;
         }
 //        QRect selectedRect(backgroundRect.x() + backgroundRect.width() - 28, backgroundRect.y(), 28, 28);
@@ -204,9 +203,9 @@ void ThumbnailDelegate::drawImgAndVideo(QPainter *painter, const QStyleOptionVie
         painter->setClipPath(bp);
         painter->setPen(QColor(85, 85, 85, 170)); //边框颜色：灰色
         //字符串的像素宽度
-        const int m_Width = painter->fontMetrics().width(data.remainDays);
+        QString str(QString::number(data.remainDays) + ThumbnailListView::tr("days"));
+        const int m_Width = painter->fontMetrics().width(str);
         painter->setBrush(QBrush(QColor(85, 85, 85, 170)));//填充颜色：灰色
-        QString str(data.remainDays);
         QFontMetrics Text(str);
 
         //2020/3/13-xiaolong
@@ -333,10 +332,9 @@ bool ThumbnailDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, co
     if (COMMON_STR_FAVORITES == m_imageTypeStr) {
         if (event->type() == QEvent::MouseButtonPress) {
             const DBImgInfo data = itemData(index);
-            bool blast = false;
-            if (!blast && rect.contains(pMouseEvent->pos())) {
+            if (rect.contains(pMouseEvent->pos())) {
                 emit sigCancelFavorite(index);
-            } else if (blast && event->type() == QEvent::MouseButtonPress && rect.contains(pMouseEvent->x(), pMouseEvent->y() + 27)) {
+            } else if (event->type() == QEvent::MouseButtonPress && rect.contains(pMouseEvent->x(), pMouseEvent->y() + 27)) {
                 emit sigCancelFavorite(index);
             }
         }
