@@ -108,6 +108,7 @@ void TimeLineView::initConnections()
     qRegisterMetaType<DBImgInfoList>("DBImgInfoList &");
     connect(dApp->signalM, &SignalManager::sigLoadOnePhoto, this, &TimeLineView::clearAndStartLayout);
     connect(dApp->signalM, &SignalManager::imagesInserted, this, &TimeLineView::clearAndStartLayout);
+    connect(dApp->signalM, &SignalManager::imagesRemoved, this, &TimeLineView::clearAndStartLayout);
     connect(dApp->signalM, &SignalManager::sigUpdateImageLoader, this, &TimeLineView::updataLayout);
     connect(m_pStatusBar->m_pSlider, &DSlider::valueChanged, dApp->signalM, &SignalManager::emitSliderValueChg);
 //    connect(pSearchView->m_pThumbnailListView, &ThumbnailListView::clicked, this, &TimeLineView::updatePicNum);
@@ -129,10 +130,12 @@ void TimeLineView::initConnections()
 
 void TimeLineView::themeChangeSlot(DGuiApplicationHelper::ColorType themeType)
 {
-    DPalette pa1 = DApplicationHelper::instance()->palette(m_dateNumItemWidget);
-    pa1.setBrush(DPalette::Background, pa1.color(DPalette::Base));
+    DPalette pa1 = DApplicationHelper::instance()->palette(pTimeLineViewWidget);
+    pa1.setBrush(DPalette::Base, pa1.color(DPalette::Window));
+
     m_dateNumItemWidget->setForegroundRole(DPalette::Background);
     m_dateNumItemWidget->setPalette(pa1);
+
     DPalette pa = DApplicationHelper::instance()->palette(m_dateLabel);
     pa.setBrush(DPalette::Text, pa.color(DPalette::ToolTipText));
     m_dateLabel->setForegroundRole(DPalette::Text);
@@ -180,7 +183,7 @@ void TimeLineView::initTimeLineViewWidget()
     palcolor.setBrush(DPalette::Base, palcolor.color(DPalette::Window));
     pTimeLineViewWidget->setPalette(palcolor);
 
-    m_timeLineThumbnailListView = new ThumbnailListView(ThumbnailDelegate::TimeLineViewType, COMMON_STR_VIEW_TIMELINE, pTimeLineViewWidget);
+    m_timeLineThumbnailListView = new ThumbnailListView(ThumbnailDelegate::TimeLineViewType, -1, COMMON_STR_VIEW_TIMELINE, pTimeLineViewWidget);
     m_timeLineThumbnailListView->setEditTriggers(QAbstractItemView::NoEditTriggers);
     m_timeLineThumbnailListView->setContextMenuPolicy(Qt::CustomContextMenu);
     m_timeLineThumbnailListView->setContentsMargins(0, 0, 0, 0);
@@ -358,12 +361,12 @@ void TimeLineView::onImportFailedToView()
     }
 }
 
-void TimeLineView::onRepeatImportingTheSamePhotos(QStringList importPaths, QStringList duplicatePaths, const QString &albumName)
+void TimeLineView::onRepeatImportingTheSamePhotos(QStringList importPaths, QStringList duplicatePaths, int UID)
 {
     Q_UNUSED(importPaths)
     // 导入的照片重复照片提示
-    if (duplicatePaths.size() > 0 && albumName.length() < 1 && dApp->getMainWindow()->getCurrentViewType() == 1) {
-        m_timeLineThumbnailListView->selectDuplicatePhotos(duplicatePaths);
+    if (duplicatePaths.size() > 0 && UID == -1 && dApp->getMainWindow()->getCurrentViewType() == 1) {
+        m_timeLineThumbnailListView->selectPhotos(duplicatePaths);
     }
 }
 
@@ -371,9 +374,9 @@ void TimeLineView::onOpenImage(int row, const QString &path, bool bFullScreen)
 {
     SignalManager::ViewInfo info;
     info.album = "";
-    info.lastPanel = nullptr;
+//    info.lastPanel = nullptr;  //todo imageviewer
     info.fullScreen = bFullScreen;
-    auto imagelist = m_timeLineThumbnailListView->getFileList(row);
+    auto imagelist = m_timeLineThumbnailListView->getFileList(row, ItemType::ItemTypePic);
     if (imagelist.size() > 0) {
         info.paths << imagelist;
         info.path = path;
@@ -383,15 +386,18 @@ void TimeLineView::onOpenImage(int row, const QString &path, bool bFullScreen)
     info.dBImgInfos = m_timeLineThumbnailListView->getAllFileInfo(row);
     info.viewType = utils::common::VIEW_TIMELINE_SRN;
     info.viewMainWindowID = VIEW_MAINWINDOW_TIMELINE;
-    emit dApp->signalM->viewImage(info);
-    emit dApp->signalM->showImageView(VIEW_MAINWINDOW_TIMELINE);
+    if (bFullScreen) {
+        emit dApp->signalM->sigViewImage(info, Operation_FullScreen);
+    } else {
+        emit dApp->signalM->sigViewImage(info, Operation_NoOperation);
+    }
 }
 
 void TimeLineView::onSlideShow(QString path)
 {
     SignalManager::ViewInfo info;
     info.album = "";
-    info.lastPanel = nullptr;
+//    info.lastPanel = nullptr;  //todo imageviewer
     auto photolist = m_timeLineThumbnailListView->selectedPaths();
     if (photolist.size() > 1) {
         //如果选中数目大于1，则幻灯片播放选中项
@@ -407,7 +413,6 @@ void TimeLineView::onSlideShow(QString path)
     info.viewType = utils::common::VIEW_TIMELINE_SRN;
     info.viewMainWindowID = VIEW_MAINWINDOW_TIMELINE;
     emit dApp->signalM->startSlideShow(info);
-    emit dApp->signalM->showSlidePanel(VIEW_MAINWINDOW_TIMELINE);
 }
 
 void TimeLineView::slotBatchSelectChanged(bool isBatchSelect)
@@ -422,18 +427,20 @@ void TimeLineView::sltSelectionChanged(const QItemSelection &selected, const QIt
     updatePicNum();
 }
 
-void TimeLineView:: addTimelineLayout()
+void TimeLineView::addTimelineLayout()
 {
     m_timeLineThumbnailListView->clearAll();
+    DBImgInfoList importList;
+
     for (int timelineIndex = 0; timelineIndex < m_timelines.size(); timelineIndex++) {
         //获取当前时间照片
         DBImgInfoList ImgInfoList = DBManager::instance()->getInfosByTimeline(m_timelines.at(timelineIndex));
 
         //加时间线标题
-        QString data, num;
+        QString date, num;
         QStringList datelist = m_timelines.at(timelineIndex).split(".");
         if (datelist.count() > 2) {
-            data = QString(QObject::tr("%1/%2/%3")).arg(datelist[0]).arg(datelist[1]).arg(datelist[2]);
+            date = QString(QObject::tr("%1/%2/%3")).arg(datelist[0]).arg(datelist[1]).arg(datelist[2]);
         }
         int photoCount = 0;
         int videoCount = 0;
@@ -457,17 +464,37 @@ void TimeLineView:: addTimelineLayout()
         }
 
         if (timelineIndex == 0) {
-            m_dateLabel->setText(data);
+            m_dateLabel->setText(date);
             m_numLabel->setText(num);
             //加空白栏
-            m_timeLineThumbnailListView->insertBlankOrTitleItem(ItemTypeBlank, data, num, SUSPENSION_WIDGET_HEIGHT);
+            DBImgInfo info;
+            info.itemType = ItemTypeBlank;
+            info.imgWidth = m_timeLineThumbnailListView->width();
+            m_timeLineThumbnailListView->m_blankItemHeight = SUSPENSION_WIDGET_HEIGHT;
+            info.imgHeight = SUSPENSION_WIDGET_HEIGHT;
+            info.date = date;
+            info.num = num;
+            importList.append(info);
         } else {
             //加时间线标题
-            m_timeLineThumbnailListView->insertBlankOrTitleItem(ItemTypeTimeLineTitle, data, num, 90);
+            DBImgInfo info;
+            info.itemType = ItemTypeTimeLineTitle;
+            info.imgWidth = m_timeLineThumbnailListView->width();
+            info.imgHeight = 90;
+            info.date = date;
+            info.num = num;
+            importList.append(info);
         }
         //加当前时间下的图片
-        m_timeLineThumbnailListView->insertThumbnailByImgInfos(ImgInfoList);
+        for (auto &eachInfo : ImgInfoList) {
+            //存入当前所属时间线的日期和照片数量信息
+            eachInfo.date = date;
+            eachInfo.num = num;
+        }
+        importList.append(ImgInfoList);
     }
+
+    m_timeLineThumbnailListView->insertThumbnails(importList);
 }
 
 void TimeLineView::on_AddLabel(QString date, QString num)
@@ -521,7 +548,7 @@ void TimeLineView::dropEvent(QDropEvent *event)
     if (urls.isEmpty()) {
         return;
     }
-    ImageEngineApi::instance()->ImportImagesFromUrlList(urls, nullptr, this);
+    ImageEngineApi::instance()->ImportImagesFromUrlList(urls, "", -1, this);
     event->accept();
 }
 
@@ -547,7 +574,6 @@ void TimeLineView::mousePressEvent(QMouseEvent *e)
 
 void TimeLineView::slotNoPicOrNoVideo(bool isNoResult)
 {
-    qDebug() << __FUNCTION__ << "---" << isNoResult;
     m_noResultWidget->setVisible(isNoResult);
     m_timeLineThumbnailListView->setVisible(!isNoResult);
     if (isNoResult) {
