@@ -63,6 +63,19 @@ int stringHeight(const QFont &f, const QString &str)
     return fm.boundingRect(str).height();
 }
 
+QString reorganizationStr(const QFont &font, const QString &fullStr, int maxWidth)
+{
+    QFontMetrics fontWidth(font); //字体信息
+    int width = fontWidth.width(fullStr) + 10; //计算字符串宽度,+10提前进入省略，避免右边遮挡
+    QString result;
+    if (width > maxWidth) {
+        result = fontWidth.elidedText(fullStr, Qt::ElideRight, maxWidth); //超过最大长度，右边搞成省略号
+    } else {
+        result = fullStr; //没超最大长度，完整显示字符串
+    }
+    return result;
+}
+
 QDateTime stringToDateTime(const QString &time)
 {
     QDateTime dt = QDateTime::fromString(time, DATETIME_FORMAT_EXIF);
@@ -165,9 +178,18 @@ QString SpliteText(const QString &text, const QFont &font, int nLabelSize)
 
 QString hashByString(const QString &str)
 {
-    return QString(QCryptographicHash::hash(str.toUtf8(), QCryptographicHash::Md5).toHex());
+    return QCryptographicHash::hash(str.toUtf8(), QCryptographicHash::Md5).toHex();
 }
 
+/*QByteArray hashByString(const QString &str)
+{
+    if (str.isEmpty()) {
+        return "\xd4\x1d\x8c\xd9\x8f\x00\xb2\x04\xe9\x80\x09\x98\xec\xf8\x42\x7e";
+    } else {
+        return QCryptographicHash::hash(str.toUtf8(), QCryptographicHash::Md5);
+    }
+}*/
+
 QString hashByData(const QString &str)
 {
     QFile file(str);
@@ -292,22 +314,20 @@ QString mkMutiDir(const QString &path)   //创建多级目录
         parentPath.mkpath(dirname);
     return parentDir + "/" + dirname;
 }
+
 //根据源文件路径生产缩略图路径
 QString filePathToThumbnailPath(const QString &filePath, QString dataHash)
 {
-    QString thumbnailPath = albumGlobal::CACHE_PATH + filePath;
-
     QFileInfo temDir(filePath);
     //如果hash为空，制作新的hash
     if (dataHash.isEmpty()) {
         dataHash = hashByData(filePath);
     }
 
-    thumbnailPath = albumGlobal::CACHE_PATH + temDir.path() + "/" + dataHash + ".png";
-    return thumbnailPath;
+    return albumGlobal::CACHE_PATH + temDir.path() + "/" + dataHash + ".png";
 }
 
-bool checkMimeUrls(const QList<QUrl> urls)
+bool checkMimeUrls(const QList<QUrl> &urls)
 {
     if (1 > urls.size()) {
         return false;
@@ -465,10 +485,173 @@ QString Time2str(const qint64 &seconds)
 bool isVideo(QString path)
 {
     QFileInfo temDir(path);
-    QString fileName = "*." + temDir.suffix().toLower(); //扩展名
+    QString fileName = temDir.suffix().toLower(); //扩展名
     return m_videoFiletypes.contains(fileName);
 }
 
+QString makeVaultLocalPath(const QString &path, const QString &base)
+{
+    QString basePath = base;
+    if (basePath.isEmpty()) {
+        basePath = VAULT_DECRYPT_DIR_NAME;
+    }
+    return VAULT_BASE_PATH + QDir::separator() + basePath + (path.startsWith('/') ? "" : "/") + path;
+}
+
+bool isVaultFile(const QString &path)
+{
+    bool bVaultFile = false;
+    QString rootPath = makeVaultLocalPath("", "");
+    if (rootPath.back() == "/") {
+        rootPath.chop(1);
+    }
+
+    if (path.contains(rootPath) && path.left(6) != "search") {
+        bVaultFile = true;
+    }
+
+    return bVaultFile;
+}
+
+//生成回收站文件名的函数，从文管里面抄的
+static QString getNotExistsTrashFileName(const QString &fileName)
+{
+    QByteArray name = fileName.toUtf8();
+
+    int index = name.lastIndexOf('/');
+
+    if (index >= 0)
+        name = name.mid(index + 1);
+
+    index = name.lastIndexOf('.');
+    QByteArray suffix;
+
+    if (index >= 0)
+        suffix = name.mid(index);
+
+    if (suffix.size() > 200)
+        suffix = suffix.left(200);
+
+    name.chop(suffix.size());
+    name = name.left(200 - suffix.size());
+
+    QString trashpath = QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + "/.local/share/Trash";
+
+    while (true) {
+        QFileInfo info(trashpath + name + suffix);
+        // QFile::exists ==> If the file is a symlink that points to a non-existing file, false is returned.
+        if (!info.isSymLink() && !info.exists()) {
+            break;
+        }
+
+        name = QCryptographicHash::hash(name, QCryptographicHash::Md5).toHex();
+    }
+
+    return QString::fromUtf8(name + suffix);
+}
+//如果删除失败,返回使用dtk接口删除
+bool trashFile(const QString &file)
+{
+    QString trashPath;
+    QString trashInfoPath;
+    QString trashFilesPath;
+
+    QString home = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+    // There maby others location for trash like $HOME/.trash or
+    // $XDG_DATA_HOME/Trash, but our stupid FileManager coder said we should
+    // assume that the trash lcation is $HOME/.local/share/Trash,so...
+    trashPath = home + "/.local/share/Trash";
+    trashInfoPath = trashPath + "/info";
+    trashFilesPath = trashPath + "/files";
+    if (! QDir(trashFilesPath).exists()) {
+        QDir().mkpath(trashFilesPath);
+    }
+    if (! QDir(trashInfoPath).exists()) {
+        QDir().mkpath(trashInfoPath);
+    }
+
+    QFileInfo originalInfo(file);
+    if (! originalInfo.exists()) {
+        qWarning() << "File doesn't exists, can't move to trash";
+        return DDesktopServices::trash(file);
+    }
+    // Info for restore
+    QString infoStr;
+    infoStr += "[Trash Info]\nPath=";
+    infoStr += QString(originalInfo.absoluteFilePath().toUtf8().toPercentEncoding("/"));
+    infoStr += "\nDeletionDate=";
+    infoStr += QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss.zzzZ");
+    infoStr += "\n";
+
+    QString trashname = getNotExistsTrashFileName(originalInfo.fileName());
+    QString infopath = trashInfoPath + "/" + trashname + ".trashinfo";
+    QString filepath = trashFilesPath + "/" + trashname;
+    int nr = 1;
+    while (QFileInfo(infopath).exists() || QFileInfo(filepath).exists()) {
+        nr++;
+        trashname = originalInfo.baseName() + "." + QString::number(nr);
+        if (!originalInfo.completeSuffix().isEmpty()) {
+            trashname += QString(".") + originalInfo.completeSuffix();
+        }
+        infopath = trashInfoPath + "/" + trashname + ".trashinfo";
+        filepath = trashFilesPath + "/" + trashname;
+    }
+    QFile infoFile(infopath);
+    if (infoFile.open(QIODevice::WriteOnly)) {
+        infoFile.write(infoStr.toUtf8());
+        infoFile.close();
+
+        if (!QDir().rename(originalInfo.absoluteFilePath(), filepath)) {
+            qWarning() << "move to trash failed!";
+            return DDesktopServices::trash(file);
+        }
+    } else {
+        qDebug() << "Move to trash failed! Could not write *.trashinfo!";
+        return DDesktopServices::trash(file);
+    }
+    return true;
+}
+
+QString getDeleteFullPath(const QString &hash, const QString &fileName)
+{
+    //防止文件过长,采用只用hash的名称;
+    return albumGlobal::DELETE_PATH + "/" + hash + "." + QFileInfo(fileName).suffix();
+}
+
+//产品需求：需要支持同步文件拷贝，以实时监控拷贝进度
+bool syncCopy(const QString &srcFileName, const QString &dstFileName)
+{
+    QFile src(srcFileName);
+    QFile dst(dstFileName);
+
+    src.open(QIODevice::ReadOnly);
+    dst.open(QIODevice::WriteOnly);
+
+    //0.预分配空间
+    auto fileSize = src.size();
+    if (!dst.resize(fileSize)) { //预分配空间失败
+        dst.close();
+        dst.remove();
+        return false;
+    }
+
+    //1.执行拷贝
+    dst.seek(0);
+    while (1) {
+        auto data = src.read(4 * 1024 * 1024);
+        if (data.isEmpty()) { //没有更多的数据
+            break;
+        }
+
+        dst.write(data);
+
+        //等待数据写入，这是和QFile::copy的区别
+        dst.waitForBytesWritten(30000);
+    }
+
+    return true;
+}
+
 }  // namespace base
 
 }  // namespace utils
