@@ -38,12 +38,24 @@ const int OPE_MODE_ADDRENAMEALBUM = 2;
 
 using namespace utils::common;
 
-AlbumLeftTabItem::AlbumLeftTabItem(QString str, QString strAlbumType)
-    : m_albumNameStr(str), m_albumTypeStr(strAlbumType), m_opeMode(0)
+AlbumLeftTabItem::AlbumLeftTabItem(QString str, int UID, QString strAlbumType)
+    : m_albumNameStr(str), m_albumTypeStr(strAlbumType), m_UID(UID), m_opeMode(0)
     , m_pLineEdit(nullptr), m_pNewLineEdit(nullptr), m_nameLabel(nullptr)
     , pImageLabel(nullptr), m_unMountBtn(nullptr), m_pListWidget(nullptr)
     , m_pListWidgetItem(nullptr)
 {
+    //修正默认相册显示的名字
+    if (DBManager::isDefaultAutoImportDB(UID)) {
+        auto paths = DBManager::getDefaultNotifyPaths();
+        auto uids = std::get<2>(paths);
+        auto names = std::get<1>(paths);
+        for (int i = 0; i != uids.size(); ++i) {
+            if (uids[i] == m_UID) {
+                m_albumNameStr = names[i];
+            }
+        }
+    }
+
     initUI();
     initConnections();
 }
@@ -73,7 +85,24 @@ void AlbumLeftTabItem::initUI()
     pImageLabel = new DLabel();
     pImageLabel->setFixedSize(24, 24);
     QPixmap pixmap;
-    if (ALBUM_PATHTYPE_BY_PHONE == m_albumTypeStr) {
+
+    if (DBManager::isDefaultAutoImportDB(m_UID)) { //如果是默认自动导入
+        switch (m_UID) {
+        case DBManager::SpUID::u_Camera:
+            pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_camera_normal.svg", QSize(24, 24));
+            break;
+        case DBManager::SpUID::u_Draw:
+            pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_draw_normal.svg", QSize(24, 24));
+            break;
+        case DBManager::SpUID::u_ScreenCapture:
+            pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_screencapture_normal.svg", QSize(24, 24));
+            break;
+        default:
+            break;
+        }
+    } else if (DBManager::instance()->getAlbumDBTypeFromUID(m_UID) == AutoImport) { //如果是自定义默认导入
+        pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_custompath_normal.svg", QSize(24, 24));
+    } else if (ALBUM_PATHTYPE_BY_PHONE == m_albumTypeStr) {
         pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_iphone_normal.svg", QSize(24, 24));
     } else if (ALBUM_PATHTYPE_BY_U == m_albumTypeStr) {
         DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
@@ -90,9 +119,8 @@ void AlbumLeftTabItem::initUI()
         pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_trash_normal.svg", QSize(24, 24));
     } else if (COMMON_STR_FAVORITES == m_albumNameStr) {
         pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_collection_normal.svg", QSize(24, 24));
-    }  else {
+    } else {
         pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_album_normal.svg", QSize(24, 24));
-
     }
     pImageLabel->setPixmap(pixmap);
 
@@ -176,9 +204,9 @@ void AlbumLeftTabItem::initUI()
     m_unMountBtn = new MountExternalBtn(m_nameLabel);
     //外部设备插入，需要添加卸载按钮
     if (ALBUM_PATHTYPE_BY_PHONE == m_albumTypeStr || ALBUM_PATHTYPE_BY_U == m_albumTypeStr) {
-        QPixmap pixmap;
-        pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_exit_normal.svg", QSize(24, 24));
-        m_unMountBtn->setPixmap(pixmap);
+        QPixmap pixmapMount;
+        pixmapMount = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_exit_normal.svg", QSize(24, 24));
+        m_unMountBtn->setPixmap(pixmapMount);
         pHBoxLayout->addWidget(m_unMountBtn);
         //m_unMountBtn->move(92, 9);
     }
@@ -215,12 +243,11 @@ void AlbumLeftTabItem::onCheckNameValid()
 {
     QString newNameStr = m_pLineEdit->lineEdit()->text().trimmed();
     if (newNameStr.isEmpty()) {
-        newNameStr = AlbumCreateDialog::getNewAlbumName("", true, m_nameLabel->text());
+        newNameStr = AlbumCreateDialog::getNewAlbumName(m_nameLabel->text());
     }
     if (OPE_MODE_RENAMEALBUM == m_opeMode || OPE_MODE_ADDRENAMEALBUM == m_opeMode) {
-        if (newNameStr != m_nameLabel->oldstr && DBManager::instance()->isAlbumExistInDB(newNameStr)) {
-            newNameStr = AlbumCreateDialog::getNewAlbumName(newNameStr, true, m_nameLabel->text());
-        }
+        //由于m_nameLabel->text()的值还是原来的值，此处修改为直接使用上面获取的lineedit的值
+        newNameStr = AlbumCreateDialog::getNewAlbumName(newNameStr);
         QFontMetrics elideFont(m_nameLabel->font());
         m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, 85));
         m_nameLabel->oldstr = newNameStr;
@@ -231,15 +258,11 @@ void AlbumLeftTabItem::onCheckNameValid()
         m_nameLabel->setVisible(true);
         m_pLineEdit->setVisible(false);
 
-        DBManager::instance()->renameAlbum(m_albumNameStr, newNameStr);
+        DBManager::instance()->renameAlbum(m_UID, newNameStr);
 
         m_albumNameStr = newNameStr;
         emit dApp->signalM->sigUpdataAlbumRightTitle(m_albumNameStr);
     } else if (OPE_MODE_ADDNEWALBUM == m_opeMode) {
-//        m_nameLabel->setText(newNameStr);
-        if (newNameStr != m_nameLabel->text() && DBManager::instance()->isAlbumExistInDB(newNameStr)) {
-            newNameStr = AlbumCreateDialog::getNewAlbumName(newNameStr);
-        }
         QFontMetrics elideFont(m_nameLabel->font());
         m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, 85));
         m_nameLabel->oldstr = newNameStr;
@@ -251,7 +274,7 @@ void AlbumLeftTabItem::onCheckNameValid()
         m_nameLabel->setVisible(true);
         m_pLineEdit->setVisible(false);
 
-        DBManager::instance()->insertIntoAlbum(newNameStr, QStringList(" "));
+        m_UID = DBManager::instance()->createAlbum(newNameStr, QStringList(" "));
 
         m_albumNameStr = newNameStr;
         emit dApp->signalM->sigUpdataAlbumRightTitle(m_albumNameStr);
@@ -260,11 +283,47 @@ void AlbumLeftTabItem::onCheckNameValid()
 
 void AlbumLeftTabItem::oriAlbumStatus()
 {
-    if (ALBUM_PATHTYPE_BY_PHONE == m_albumTypeStr) {
-        QPixmap pixmap;
-        QPixmap mountpixmap;
+    DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
+    QPixmap pixmap;
 
-        DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
+    if (DBManager::isDefaultAutoImportDB(m_UID)) { //如果是默认自动导入
+        if (themeType == DGuiApplicationHelper::LightType) {
+            switch (m_UID) {
+            case DBManager::SpUID::u_Camera:
+                pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_camera_normal.svg", QSize(24, 24));
+                break;
+            case DBManager::SpUID::u_Draw:
+                pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_draw_normal.svg", QSize(24, 24));
+                break;
+            case DBManager::SpUID::u_ScreenCapture:
+                pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_screencapture_normal.svg", QSize(24, 24));
+                break;
+            default:
+                break;
+            }
+        } else {
+            switch (m_UID) {
+            case DBManager::SpUID::u_Camera:
+                pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_camera_normal_dark.svg", QSize(24, 24));
+                break;
+            case DBManager::SpUID::u_Draw:
+                pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_draw_normal_dark.svg", QSize(24, 24));
+                break;
+            case DBManager::SpUID::u_ScreenCapture:
+                pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_screencapture_normal_dark.svg", QSize(24, 24));
+                break;
+            default:
+                break;
+            }
+        }
+    } else if (DBManager::instance()->getAlbumDBTypeFromUID(m_UID) == AutoImport) { //如果是自定义默认导入
+        if (themeType == DGuiApplicationHelper::LightType) {
+            pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_custompath_normal.svg", QSize(24, 24));
+        } else {
+            pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_custompath_normal_dark.svg", QSize(24, 24));
+        }
+    } else if (ALBUM_PATHTYPE_BY_PHONE == m_albumTypeStr) {
+        QPixmap mountpixmap;
         if (themeType == DGuiApplicationHelper::LightType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_iphone_normal.svg", QSize(24, 24));
             mountpixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_exit_normal.svg", QSize(24, 24));
@@ -273,14 +332,9 @@ void AlbumLeftTabItem::oriAlbumStatus()
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_iphone_normal_dark.svg", QSize(24, 24));
             mountpixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_exit_normal_dark.svg", QSize(24, 24));
         }
-
-        pImageLabel->setPixmap(pixmap);
         m_unMountBtn->setPixmap(mountpixmap);
     } else if (ALBUM_PATHTYPE_BY_U == m_albumTypeStr) {
-        QPixmap pixmap;
         QPixmap mountpixmap;
-
-        DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
         if (themeType == DGuiApplicationHelper::LightType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_usb_normal.svg", QSize(24, 24));
             mountpixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_exit_normal.svg", QSize(24, 24));
@@ -289,71 +343,69 @@ void AlbumLeftTabItem::oriAlbumStatus()
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_usb_normal_dark.svg", QSize(24, 24));
             mountpixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_exit_normal_dark.svg", QSize(24, 24));
         }
-
-        pImageLabel->setPixmap(pixmap);
         m_unMountBtn->setPixmap(mountpixmap);
     } else if (COMMON_STR_CUSTOM == m_albumTypeStr || COMMON_STR_CREATEALBUM == m_albumTypeStr) {
-        QPixmap pixmap;
-        DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
         if (themeType == DGuiApplicationHelper::LightType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_album_normal.svg", QSize(24, 24));
         }
         if (themeType == DGuiApplicationHelper::DarkType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_album_normal_dark.svg", QSize(24, 24));
         }
-        pImageLabel->setPixmap(pixmap);
     } else if (COMMON_STR_RECENT_IMPORTED == m_albumNameStr) {
-        QPixmap pixmap;
-        DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
         if (themeType == DGuiApplicationHelper::LightType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_import_normal.svg", QSize(24, 24));
         }
         if (themeType == DGuiApplicationHelper::DarkType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_import_normal_dark.svg", QSize(24, 24));
         }
-        pImageLabel->setPixmap(pixmap);
-
     } else if (COMMON_STR_TRASH == m_albumNameStr) {
-        QPixmap pixmap;
-        DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
         if (themeType == DGuiApplicationHelper::LightType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_trash_normal.svg", QSize(24, 24));
         }
         if (themeType == DGuiApplicationHelper::DarkType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_trash_normal_dark.svg", QSize(24, 24));
         }
-        pImageLabel->setPixmap(pixmap);
-
     } else if (COMMON_STR_FAVORITES == m_albumNameStr) {
-        QPixmap pixmap;
-        DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
         if (themeType == DGuiApplicationHelper::LightType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_collection_normal.svg", QSize(24, 24));
         }
         if (themeType == DGuiApplicationHelper::DarkType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_collection_normal_dark.svg", QSize(24, 24));
         }
-        pImageLabel->setPixmap(pixmap);
-
     }  else {
-        QPixmap pixmap;
-        DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
         if (themeType == DGuiApplicationHelper::LightType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_album_normal.svg", QSize(24, 24));
         }
         if (themeType == DGuiApplicationHelper::DarkType) {
             pixmap = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_album_normal_dark.svg", QSize(24, 24));
         }
-        pImageLabel->setPixmap(pixmap);
     }
 
+    pImageLabel->setPixmap(pixmap);
     m_nameLabel->setForegroundRole(DPalette::TextTitle);
 }
 
 void AlbumLeftTabItem::newAlbumStatus()
 {
     QPixmap pixmap;
-    if (ALBUM_PATHTYPE_BY_PHONE == m_albumTypeStr) {
+
+    if (DBManager::isDefaultAutoImportDB(m_UID)) { //如果是默认自动导入
+        switch (m_UID) {
+        case DBManager::SpUID::u_Camera:
+            pixmap = utils::base::renderSVG(":/resources/images/sidebar/active/icon_camera_active.svg", QSize(24, 24));
+            break;
+        case DBManager::SpUID::u_Draw:
+            pixmap = utils::base::renderSVG(":/resources/images/sidebar/active/icon_draw_active.svg", QSize(24, 24));
+            break;
+        case DBManager::SpUID::u_ScreenCapture:
+            pixmap = utils::base::renderSVG(":/resources/images/sidebar/active/icon_screencapture_active.svg", QSize(24, 24));
+            break;
+        default:
+            break;
+        }
+    } else if (DBManager::instance()->getAlbumDBTypeFromUID(m_UID) == AutoImport) { //如果是自定义默认导入
+        pixmap = utils::base::renderSVG(":/resources/images/sidebar/active/icon_custompath_active.svg", QSize(24, 24));
+    } else if (ALBUM_PATHTYPE_BY_PHONE == m_albumTypeStr) {
         pixmap = utils::base::renderSVG(":/resources/images/sidebar/active/icon_iphone_active.svg", QSize(24, 24));
 
         QPixmap mountpixmap;
@@ -379,4 +431,3 @@ void AlbumLeftTabItem::newAlbumStatus()
     pImageLabel->setPixmap(pixmap);
     m_nameLabel->setForegroundRole(DPalette::HighlightedText);
 }
-
