@@ -46,8 +46,8 @@
 #include <DSpinner>
 #include <DWarningButton>
 #include <QtMath>
+#include <DHiDPIHelper>
 
-#include "imgviewlistview.h"
 #include "thumbnaillistview.h"
 #include "expansionmenu.h"
 #include "imgdeletedialog.h"
@@ -96,26 +96,51 @@ void BatchOperateWidget::initConnection()
     connect(m_trashRecoveryBtn, &DPushButton::clicked, this, &BatchOperateWidget::onTrashRecoveryBtnClicked);
     //点击最近删除中删除按钮
     connect(m_trashDeleteBtn, &DPushButton::clicked, this, &BatchOperateWidget::onTrashDeleteBtnClicked);
-
     //主题变化
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &BatchOperateWidget::onThemeTypeChanged);
+    //数据库变化
+    //我的收藏
+    connect(dApp->signalM, &SignalManager::removedFromAlbum, this, &BatchOperateWidget::sltAlbumChanged);
+    connect(dApp->signalM, &SignalManager::insertedIntoAlbum, this, &BatchOperateWidget::sltAlbumChanged, Qt::QueuedConnection);
+    //图片/视频插入删除
+    viewChangedFlushTimer = new QTimer(this);
+    connect(viewChangedFlushTimer, &QTimer::timeout, this, &BatchOperateWidget::sltListViewChanged);
+    connect(m_thumbnailListView, &DListView::rowCountChanged, [this]() {
+        if (!viewChangedFlushFlag) {
+            viewChangedFlushTimer->start(200);
+            viewChangedFlushFlag = true;
+        }
+    });
+}
+
+void BatchOperateWidget::sltAlbumChanged(int UID, const QStringList &paths)
+{
+    Q_UNUSED(paths)
+    if (UID == DBManager::SpUID::u_Favorite) {
+        refreshCollectBtn();
+    }
+}
+
+void BatchOperateWidget::sltListViewChanged()
+{
+    viewChangedFlushTimer->stop();
+    viewChangedFlushFlag = false;
+
+    ExpansionPanel::FilteData data;
+    data.type = m_ToolButton->getFilteType();
+    sltCurrentFilterChanged(data);
+
+    batchSelectChanged(false, true);
 }
 
 bool BatchOperateWidget::isAllSelectedCollected()
 {
-    bool isCollected = true;
     QStringList paths =  m_thumbnailListView->selectedPaths();
     if (paths.isEmpty()) {
-        isCollected = false;
-        return isCollected;
+        return false;
     }
-    for (int i = 0; i < paths.size(); i++) {
-        if (!DBManager::instance()->isImgExistInAlbum(COMMON_STR_FAVORITES, paths.at(i), AlbumDBType::Favourite)) {
-            isCollected = false;
-            break;
-        }
-    }
-    return isCollected;
+
+    return DBManager::instance()->isAllImgExistInAlbum(DBManager::SpUID::u_Favorite, paths, AlbumDBType::Favourite);
 }
 //刷新恢复与删除按钮是否可用状态
 void BatchOperateWidget::refreshTrashBtnState()
@@ -135,6 +160,7 @@ void BatchOperateWidget::sltBatchSelectChanged()
         batchSelectChanged(false, true);
     }
     refreshBtnEnabled();
+    m_thumbnailListView->setFocus();
 }
 //全选
 void BatchOperateWidget::sltSelectAll()
@@ -142,6 +168,7 @@ void BatchOperateWidget::sltSelectAll()
     m_thumbnailListView->selectAllByItemType(m_ToolButton->getFilteType());
     m_thumbnailListView->slotChangeAllSelectBtnVisible(true);
     m_thumbnailListView->updatetimeLimeBtnText();
+    m_thumbnailListView->setFocus();
     m_chooseAll->setVisible(false);
     m_cancelChooseAll->setVisible(true);
 }
@@ -151,6 +178,7 @@ void BatchOperateWidget::sltUnSelectAll()
     m_thumbnailListView->clearSelection();
     m_thumbnailListView->slotChangeAllSelectBtnVisible(true);
     m_thumbnailListView->updatetimeLimeBtnText();
+    m_thumbnailListView->setFocus();
     m_chooseAll->setVisible(true);
     m_cancelChooseAll->setVisible(false);
 }
@@ -161,6 +189,7 @@ void BatchOperateWidget::sltRemoveSelect(bool checked)
     qDebug() << __FUNCTION__ << "---";
     QStringList paths = m_thumbnailListView->selectedPaths();
     m_thumbnailListView->removeSelectToTrash(paths);
+    m_thumbnailListView->setFocus();
 }
 //收藏选中项
 void BatchOperateWidget::sltCollectSelect(bool checked)
@@ -169,11 +198,11 @@ void BatchOperateWidget::sltCollectSelect(bool checked)
     QStringList paths =  m_thumbnailListView->selectedPaths();
     if (isAllSelectedCollected()) {
         //全部收藏，执行取消收藏动作
-        DBManager::instance()->removeFromAlbum(COMMON_STR_FAVORITES, paths, AlbumDBType::Favourite);
+        DBManager::instance()->removeFromAlbum(DBManager::SpUID::u_Favorite, paths, AlbumDBType::Favourite);
     } else {
         //未全部收藏，执行收藏动作
-        DBManager::instance()->insertIntoAlbum(COMMON_STR_FAVORITES, paths, AlbumDBType::Favourite);
-        emit dApp->signalM->insertedIntoAlbum(COMMON_STR_FAVORITES, paths);
+        DBManager::instance()->insertIntoAlbum(DBManager::SpUID::u_Favorite, paths, AlbumDBType::Favourite);
+        emit dApp->signalM->insertedIntoAlbum(DBManager::SpUID::u_Favorite, paths);
     }
     //收藏后刷新按钮状态，未通过insertIntoAlbum返回值判断是否成功
     if (isAllSelectedCollected()) {
@@ -181,6 +210,7 @@ void BatchOperateWidget::sltCollectSelect(bool checked)
     } else {
         m_collection->setIcon(QIcon::fromTheme("dcc_collection_normal"));
     }
+    m_thumbnailListView->setFocus();
 }
 //顺时针旋转
 void BatchOperateWidget::sltRightRotate(bool checked)
@@ -191,6 +221,7 @@ void BatchOperateWidget::sltRightRotate(bool checked)
     for (int i = 0; i < paths.size(); i++) {
         emit ImageEngineApi::instance()->sigRotateImageFile(90, paths.at(i));
     }
+    m_thumbnailListView->setFocus();
 }
 //逆时针旋转
 void BatchOperateWidget::sltLeftRotate(bool checked)
@@ -201,6 +232,7 @@ void BatchOperateWidget::sltLeftRotate(bool checked)
     for (int i = 0; i < paths.size(); i++) {
         emit ImageEngineApi::instance()->sigRotateImageFile(-90, paths.at(i));
     }
+    m_thumbnailListView->setFocus();
 }
 //缩略图列表选中状态发生变化
 void BatchOperateWidget::sltSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
@@ -213,6 +245,7 @@ void BatchOperateWidget::sltSelectionChanged(const QItemSelection &selected, con
     }
     batchSelectChanged(true, false);
     refreshBtnEnabled();
+    m_thumbnailListView->setFocus();
 }
 
 void BatchOperateWidget::sltCurrentFilterChanged(ExpansionPanel::FilteData &data)
@@ -229,6 +262,7 @@ void BatchOperateWidget::sltCurrentFilterChanged(ExpansionPanel::FilteData &data
     }
     //如果过滤会后数量<=0，则不可用
     m_startBatchSelect->setEnabled(m_thumbnailListView->getAppointTypeItemCount(m_ToolButton->getFilteType()) > 0);
+    m_thumbnailListView->setFocus();
 }
 //点击最近删除恢复按钮
 void BatchOperateWidget::onTrashRecoveryBtnClicked()
@@ -236,23 +270,13 @@ void BatchOperateWidget::onTrashRecoveryBtnClicked()
     QStringList paths;
     paths = m_thumbnailListView->selectedPaths();
     ImageEngineApi::instance()->recoveryImagesFromTrash(paths);
+    m_thumbnailListView->setFocus();
 }
 //点击最近删除中删除按钮
 void BatchOperateWidget::onTrashDeleteBtnClicked()
 {
     QStringList paths = m_thumbnailListView->selectedPaths();
-    int imgCount = 0;
-    int videoCount = 0;
-    DBImgInfo info;
-    for (int i = 0; i < paths.size(); i++) {
-        ImageEngineApi::instance()->getImageData(paths.at(i), info);
-        if (info.itemType == ItemTypePic) {
-            imgCount++;
-        } else if (info.itemType == ItemTypeVideo) {
-            videoCount++;
-        }
-    }
-    ImgDeleteDialog *dialog = new ImgDeleteDialog(this, imgCount, videoCount);
+    ImgDeleteDialog *dialog = new ImgDeleteDialog(this, paths.size(), true);
     dialog->setObjectName("deteledialog");
     if (dialog->exec() > 0) {
         m_thumbnailListView->clearSelection();
@@ -260,6 +284,7 @@ void BatchOperateWidget::onTrashDeleteBtnClicked()
     }
 
     refreshTrashBtnState();
+    m_thumbnailListView->setFocus();
 }
 //主题变化
 void BatchOperateWidget::onThemeTypeChanged(DGuiApplicationHelper::ColorType themeType)
@@ -389,24 +414,28 @@ void BatchOperateWidget::initDropdown()
     m_expansionMenu = new ExpansionMenu(this);
     m_ToolButton = m_expansionMenu->mainWidget();
     m_ToolButton->setText(QObject::tr("All"));
-    m_ToolButton->setIcon(QIcon::fromTheme("album_all"));
+    //m_ToolButton->setIcon(DHiDPIHelper::loadNxPixmap(":/icons/deepin/builtin/icons/light/album_all_16px.svg"));
+    m_ToolButton->setIcon(DHiDPIHelper::loadNxPixmap(":/icons/deepin/builtin/icons/dark/album_all_16px.svg"));
     ExpansionPanel::FilteData data;
 
-    data.icon_r = QIcon::fromTheme("album_all");
-    data.icon_r_path = "album_all";
+    data.icon_r_light = QIcon::fromTheme("album_all");
+    data.icon_r_dark  = QIcon::fromTheme("album_all_hover");
+    data.icon_r_path  = "album_all";
     data.text = QObject::tr("All");
     data.type = ItemType::ItemTypeNull;
     m_expansionMenu->setDefaultFilteData(data);
     m_expansionMenu->addNewButton(data);
 
-    data.icon_r = QIcon::fromTheme("album_pic");
-    data.icon_r_path = "album_pic";
+    data.icon_r_light = QIcon::fromTheme("album_pic");
+    data.icon_r_dark  = QIcon::fromTheme("album_pic_hover");
+    data.icon_r_path  = "album_pic";
     data.text = QObject::tr("Photos");
     data.type = ItemType::ItemTypePic;
     m_expansionMenu->addNewButton(data);
 
-    data.icon_r = QIcon::fromTheme("album_video");
-    data.icon_r_path = "album_video";
+    data.icon_r_light = QIcon::fromTheme("album_video");
+    data.icon_r_dark  = QIcon::fromTheme("album_video_hover");
+    data.icon_r_path  = "album_video";
     data.text = QObject::tr("Videos");
     data.type = ItemType::ItemTypeVideo;
     m_expansionMenu->addNewButton(data);
@@ -493,11 +522,11 @@ void BatchOperateWidget::batchSelectChanged(bool isBatchSelect, bool disConnectS
 void BatchOperateWidget::refreshBtnEnabled(bool noSelected)
 {
     //选中项数量变化，更新按钮可用状态
-    bool selectMultiple = m_thumbnailListView->selectedPaths().size() > 0;
+    bool selectMultiple = !m_thumbnailListView->selectedPaths().isEmpty();
     m_collection->setEnabled(selectMultiple);
     m_leftRotate->setEnabled(selectMultiple);
     m_rightRotate->setEnabled(selectMultiple);
-    m_delete->setEnabled(selectMultiple);
+    m_delete->setEnabled(m_thumbnailListView->isSelectedCanUseDelete());
     //选择发生变化，刷新收藏按钮状态
     if (m_collection->isVisible()) {
         if (isAllSelectedCollected()) {
@@ -543,3 +572,9 @@ void BatchOperateWidget::hideEvent(QHideEvent *event)
     refreshBtnEnabled();
 }
 
+void BatchOperateWidget::mouseReleaseEvent(QMouseEvent *event)
+{
+    QWidget::mouseReleaseEvent(event);
+
+    m_thumbnailListView->setFocus();
+}
