@@ -25,6 +25,7 @@
 #include <DDialog>
 #include <DMessageBox>
 #include <DTitlebar>
+#include <DComboBox>
 
 #include <QFormLayout>
 #include <QImageWriter>
@@ -36,7 +37,8 @@
 #include <QDebug>
 #include <QDateTime>
 #include <QTimer>
-
+#include <QRegExp>
+#include <QRegExpValidator>
 
 const QSize DIALOG_SIZE = QSize(380, 280);
 const QSize LINE_EDIT_SIZE = QSize(250, 35);
@@ -44,7 +46,7 @@ const QSize LINE_EDIT_SIZE = QSize(250, 35);
 CExportImageDialog::CExportImageDialog(DWidget *parent)
     : DDialog(parent), m_fileNameEdit(nullptr), m_savePathCombox(nullptr)
     , m_formatCombox(nullptr), m_qualitySlider(nullptr), m_qualityLabel(nullptr)
-    , m_quality(0), m_questionDialog(nullptr), m_emptyWarningDialog(nullptr)
+    , m_quality(0), m_questionDialog(nullptr), m_questionDialogs(nullptr), m_emptyWarningDialog(nullptr)
 {
     initUI();
     initConnection();
@@ -141,39 +143,6 @@ void CExportImageDialog::initUI()
 
     setWindowTitle(tr("Export"));
 
-    m_fileNameEdit = new DLineEdit(this);
-    //m_fileNameEdit->setFixedSize(LINE_EDIT_SIZE);
-    m_fileNameEdit->setClearButtonEnabled(false);
-//    m_fileNameEdit->setFocusPolicy(Qt::ClickFocus);
-
-    connect(m_fileNameEdit, &DLineEdit::editingFinished, this, [ = ] {
-        QString arg = m_fileNameEdit->text();
-        int len = arg.toLocal8Bit().size();
-        int filemaxlen = 251;
-        if (m_saveFormat.toUpper().compare("JPEG") == 0)
-            filemaxlen -= 1;
-        QString Interceptstr;
-        if (len > filemaxlen)
-        {
-            int num = 0;
-            int pos = 0;
-            for (; pos < arg.size(); pos++) {
-                if (arg.at(pos) >= 0x4e00 && arg.at(pos) <= 0x9fa5) {
-                    num += 3;
-                    if (num >= filemaxlen) {
-                        break;
-                    }
-                } else if (num < filemaxlen) {
-                    num += 1;
-                } else {
-                    break;
-                }
-            }
-            Interceptstr = arg.left(pos);
-            m_fileNameEdit->setText(Interceptstr);
-        }
-    });
-
     m_savePathCombox = new DComboBox(this);
     m_savePathCombox->setFocusPolicy(Qt::TabFocus);
     m_savePathCombox->insertItem(Pictures, tr("Pictures"));
@@ -186,7 +155,6 @@ void CExportImageDialog::initUI()
 
     //m_savePathCombox->setFixedSize(LINE_EDIT_SIZE);
 
-
     m_formatCombox = new DComboBox(this);
     m_formatCombox->setFocusPolicy(Qt::TabFocus);
 //    m_formatCombox->insertItem(JPG, "jpg");
@@ -205,6 +173,13 @@ void CExportImageDialog::initUI()
     m_formatCombox->insertItem(XPM, "xpm");
     //m_formatCombox->setFixedSize(LINE_EDIT_SIZE);
 
+    m_fileNameEdit = new DLineEdit(this);
+    m_fileNameEdit->setClearButtonEnabled(false);
+    m_fileNameEdit->lineEdit()->setMaxLength(255 - 1 - m_formatCombox->currentText().size());
+    QRegExp regExp("[^/\\\\\\[\\]:|<>+=;,?*'\"]+");
+    QRegExpValidator *pattern = new QRegExpValidator(regExp, this);
+    m_fileNameEdit->lineEdit()->setValidator(pattern);
+
     m_qualitySlider = new DSlider(Qt::Horizontal, this);
     m_qualitySlider->slider()->setFocusPolicy(Qt::TabFocus);
     m_qualitySlider->setMinimum(1);
@@ -300,30 +275,9 @@ void CExportImageDialog::slotOnSavePathChange(int index)
 void CExportImageDialog::slotOnFormatChange(int index)
 {
     m_saveFormat = m_formatCombox->itemText(index);
-    //when jpeg format,recalculate file name length ,because ".jpeg"==5
-    if (m_saveFormat.toUpper().compare("JPEG") == 0) {
-        QString arg = m_fileNameEdit->text();
-        int len = arg.toLocal8Bit().size();
-        QString Interceptstr;
-        if (len > 250) {
-            unsigned num = 0;
-            int pos = 0;
-            for (; pos < arg.size(); pos++) {
-                if (arg.at(pos) >= 0x4e00 && arg.at(pos) <= 0x9fa5) {
-                    num += 3;
-                    if (num >= 250) {
-                        break;
-                    }
-                } else if (num < 250) {
-                    num += 1;
-                } else {
-                    break;
-                }
-            }
-            Interceptstr = arg.left(pos);
-            m_fileNameEdit->setText(Interceptstr);
-        }
-    }
+
+    int filemaxlen = 255 - 1 - m_saveFormat.size();
+    m_fileNameEdit->lineEdit()->setMaxLength(filemaxlen);
 }
 
 void CExportImageDialog::slotOnDialogButtonClick(int index, const QString &text)
@@ -377,6 +331,16 @@ void CExportImageDialog::slotOnQuestionDialogButtonClick(int index, const QStrin
     }
 }
 
+void CExportImageDialog::slotOnQuestionDialogButtonClicks(int index, const QString &text)
+{
+    Q_UNUSED(text);
+    m_isCover = false;
+    if (index == 1) {
+        QFile::remove(m_CoverFilepath);
+        m_isCover = true;
+    }
+}
+
 void CExportImageDialog::slotOnQualityChanged(int value)
 {
     m_qualityLabel->setText(QString("%1%").arg(value));
@@ -399,6 +363,8 @@ void CExportImageDialog::showDirChoseDialog()
         QTimer::singleShot(50, this, [ = ] {
             m_savePathCombox->setCurrentText(fileDir);
         });
+    } else {
+        m_savePathCombox->setCurrentIndex(0);
     }
 }
 
@@ -463,20 +429,59 @@ void CExportImageDialog::showQuestionDialog(const QString &path, const QString &
     m_questionDialog->exec();
 }
 
+void CExportImageDialog::showQuestionDialogs(const QString &path)
+{
+    delete m_questionDialogs;
+    m_questionDialogs = new DDialog(this);
+    m_questionDialogs->setFocusPolicy(Qt::NoFocus);
+    m_questionDialogs->setModal(true);
+    m_questionDialogs->addButtons({tr("Cancel"), tr("Replace")});
+    m_questionDialogs->setFixedSize(400, 170);
+    m_CoverFilepath = path;
+    connect(m_questionDialogs, SIGNAL(buttonClicked(int, const QString &)), this, SLOT(slotOnQuestionDialogButtonClicks(int, const QString &)));
+    //BUG#90251
+
+    DWidget *wid = new DWidget();
+    DLabel *lab1 = new DLabel();
+    QFontMetrics elideFont(lab1->font());
+    lab1->setText(elideFont.elidedText(path, Qt::ElideRight, 255));
+    lab1->setToolTip(path);
+
+    DLabel *lab2 = new DLabel();
+    lab2->setText(tr("already exists. Do you want to replace it?"));
+    lab2->setAlignment(Qt::AlignCenter);
+
+    QVBoxLayout *lay = new QVBoxLayout();
+    lay->setContentsMargins(0, 0, 0, 0);
+    lay->addWidget(lab1);
+    lay->addWidget(lab2);
+    lay->addSpacing(100);
+    wid->setLayout(lay);
+    m_questionDialogs->addContent(wid, Qt::AlignCenter);
+    m_questionDialogs->move(dApp->getMainWindow()->x() + (dApp->getMainWindow()->width() - m_questionDialogs->width()) / 2,
+                            dApp->getMainWindow()->y() + (dApp->getMainWindow()->height() - m_questionDialogs->height()) / 2);
+    m_questionDialogs->exec();
+}
+
+bool CExportImageDialog::getIsCover()
+{
+    return m_isCover;
+}
+
 bool CExportImageDialog::doSave()
 {
     bool isSuccess = false;
     m_saveFormat = m_formatCombox->currentText();
     QString completePath = m_savePath + "/" + m_fileNameEdit->text().trimmed() + "." + m_saveFormat;
     if (tr("gif") == m_saveFormat) {
-        if(gifpath.isEmpty()){
+        if (gifpath.isEmpty()) {
             return isSuccess;
         }
 
         QFileInfo fileinfo(completePath);
         if (fileinfo.exists() && !fileinfo.isDir()) {
             //目标位置与原图位置相同则直接返回
-            if(gifpath == completePath){
+            if (gifpath == completePath) {
                 return true;
             }
             //目标位置与原图位置不同则先删除再复制
