@@ -44,7 +44,7 @@ struct MetaData {
 };
 
 static MetaData MetaDataBasics[] = {
-    {"FileName",            QT_TRANSLATE_NOOP("MetadataName", "Photo name")},
+    {"FileName",            QT_TRANSLATE_NOOP("MetadataName", "Name")},
 
     {"DateTimeOriginal",    QT_TRANSLATE_NOOP("MetadataName", "Date captured")},
     {"DateTimeDigitized",   QT_TRANSLATE_NOOP("MetadataName", "Date modified")},
@@ -77,9 +77,7 @@ static MetaData MetaDataDetails[] = {
 
 }  // namespace
 
-
-
-ImgInfoDialog::ImgInfoDialog(const QString &path, QWidget *parent)
+ImgInfoDialog::ImgInfoDialog(const QString &path, const QString &displayName, QWidget *parent)
     : DDialog(parent), m_title_maxwidth(0), m_maxFieldWidth(0),
       m_isBaseInfo(false), m_isDetailsInfo(false), m_exif_base(nullptr),
       m_exif_details(nullptr), m_exifLayout_base(nullptr), m_exifLayout_details(nullptr),
@@ -94,6 +92,8 @@ ImgInfoDialog::ImgInfoDialog(const QString &path, QWidget *parent)
     else
         m_title_maxwidth = 108;
 
+    m_displayName = displayName;
+
     initUI();
     setImagePath(path);
 }
@@ -105,15 +105,20 @@ int ImgInfoDialog::height()
 
 void ImgInfoDialog::initUI()
 {
-//    setAutoFillBackground(true);
-    setAttribute(Qt::WA_TranslucentBackground, true);
+    //wayland背景透明问题
+    DPalette imgInfoDlgPl = this->palette();
+    QColor imgInfoDlgColor("#F7F7F7");
+    imgInfoDlgColor.setAlphaF(0.8);
+    imgInfoDlgPl.setColor(DPalette::Window, imgInfoDlgColor);
+    this->setBackgroundRole(DPalette::Window);
+
     setFixedWidth(320);
     setMaximumHeight(540);
     setContentLayoutContentsMargins(QMargins(0, 0, 0, 0));
 
     //title
     DLabel *title = new DLabel(this);
-    title->setText(tr("Photo info"));
+    title->setText(tr("Image info"));
     title->setGeometry(this->x() + (this->width() - title->width()) / 2, this->y(), 112, 50);
     title->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
     DFontSizeManager::instance()->bind(title, DFontSizeManager::T6);
@@ -274,18 +279,13 @@ void ImgInfoDialog::updateBaseInfo(const QMap<QString, QString> &infos)
         if (i->key.contains("Dimension")) {
             value = infos.value("Dimension");
             if (value == "0x0") {
-                DBImgInfo st;
-                ImageEngineApi::instance()->getImageData(m_path, st);
-                value = st.albumSize;
-                if (value.isEmpty()) {
-                    QImage tImg;
-                    QString errMsg;
-                    if (!UnionImage_NameSpace::loadStaticImageFromFile(m_path, tImg, errMsg)) {
-                        qDebug() << errMsg;
-                        continue;
-                    }
-                    value = QString::number(tImg.width()) + "x" + QString::number(tImg.height());
+                QImage tImg;
+                QString errMsg;
+                if (!UnionImage_NameSpace::loadStaticImageFromFile(m_path, tImg, errMsg)) {
+                    qDebug() << errMsg;
+                    continue;
                 }
+                value = QString::number(tImg.width()) + "x" + QString::number(tImg.height());
             }
         } else if (i->key.contains("FileFormat")) {
             QStringList list = value.split("/");
@@ -312,7 +312,13 @@ void ImgInfoDialog::updateBaseInfo(const QMap<QString, QString> &infos)
             DPalette pa1 = DApplicationHelper::instance()->palette(field);
             pa1.setBrush(DPalette::Text, pa1.color(DPalette::TextTitle));
             field->setPalette(pa1);
-            field->setText(SpliteText(value, field->font(), m_maxFieldWidth));
+
+            if (i->key == "FileName") {
+                field->setText(SpliteText(m_displayName, field->font(), m_maxFieldWidth));
+            } else {
+                field->setText(SpliteText(value, field->font(), m_maxFieldWidth));
+            }
+
             SimpleFormLabel *title = new SimpleFormLabel(trLabel(i->name) + ":");
             title->setMinimumHeight(field->minimumHeight());
             title->setFixedWidth(m_title_maxwidth);
@@ -322,9 +328,8 @@ void ImgInfoDialog::updateBaseInfo(const QMap<QString, QString> &infos)
             DPalette pa2 = DApplicationHelper::instance()->palette(title);
             pa2.setBrush(DPalette::Text, pa2.color(DPalette::TextTitle));
             title->setPalette(pa2);
-            QString text1 = i->name;
             title->setText(SpliteText(trLabel(i->name) + ":", title->font(), m_title_maxwidth));
-            QString text = title->text();
+
             m_exifLayout_base->addRow(title, field);
         }
     }
