@@ -44,7 +44,7 @@ struct MetaData {
     const char *name;
 };
 
-VideoInfoDialog::VideoInfoDialog(const QString &path, QWidget *parent): DDialog(parent)
+VideoInfoDialog::VideoInfoDialog(const QString &path, const QString &displayName, bool isTrash, QWidget *parent): DDialog(parent)
 {
     QFont font;
     m_currentFontSize = DFontSizeManager::instance()->fontPixelSize(font);
@@ -54,13 +54,14 @@ VideoInfoDialog::VideoInfoDialog(const QString &path, QWidget *parent): DDialog(
     else
         m_title_maxwidth = 108;
     this->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+    m_displayName = displayName;
+    m_isTrash = isTrash;
     initUI();
     setVideoInfo(path);
 }
 
 void VideoInfoDialog::setVideoInfo(const QString &path)
 {
-    bool is = false;
     //获取视频信息
     m_movieInfo = MovieService::instance()->getMovieInfo(QUrl::fromLocalFile(path));
     m_maxFieldWidth = width() - m_title_maxwidth - 20 * 2 - 10 * 2;
@@ -81,6 +82,8 @@ void VideoInfoDialog::setVideoInfo(const QString &path)
         int index = m_expandGroup.size() > 0 ? (m_expandGroup.size() - 1) : 0;
         m_expandGroup.at(index)->setContent(m_codecInfoFrame);
         m_expandGroup.at(index)->setExpand(true);
+        //音频编码等信息默认隐藏
+        m_expandGroup.at(index)->setExpand(false);//疑似DDrawer的BUG，直接false会显示不全
     }
 
     if (m_containAudioInfo) {
@@ -88,6 +91,7 @@ void VideoInfoDialog::setVideoInfo(const QString &path)
         int index = m_expandGroup.size() > 0 ? (m_expandGroup.size() - 1) : 0;
         m_expandGroup.at(index)->setContent(m_audioInfoFrame);
         m_expandGroup.at(index)->setExpand(true);
+        m_expandGroup.at(index)->setExpand(false);//疑似DDrawer的BUG，直接false会显示不全
     }
 
     //剔除多余不需要的焦点
@@ -143,9 +147,6 @@ void VideoInfoDialog::updateCodecInfo()
         pa1.setBrush(DPalette::Text, pa1.color(DPalette::TextTitle));
         field->setPalette(pa1);
         field->setText(SpliteText(value, field->font(), m_maxFieldWidth));
-//        field->setText(value);
-//        field->setWordWrap(true);
-//        field->adjustSize();
 
         SimpleFormLabel *title = new SimpleFormLabel(key);
         title->setMinimumHeight(field->minimumHeight());
@@ -157,13 +158,9 @@ void VideoInfoDialog::updateCodecInfo()
         pa2.setBrush(DPalette::Text, pa2.color(DPalette::TextTitle));
         title->setPalette(pa2);
         title->setText(SpliteText((key), title->font(), m_title_maxwidth));
-//        title->setText((key + ":"));
-//        title->setWordWrap(true);
-//        title->adjustSize();
 
         m_codecInfoFrameLayout->addRow(title, field);
         QFontMetrics fm(field->font());
-//        m_codecInfoFrame->setFixedHeight(m_codecInfoFrame->height() + field->height());
     }
 }
 
@@ -202,9 +199,6 @@ void VideoInfoDialog::updateAudioInfo()
         pa1.setBrush(DPalette::Text, pa1.color(DPalette::TextTitle));
         field->setPalette(pa1);
         field->setText(SpliteText(value, field->font(), m_maxFieldWidth));
-//        field->setText(value);
-//        field->setWordWrap(true);
-//        field->adjustSize();
 
         SimpleFormLabel *title = new SimpleFormLabel(key);
         title->setMinimumHeight(field->minimumHeight());
@@ -216,13 +210,9 @@ void VideoInfoDialog::updateAudioInfo()
         pa2.setBrush(DPalette::Text, pa2.color(DPalette::TextTitle));
         title->setPalette(pa2);
         title->setText(SpliteText((key), title->font(), m_title_maxwidth));
-//        title->setText((key + ":"));
-//        title->setWordWrap(true);
-//        title->adjustSize();
 
         m_audioInfoFrameLayout->addRow(title, field);
         QFontMetrics fm(field->font());
-//        m_audioInfoFrame->setFixedHeight(m_audioInfoFrame->height() + field->height());
     }
 }
 
@@ -231,10 +221,10 @@ void VideoInfoDialog::updateBasicInfo()
 //    clearLayout(m_basicInfoFrameLayout);
     QMap<QString, QString> basicInfoMap;
     QList<QString> basicInfoKeys;
-    basicInfoMap[tr("Video name")] = m_movieInfo.title;
-    basicInfoKeys.append(tr("Video name"));
+    basicInfoMap[tr("Name")] = m_displayName;
+    basicInfoKeys.append(tr("Name"));
 
-    QDateTime dateTime = QDateTime::fromString(m_movieInfo.creation);
+    QDateTime dateTime = m_movieInfo.creation;
 //    basicInfoMap[tr("Date captured")] = m_movieInfo.creation;
     basicInfoMap[tr("Date captured")] = dateTime.toString("yyyy/MM/dd HH:mm");
     basicInfoKeys.append(tr("Date captured"));
@@ -256,8 +246,11 @@ void VideoInfoDialog::updateBasicInfo()
     basicInfoMap[tr("Duration")] = m_movieInfo.durationStr();
     basicInfoKeys.append(tr("Duration"));
 
-    basicInfoMap[tr("Path")] = m_movieInfo.filePath;
-    basicInfoKeys.append(tr("Path"));
+    //trash目录不显示路径
+    if (!m_isTrash) {
+        basicInfoMap[tr("Path")] = m_movieInfo.filePath;
+        basicInfoKeys.append(tr("Path"));
+    }
 
     for (int i = 0; i < basicInfoKeys.size(); i++) {
         QString key = basicInfoKeys.at(i);
@@ -277,6 +270,7 @@ void VideoInfoDialog::updateBasicInfo()
 
         SimpleFormLabel *title = new SimpleFormLabel(key);
         title->setMinimumHeight(field->minimumHeight());
+        title->setFixedWidth(m_title_maxwidth);
         title->setAlignment(Qt::AlignLeft | Qt::AlignTop);
         DFontSizeManager::instance()->bind(title, DFontSizeManager::T8);
         DPalette pa2 = DApplicationHelper::instance()->palette(title);
@@ -288,25 +282,8 @@ void VideoInfoDialog::updateBasicInfo()
     }
 }
 
-//QList<DDrawer *> VideoInfoDialog::addExpandWidget(const QStringList &titleList)
-//{
-//    QVBoxLayout *layout = qobject_cast<QVBoxLayout *>(m_scrollArea->widget()->layout());
-//    QList<DDrawer *> group;
-
-//    for (const QString &title : titleList) {
-//        DFMDArrowLineExpand *expand = new DFMDArrowLineExpand;//DArrowLineExpand;
-//        expand->setTitle(title);
-//        initExpand(layout, expand);
-//        group.push_back(expand);
-//    }
-
-//    return group;
-//}
-
 void VideoInfoDialog::appendExpandWidget(const QString &title)
 {
-//    QVBoxLayout *layout = qobject_cast<QVBoxLayout *>(m_scrollArea->widget()->layout());
-
     DFMDArrowLineExpand *expand = new DFMDArrowLineExpand;//DArrowLineExpand;
     expand->setTitle(title);
     initExpand(m_scrollAreaLayout, expand);
@@ -329,13 +306,10 @@ void VideoInfoDialog::initExpand(QVBoxLayout *layout, DDrawer *expand)
         QRect rc = geometry();
         if (m_expandGroup.count() == 2) {
             rc.setHeight(qMin(615, contentHeight() + 15));
-//            setGeometry(rc);
-//            this->setFixedHeight(qMin(615, contentHeight() + 15));
             setGeometry(rc);
         } else {
             rc.setHeight(qMin(615, contentHeight() + 25));
             setGeometry(rc);
-//            this->setFixedHeight(qMin(615, contentHeight() + 25));
         }
     });
 }
@@ -408,7 +382,13 @@ void VideoInfoDialog::showEvent(QShowEvent *e)
 
 void VideoInfoDialog::initUI()
 {
-    setAttribute(Qt::WA_TranslucentBackground, true);
+    //wayland背景透明问题
+    DPalette imgInfoDlgPl = this->palette();
+    QColor imgInfoDlgColor("#F7F7F7");
+    imgInfoDlgColor.setAlphaF(0.8);
+    imgInfoDlgPl.setColor(DPalette::Window, imgInfoDlgColor);
+    this->setBackgroundRole(DPalette::Window);
+
     setFixedWidth(320);
     setMaximumHeight(540);
     setContentLayoutContentsMargins(QMargins(0, 0, 0, 0));
