@@ -30,11 +30,7 @@
 
 #include "leftlistview.h"
 #include "application.h"
-#include "frame/mainwidget.h"
-#include "module/view/navigationwidget.h"
-#include "module/view/scen/graphicsitem.h"
 #include "searchview/searchview.h"
-#include "module/view/scen/imageview.h"
 #include "gio-qt/dgiovolumemanager.h"
 #include "mainwindow.h"
 #include "albumview.h"
@@ -44,6 +40,8 @@
 #include "../test_qtestDefine.h"
 #include "ac-desktop-define.h"
 #include "mock_mount.h"
+#include "imageengineapi.h"
+#include "viewerthememanager.h"
 
 #include <QMovie>
 
@@ -121,9 +119,6 @@ TEST(AlbumView, clickImportViewBtn)
         image_list << info.absoluteFilePath();
     }
     QTest::qWait(500);
-
-    if (image_list.size() > 0)
-        ImageEngineApi::instance()->insertImage(image_list.first(), "");
 }
 
 TEST(AlbumView, ini)
@@ -224,8 +219,8 @@ TEST(AlbumView, createNewAlbumFromDialog)
         }
     }
     QTest::qWait(200);
-    emit dApp->signalM->sigCreateNewAlbumFromDialog("test-album");
-    emit dApp->signalM->sigCreateNewAlbumFrom("test-album2");
+    emit dApp->signalM->sigCreateNewAlbumFromDialog("test-album", 994);
+    emit dApp->signalM->sigCreateNewAlbumFrom("test-album2", 993);
 }
 
 TEST(AlbumView, dragPhotoToAnAlbum)
@@ -637,13 +632,14 @@ TEST(AlbumView, onLeftListDropEvent_test)
 TEST(AlbumView, albumView_other1_test)
 {
     TEST_CASE_NAME("albumView_other1_test")
+
     MainWindow *w = dApp->getMainWindow();
     w->albumBtnClicked();
 
     QMimeData mimedata;
     QList<QUrl> li;
     QString lastImportPath =  QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first();
-    lastImportPath += "/test/4l6r5y.png";
+    lastImportPath += "/AlbumtestResource/test/4l6r5y.png";
     li.append(QUrl(lastImportPath));
     mimedata.setUrls(li);
 
@@ -667,7 +663,7 @@ TEST(AlbumView, albumView_other1_test)
     w->m_pAlbumview->m_currentType = COMMON_STR_FAVORITES;
     w->m_pAlbumview->updateRightView();
 
-    w->m_pAlbumview->updateAlbumView(w->m_pAlbumview->m_currentType);
+    w->m_pAlbumview->updateAlbumView(-1);
     w->m_pAlbumview->updateRightMyFavoriteView();
 //    w->m_pAlbumview->onTrashDeleteBtnClicked();
 
@@ -697,6 +693,7 @@ TEST(AlbumView, albumView_other1_test)
     w->m_pAlbumview->onImportFailedToView();
     w->m_pAlbumview->onWaitDailogTimeout();
 
+    w->m_pAlbumview->onBlockDeviceAdded("");
 
     QTest::qWait(500);
 }
@@ -743,7 +740,7 @@ TEST(AlbumViewList, albumViewList_other4_test)
         QMimeData mimedata;
         QList<QUrl> li;
         QString lastImportPath =  QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first();
-        lastImportPath += "/test/4l6r5y.png";
+        lastImportPath += "/AlbumtestResource/test/4l6r5y.png";
         li.append(QUrl(lastImportPath));
         mimedata.setUrls(li);
 
@@ -768,7 +765,7 @@ TEST(AlbumViewList, albumViewList_other5_test)
     QMimeData mimedata;
     QList<QUrl> li;
     QString lastImportPath =  QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first();
-    lastImportPath += "/test/4l6r5y.png";
+    lastImportPath += "/AlbumtestResource/test/4l6r5y.png";
     li.append(QUrl(lastImportPath));
     mimedata.setUrls(li);
 
@@ -784,37 +781,20 @@ TEST(AlbumViewList, albumViewList_other5_test)
 
     w->m_pAlbumview->m_pImportView->imageImported(true);
     w->m_pAlbumview->m_pImportView->imageImported(false);
-
-
-    MainWidget *mainWidget = w->m_commandLine->findChild<MainWidget *>("MainWidget");
-
-//    if (mainWidget) {
-//        NavigationWidget *nw = mainWidget->m_viewPanel->m_nav.widget();
-//        nw->setAlwaysHidden(false);
-//        nw->setAlwaysHidden(true);
-//        nw->transImagePos(QPoint(0, 0));
-
-//        mainWidget->m_viewPanel->m_ttbc->deleteImage();
-//    }
 }
 
 TEST(AlbumViewList, albumViewList_other6_test)
 {
     TEST_CASE_NAME("albumViewList_other6_test")
-
-    GraphicsMovieItem gmi_1(testPath_Pictures + "/2e5y8y.jpg", "");
-    GraphicsMovieItem gmi_2("", "");
-
-    ImageView *iv = new ImageView;
-    iv->setImage("");
-    iv->setImage(testPath_Pictures + "/2e5y8y.jpg");
-    iv->windowRelativeScale();
-    iv->imageRelativeScale();
-    iv->isWholeImageVisible();
-    iv->onThemeTypeChanged();
-
-    ImgInfoDialog iid("");
+    ImgInfoDialog iid("1", "2");
     iid.height();
+    iid.setImagePath(testPath_Pictures + "DetailInfo.jpg");
+    iid.show();
+
+    QTestEventList e;
+    e.addKeyClick(Qt::Key_Escape);
+    e.addDelay(200);
+    e.simulate(&iid);
 }
 
 TEST(AlbumViewList, deviceMount)
