@@ -30,7 +30,7 @@
 #include <gtest/gtest.h>
 #include <gmock/gmock-matchers.h>
 
-static QString testPath_test = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + QDir::separator() + "test";
-static QString testPath_Pictures = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
+static QString testPath_test = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + QDir::separator() + "AlbumtestResource/test";
+static QString testPath_Pictures = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + "/AlbumtestResource";
 
 #endif // QTESTDEFINE_H
