@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Delete</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Fullscreen</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Slide show</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Export</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Copy</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Favorite</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Rotate clockwise</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Rotate counterclockwise</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Set as wallpaper</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Display in file manager</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Photo info</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Video info</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Restore</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Or drag photos here</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 photo(s)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Import All</translation>
@@ -111,8 +162,8 @@
         <translation>Loading...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation>The files will be permanently deleted after the days shown on it</translation>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>The files will be permanently deleted after the days shown on them</translation>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>already exists. Do you want to replace it?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Screen Capture</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Camera</translation>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation>Draw</translation>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation>(copy)</translation>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Cancel</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Photo info</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Are you sure you want to delete this photo from the album?</translation>
+        <translation type="vanished">Are you sure you want to delete this photo from the album?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Are you sure you want to delete %n photos from albums?</numerusform><numerusform>Are you sure you want to delete %n photos from albums?</numerusform></translation>
+        <translation type="vanished"><numerusform>Are you sure you want to delete %n photos from albums?</numerusform><numerusform>Are you sure you want to delete %n photos from albums?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Are you sure you want to delete this video from the album?</translation>
+        <translation type="vanished">Are you sure you want to delete this video from the album?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Are you sure you want to delete %n videos from albums?</numerusform><numerusform>Are you sure you want to delete %n videos from albums?</numerusform></translation>
+        <translation type="vanished"><numerusform>Are you sure you want to delete %n videos from albums?</numerusform><numerusform>Are you sure you want to delete %n videos from albums?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Are you sure you want to delete %n items from albums?</numerusform><numerusform>Are you sure you want to delete %n items from albums?</numerusform></translation>
+        <translation type="vanished"><numerusform>Are you sure you want to delete %n items from albums?</numerusform><numerusform>Are you sure you want to delete %n items from albums?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation>Are you sure you want to permanently delete this file?</translation>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation>You cannot restore it any longer</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation>Are you sure you want to permanently delete %1 files?</translation>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation>You cannot restore them any longer</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation>Are you sure you want to delete this file locally?</translation>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation>You can restore it in the trash</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation>Are you sure you want to delete %1 files locally?</translation>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation>You can restore them in the trash</translation>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Details</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Photo info</translation>
+        <source>Image info</source>
+        <translation>Image info</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>All photos and videos</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>No photos or videos found</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>New album</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>You have no permission to view the file</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Settings</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Import photos</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Importing...</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>Photo/Video info</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Import photos and videos</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation>Import folders</translation>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation>Import interrupted</translation>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation>Cannot add this path, please try another one</translation>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation>The path already exists</translation>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation>Failed to restore %1 files: file name too long</translation>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>Tag</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Photo name</translation>
+        <source>Name</source>
+        <translation>Name</translation>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation><numerusform>%n photos found</numerusform><numerusform>%n photos found</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Pause</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Play</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Exit</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Previous</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Next</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>Exporting: %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Back</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Previous</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Next</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>1:1 Size</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Fit to window</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Rotate counterclockwise</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Rotate clockwise</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Delete</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Favorite</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Unfavorite</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>days</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>No image files found</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Photo not found</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Sampling</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Video name</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Date modified</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Date captured</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Add to album</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Slide show</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Exit fullscreen</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Fullscreen</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Copy</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Delete</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Show navigation window</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Hide navigation window</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Rotate clockwise</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Rotate counterclockwise</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Set as wallpaper</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Display in file manager</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Export</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Unfavorite</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Photo info</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Remove from album</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Favorite</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>New album</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Print</translation>
+        <source>Name</source>
+        <translation>Name</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
