@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="az" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Silmək</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Tam ekran</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Slayd-şou</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">İxrac</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Kopyalamaq</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Sevimlilər</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Saat əqrəbi istiqamətinə döndərmək</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Saat əqrəbinin əksinə döndərmək</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Divar kağızı kimi təyin etmək</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Fayl menecerində göstərmək</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Fotoşəkil məlumatları</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Video haqqında</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Bərpa etmək</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Və ya fotoşəkilləri buraya atın</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 fotoşəkil</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Hamısını idxal etmək</translation>
@@ -111,8 +162,8 @@
         <translation>Yüklənir...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation>Fayllar, onda göstərilən vaxt bitdikdən sonra birdəfəlik silinəcəkdir</translation>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>Fayllar, onlarda göstərilən vaxt bitdikdən sonra birdəfəlik silinəcəkdir</translation>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>artıq mövcuddur. Onu əvəzləmək istəyirsiniz?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>İmtina</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Fotoşəkil məlumatları</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Bu şəkili albomdan silmək istədiyinizə əminsiniz?</translation>
+        <translation type="vanished">Bu şəkili albomdan silmək istədiyinizə əminsiniz?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Albomlardan %n şəkli silmək istədiyinizə əminsiniz?</numerusform><numerusform>Albomdan %n şəkli silmək istədiyinizə əminsiniz?</numerusform></translation>
+        <translation type="vanished"><numerusform>Albomlardan %n şəkli silmək istədiyinizə əminsiniz?</numerusform><numerusform>Albomdan %n şəkli silmək istədiyinizə əminsiniz?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Albomdan bu videonu silmək istədiyinizə əminsiniz?</translation>
+        <translation type="vanished">Albomdan bu videonu silmək istədiyinizə əminsiniz?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Albomlardan %n videonu silmək istədiyinizə əminsiniz?</numerusform><numerusform>Albomlardan %n videonu silmək istədiyinizə əminsiniz?</numerusform></translation>
+        <translation type="vanished"><numerusform>Albomlardan %n videonu silmək istədiyinizə əminsiniz?</numerusform><numerusform>Albomlardan %n videonu silmək istədiyinizə əminsiniz?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Albomlardan %n elementi silmək istədiyinizə əminsiniz?</numerusform><numerusform>Albomlardan %n elementi silmək istədiyinizə əminsiniz?</numerusform></translation>
+        <translation type="vanished"><numerusform>Albomlardan %n elementi silmək istədiyinizə əminsiniz?</numerusform><numerusform>Albomlardan %n elementi silmək istədiyinizə əminsiniz?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Təfərrüatlar</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Fotoşəkil məlumatları</translation>
+        <source>Image info</source>
+        <translation>Şəkil məlumatı</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Bütün şəkillər və videolar</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Heç bir şəkil və ya video tapılmadı</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Yeni albom</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>Bu faylı baxmaq üçün icazəniz yoxdur</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Ayarlar</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Fotoşəkilləri idxal etmə</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>İdxal edilir...</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>Foto/video məlumatı</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Fotoları və videoları idxal edin</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>Yarlıq</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Fotoşəkilin adı</translation>
+        <source>Name</source>
+        <translation>Ad</translation>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation><numerusform>%n fotoşəkil tapıldı</numerusform><numerusform>%n fotoşəkil tapıldı</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Fasilə</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Oynatmaq</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Çıxış</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Əvvəlki</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Növbəti</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>İxrac olunur:%2</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Geriyə</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Əvvəlki</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Növbəti</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>1:1 Ölçü</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Pəncərə sığışdırmaq</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Saat əqrəbinin əksinə döndərmək</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Saat əqrəbi istiqamətinə döndərmək</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Silmək</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Sevimlilər</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Sevimlilərdən çıxartmaq</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>günlər</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Şəkil faylı tapılmadı</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Foto tapılmadı</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Sampling</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Video&apos;nun adı</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Dəyişdirilmə tarixi</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Çəkilmə tarixi</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Alboma əlavə etmək</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Slayd şou</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Tam ekrandan çıxış</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Tam ekran</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Kopyalamaq</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Silmək</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Naviqasiya pəncərəsini göstərmək</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Naviqasiya pəncərəsini gizlətmək</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Saat əqrəbi istiqamətinə döndərmək</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Saat əqrəbinin əksinə döndərmək</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Divar kağızı kimi təyin etmək</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Fayl menecerində göstərmək</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>İxrac</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Sevimlilərdən çıxartmaq</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Fotoşəkil məlumatları</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Albomdan silmək</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Sevimlilər</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Yeni albom</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Çap</translation>
+        <source>Name</source>
+        <translation>Ad</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
