@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">སུབ་པ།</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">ཡོལ་གང་།</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">སྒྲོན་བརྙན་སྟོན་པ།</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">ཕྱིར་འདྲེན།</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">པར་སློག</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">བསྡུ་ཉར།</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">གཡས་སྐོར་བརྒྱབ།</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">གཡོན་སྐོར་བརྒྱབ།</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">རྒྱབ་ཤོག་ཏུ་བྱེད་པ།</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">ཡིག་ཆ་དོ་དམ་བྱེད་ཆས་ཁྲོད་མངོན་སྟོན་བྱེད།</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">པར་གྱི་ཆ་འཕྲིན།</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">བརྙན་གྱི་ཆ་འཕྲིན།</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">སོར་ཆུད།</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>ཁྱོད་ཀྱིས་པར་འདིར་འཐེན་ཡང་ཆོག</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1པར(གང་རུང)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>ཚང་མ་ནང་འདྲེན་བྱེད།</translation>
@@ -111,7 +162,7 @@
         <translation>སྣོན་འཇུག་བྱེད་བཞིན་ཡོད་པས། ཏོག་ཙམ་སྒུག་རོགས།</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
+        <source>The files will be permanently deleted after the days shown on them</source>
         <translation>ཡིག་ཆ་མ་བསུབ་གོང་ཉིན་གྲངས་ལྷག་མ་མཐོང་ཐུབ། དེ་རྗེས་རྦད་དེ་བསུབ་པ་ཡིན།</translation>
     </message>
 </context>
@@ -201,6 +252,25 @@
         <translation>འདུག ཁྱོད་ཀྱི་བརྗེ་རྒྱུ་གཏན་ཁེལ་ལམ།</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>འདོར་བ།</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>པར་གྱི་ཆ་འཕྲིན།</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>ཁྱོད་ཀྱི་པར་ཁུག་ལས་པར་འདི་བསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</translation>
+        <translation type="vanished">ཁྱོད་ཀྱི་པར་ཁུག་ལས་པར་འདི་བསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>ཁྱོད་ཀྱི་པར་ཁུག་ལས་པར་འདི་%nབསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</numerusform></translation>
+        <translation type="vanished"><numerusform>ཁྱོད་ཀྱི་པར་ཁུག་ལས་པར་འདི་%nབསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>ཁྱོད་ཀྱི་པར་ཁུག་ལས་བརྙན་འདི་བསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</translation>
+        <translation type="vanished">ཁྱོད་ཀྱི་པར་ཁུག་ལས་བརྙན་འདི་བསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>ཁྱོད་ཀྱི་པར་ཁུག་ལས་བརྙན་འདི་%nབསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</numerusform></translation>
+        <translation type="vanished"><numerusform>ཁྱོད་ཀྱི་པར་ཁུག་ལས་བརྙན་འདི་%nབསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>ཁྱོད་ཀྱི་པར་ཁུག་ལས་རྣམ་གྲངས་འདི་%nབསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</numerusform></translation>
+        <translation type="vanished"><numerusform>ཁྱོད་ཀྱི་པར་ཁུག་ལས་རྣམ་གྲངས་འདི་%nབསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,7 +390,7 @@
         <translation>ཞིབ་ཕྲའི་ཆ་འཕྲིན།</translation>
     </message>
     <message>
-        <source>Photo info</source>
+        <source>Image info</source>
         <translation>པར་གྱི་ཆ་འཕྲིན།</translation>
     </message>
 </context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>པར་དང་བརྙན་ཆ་ཚང་།</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>པར་དང་བརྙན་གྱི་ཡིག་ཆ་མ་རྙེད།</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>པར་ཁུག་གསར་འཛུགས།</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>ཁྱེད་ལ་ཡིག་ཆ་འདི་ལྟ་དབང་མེད།</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>སྒྲིག་འགོད།</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>པར་ནང་དུ་འདྲེན་པ།</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>པར་ནང་དུ་འདྲེན་བཞིན་ཡོད་པས། ཏོག་ཙམ་སྒུག་རོགས།</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>པར་དང་བརྙན་གྱི་ཆ་འཕྲིན།</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>པར་དང་བརྙན་ནང་དུ་འདྲེན་པ།</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>མཚོན་རྟགས།</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>པར་མིང་།</translation>
+        <source>Name</source>
+        <translation>ཡིག་ཆའི་མིང་།</translation>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation><numerusform>ཁྱོན་པར་%nརྙེད་པ།</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>མཚམས་འཇོག་པ།</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>གཏོང་བ།</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>ཕྱིར་འཐོན།</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>པར་གོང་མ།</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>པར་འོག་མ།</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>འདོན་བཞིན་པ། %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>ཕྱིར་ལོག</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>པར་གོང་མ།</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>པར་འོག་མ།</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>1:1མཐོང་རིས།</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>སྒེའུ་ཁུང་དང་འཚམ་པ།</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>གཡོན་སྐོར་བརྒྱབ།</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>གཡས་སྐོར་བརྒྱབ།</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>སུབ་པ།</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>བསྡུ་ཉར།</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>བསྡུ་ཉར་བྱེད་པ་འདོར་བ།</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>ཉིན།</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>པར་རིས་ཡིག་ཆ་མ་རྙེད།</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>པར་གྱི་ཡིག་ཆ་མ་རྙེད།</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>དཔེ་དབྱིབས་བསྡུ་གྲངས།</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>བརྙན་མིང་།</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>ཚེས་གྲངས་བཟོ་བཅོས།</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>པར་རྒྱག་པའི་ཚེས་གྲངས།</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>པར་ཁུག་ནང་དུ་སྣོན་པ།</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>སྒྲོན་བརྙན་སྟོན་པ།</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>ཡོལ་གང་ལས་ཕྱིར་འཐེན།</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>ཡོལ་གང་།</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>པར་སློག</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>སུབ་པ།</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>ཕྱོགས་སྟོན་སྒེའུ་ཁུང་མངོན་སྟོན་བྱེད།</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>ཕྱོགས་སྟོན་སྒེའུ་ཁུང་ཡིབ་པ།</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>གཡས་སྐོར་བརྒྱབ།</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>གཡོན་སྐོར་བརྒྱབ།</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>རྒྱབ་ཤོག་ཏུ་བྱེད་པ།</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>ཡིག་ཆ་དོ་དམ་བྱེད་ཆས་ཁྲོད་མངོན་སྟོན་བྱེད།</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>ཕྱིར་འདྲེན།</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>བསྡུ་ཉར་བྱེད་པ་འདོར་བ།</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>པར་གྱི་ཆ་འཕྲིན།</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>པར་ཁུག་ལས་སྤོ་བ།</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>བསྡུ་ཉར།</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>པར་ཁུག་གསར་འཛུགས།</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>པར་འདེབས།</translation>
+        <source>Name</source>
+        <translation>ཡིག་ཆའི་མིང་།</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
