@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Elimina</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Pantalla completa</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Presentació</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Exporta-ho</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Copia</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Preferits</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Gira-la a la dreta</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Gira-la a l&apos;esquerra</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Estableix com a fons de pantalla</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Mostra-ho al gestor de fitxers.</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Informació de la fotografia</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Informació del vídeo</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Restaura</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>O arrossegueu fotos aquí.</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 foto/s</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Importa-ho tot</translation>
@@ -111,8 +162,8 @@
         <translation>Es carrega...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation>Els fitxers se suprimiran permanentment després dels dies que s&apos;hi mostren.</translation>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>Els fitxers s&apos;eliminaran permanentment després dels dies que s&apos;hi mostren.</translation>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>ja existeix. El voleu reemplaçar?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Cancel·la</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Informació de la fotografia</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Segur que voleu eliminar aquesta fotografia de l&apos;àlbum?</translation>
+        <translation type="vanished">Segur que voleu eliminar aquesta fotografia de l&apos;àlbum?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Segur que voleu eliminar %n fotografia dels àlbums?</numerusform><numerusform>Segur que voleu eliminar %n fotografies dels àlbums?</numerusform></translation>
+        <translation type="vanished"><numerusform>Segur que voleu eliminar %n fotografia dels àlbums?</numerusform><numerusform>Segur que voleu eliminar %n fotografies dels àlbums?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Segur que voleu eliminar aquest vídeo de l&apos;àlbum?</translation>
+        <translation type="vanished">Segur que voleu eliminar aquest vídeo de l&apos;àlbum?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Segur que voleu eliminar %n vídeo dels àlbums?</numerusform><numerusform>Segur que voleu eliminar %n vídeos dels àlbums?</numerusform></translation>
+        <translation type="vanished"><numerusform>Segur que voleu eliminar %n vídeo dels àlbums?</numerusform><numerusform>Segur que voleu eliminar %n vídeos dels àlbums?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Segur que voleu eliminar %n element dels àlbums?</numerusform><numerusform>Segur que voleu eliminar %n elements dels àlbums?</numerusform></translation>
+        <translation type="vanished"><numerusform>Segur que voleu eliminar %n element dels àlbums?</numerusform><numerusform>Segur que voleu eliminar %n elements dels àlbums?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Detalls</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Informació de la fotografia</translation>
+        <source>Image info</source>
+        <translation>Informació de la imatge</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Totes les fotografies i vídeos</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>No s&apos;ha trobat cap fotografia ni vídeo.</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Àlbum nou</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>No teniu permís per veure el fitxer.</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Paràmetres</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Importa fotografies</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>S&apos;importa...</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>Informació de la fotografia o vídeo</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Importa fotografies i vídeos</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>Etiqueta</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Nom de la fotografia</translation>
+        <source>Name</source>
+        <translation>Nom</translation>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation><numerusform>S&apos;ha trobat %n fotografia.</numerusform><numerusform>S&apos;han trobat %n fotografies.</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Pausa</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Reprodueix</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Surt</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Anterior</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Següent</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>S&apos;exporta: %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Enrere</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Anterior</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Següent</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Mida 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Ajusta-ho a la finestra</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Gira-la a l&apos;esquerra</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Gira-la a la dreta</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Elimina</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Afegeix als preferits</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Elimina dels preferits</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>dies</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>No s&apos;ha trobat la fotografia.</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Exemple</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Nom del vídeo</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Data de modificació</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Data de captura</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Afegeix a l&apos;àlbum</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Presentació</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Surt de la pantalla completa</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantalla completa</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Copia</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Elimina</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Mostra la finestra de navegació</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Amaga la finestra de navegació</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Gira-la a la dreta</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Gira-la a l&apos;esquerra</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Estableix com a fons de pantalla</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Mostra-ho al gestor de fitxers.</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Exporta-ho</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Elimina dels preferits</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Informació de la fotografia</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Elimina de l&apos;àlbum</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Preferit</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Àlbum nou</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Imprimeix</translation>
+        <source>Name</source>
+        <translation>Nom</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
