@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Smazat</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Na celou obrazovku</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Promítání</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Export</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Kopírovat</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Přidat do oblíbených</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Otočit doprava</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Otočit doleva</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Nastavit jako pozadí plochy</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Zobrazit ve správci souborů</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Informace o fotce</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Informace o videu</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Obnovit</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,13 +117,9 @@
         <source>Or drag photos here</source>
         <translation>Nebo fotky přetáhněte sem</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 fotek</translation>
-    </message>
     <message>
         <source>Import All</source>
-        <translation>Importovat vše</translation>
+        <translation>Naimportovat vše</translation>
     </message>
     <message>
         <source>Import to:</source>
@@ -108,11 +159,11 @@
     </message>
     <message>
         <source>Loading...</source>
-        <translation>Načítání</translation>
+        <translation>Načítání…</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation>Po uplynutí počtu dnů na tomto zobrazených budou soubory nadobro smazány</translation>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>Po uplynutí na nich zobrazeného počtu dnů budou soubory nadobro smazány</translation>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>už existuje. Má být nahrazeno?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Storno</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Informace o fotce</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Opravdu chcete tuto fotku vymazat z alba?</translation>
+        <translation type="vanished">Opravdu chcete tuto fotku vymazat z alba?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Opravdu chcete %n fotku vymazat z alb?</numerusform><numerusform>Opravdu chcete %n fotky vymazat z alb?</numerusform><numerusform>Opravdu chcete %n fotek vymazat z alb?</numerusform><numerusform>Opravdu chcete %n fotky vymazat z alb?</numerusform></translation>
+        <translation type="vanished"><numerusform>Opravdu chcete %n fotku vymazat z alb?</numerusform><numerusform>Opravdu chcete %n fotky vymazat z alb?</numerusform><numerusform>Opravdu chcete %n fotek vymazat z alb?</numerusform><numerusform>Opravdu chcete %n fotky vymazat z alb?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Opravdu chcete toto video vymazat z alba?</translation>
+        <translation type="vanished">Opravdu chcete toto video vymazat z alba?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Opravdu chcete %n video vymazat z alb?</numerusform><numerusform>Opravdu chcete %n videa vymazat z alb?</numerusform><numerusform>Opravdu chcete %n videí vymazat z alb?</numerusform><numerusform>Opravdu chcete %n videa vymazat z alb?</numerusform></translation>
+        <translation type="vanished"><numerusform>Opravdu chcete %n video vymazat z alb?</numerusform><numerusform>Opravdu chcete %n videa vymazat z alb?</numerusform><numerusform>Opravdu chcete %n videí vymazat z alb?</numerusform><numerusform>Opravdu chcete %n videa vymazat z alb?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Opravdu chcete %n položku vymazat z alb?</numerusform><numerusform>Opravdu chcete %n položky vymazat z alb?</numerusform><numerusform>Opravdu chcete %n položek vymazat z alb?</numerusform><numerusform>Opravdu chcete %n položky vymazat z alb?</numerusform></translation>
+        <translation type="vanished"><numerusform>Opravdu chcete %n položku vymazat z alb?</numerusform><numerusform>Opravdu chcete %n položky vymazat z alb?</numerusform><numerusform>Opravdu chcete %n položek vymazat z alb?</numerusform><numerusform>Opravdu chcete %n položky vymazat z alb?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Podrobnosti</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Informace o fotce</translation>
+        <source>Image info</source>
+        <translation>Informace o obrázku</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Všechny fotky a videa</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Nenalezeny žádné fotky či videa</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Nové album</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>Nemáte oprávnění zobrazit obsah souboru</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -414,7 +506,7 @@
     </message>
     <message>
         <source>Copy</source>
-        <translation>Kopírovat</translation>
+        <translation>Zkopírovat</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Nastavení</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Importovat fotky</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Importování…</translation>
@@ -546,11 +634,11 @@
     </message>
     <message>
         <source>Export photos</source>
-        <translation type="unfinished"/>
+        <translation>Exportovat fotky</translation>
     </message>
     <message>
         <source>Import photos/videos</source>
-        <translation type="unfinished"/>
+        <translation>Importovat fotky/videa</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -558,6 +646,30 @@
     </message>
     <message>
         <source>Photo/Video info</source>
+        <translation>Informace o fotce/videu</translation>
+    </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Nahrát fotky a videa</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -644,8 +756,8 @@
         <translation>Štítek</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Název fotky</translation>
+        <source>Name</source>
+        <translation>Název</translation>
     </message>
 </context>
 <context>
@@ -778,7 +890,7 @@
     </message>
     <message>
         <source>%1 items imported, %2 items exist already</source>
-        <translation>Naimportování %1 položek, %2 položek už existuje</translation>
+        <translation>Naimportováno %1 položek, %2 položek už existuje</translation>
     </message>
 </context>
 <context>
@@ -813,30 +925,7 @@
     </message>
     <message numerus="yes">
         <source>%n photos found</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-</context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Pozastavit</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Přehrát</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Ukončit</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Předchozí</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Další</translation>
+        <translation><numerusform>Nalezena %1 fotka</numerusform><numerusform>Nalezeno %1 fotek</numerusform><numerusform>Nalezeno %1 fotek</numerusform><numerusform>Nalezeno %1 fotek</numerusform></translation>
     </message>
 </context>
 <context>
@@ -863,50 +952,7 @@
     </message>
     <message>
         <source>Exporting: %1</source>
-        <translation>Exportuje se: %1</translation>
-    </message>
-</context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Zpět</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Předchozí</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Další</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Velikost 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Přizpůsobit oknu</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Otočit doleva</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Otočit doprava</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Smazat</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Přidat do oblíbených</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Odebrat z oblíbených</translation>
+        <translation>Ukládá se: %1</translation>
     </message>
 </context>
 <context>
@@ -992,17 +1038,6 @@
         <translation>dní</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Nenalezeny žádné soubory s obrázky</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Fotka nenalezena</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Frekvence vzorkování</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Název videa</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Změněno</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Datum pořízení</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Přidat do alba</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Promítání</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Opustit celou obrazovku</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Celá obrazovka</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Kopírovat</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Smazat</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Zobrazit okno navigace</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Skrýt navigační okno</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Otočit doprava</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Otočit doleva</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Nastavit jako pozadí plochy</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Zobrazit ve správci souborů</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Export</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Odebrat z oblíbených</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Informace o fotce</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Odstranit z alba</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Přidat do oblíbených</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Nové album</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Tisk</translation>
+        <source>Name</source>
+        <translation>Název</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
