@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Borrar</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Pantalla completa</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Presentación</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Exportar</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Copiar</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Favorito</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Girar hacia la derecha</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Girar hacia la izquierda</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Establecer como fondo de pantalla</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Mostrar en el administrador de archivos</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Inf. de la foto</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Inf. de video</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Restaurar</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>O arrastre fotos aquí</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 foto(s)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Importar todo</translation>
@@ -108,11 +159,11 @@
     </message>
     <message>
         <source>Loading...</source>
-        <translation type="unfinished"/>
+        <translation>Cargando...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation type="unfinished"/>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>Los archivos se borrarán permanentemente después de los días indicados en ellos</translation>
     </message>
 </context>
 <context>
@@ -154,7 +205,7 @@
     </message>
     <message>
         <source>Videos</source>
-        <translation>Vídeos</translation>
+        <translation>Videos</translation>
     </message>
     <message>
         <source>Music</source>
@@ -201,6 +252,25 @@
         <translation>ya existe. ¿Desea reemplazarlo?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Cancelar</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Información de la foto</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>¿Está seguro que desea borrar esta foto del álbum?</translation>
+        <translation type="vanished">¿Está seguro que desea borrar esta foto del álbum?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>¿Estás seguro de que quieres eliminar %n foto de los álbumes?</numerusform><numerusform>¿Estás seguro de que quieres eliminar %n fotos de los álbumes?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation type="unfinished"/>
+        <translation type="vanished">¿Estás seguro de que quieres eliminar este video del álbum?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>¿Estás seguro de que quieres eliminar %n vídeo de los álbumes?</numerusform><numerusform>¿Estás seguro de que quieres eliminar %n videos de los álbumes?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>¿Estás seguro de que quieres eliminar %n elemento de los álbumes?</numerusform><numerusform>¿Estás seguro de que quieres eliminar %n elementos de los álbumes?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Detalles</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Información de la foto</translation>
+        <source>Image info</source>
+        <translation>Inf. de la imagen</translation>
     </message>
 </context>
 <context>
@@ -330,7 +425,7 @@
     <name>ImportView</name>
     <message>
         <source>Import Photos and Videos</source>
-        <translation>Importar fotos y vídeos</translation>
+        <translation>Importar fotos y videos</translation>
     </message>
     <message>
         <source>Or drag them here</source>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Todas las fotos y videos</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>No fotos o videos encontrados</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,18 +475,11 @@
         <translation>Nuevo álbum</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
         <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
-        <translation type="unfinished"/>
+        <translation>Album es un gestor de moda para ver y organizar fotos y videos.</translation>
     </message>
 </context>
 <context>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Ajustes</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Importar fotos</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Importando…</translation>
@@ -538,7 +626,7 @@
     </message>
     <message>
         <source>Import Photos and Videos</source>
-        <translation>Importar fotos y vídeos</translation>
+        <translation>Importar fotos y videos</translation>
     </message>
     <message>
         <source>No photos or videos found</source>
@@ -550,7 +638,7 @@
     </message>
     <message>
         <source>Import photos/videos</source>
-        <translation type="unfinished"/>
+        <translation>Importar fotos/videos</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -558,6 +646,30 @@
     </message>
     <message>
         <source>Photo/Video info</source>
+        <translation>Información de foto/video</translation>
+    </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Importar fotos y videos</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -644,8 +756,8 @@
         <translation>Etiqueta</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Nombre de foto</translation>
+        <source>Name</source>
+        <translation>Nombre</translation>
     </message>
 </context>
 <context>
@@ -718,7 +830,7 @@
     </message>
     <message>
         <source>Videos</source>
-        <translation>Vídeos</translation>
+        <translation>Videos</translation>
     </message>
     <message>
         <source>No results</source>
@@ -813,30 +925,7 @@
     </message>
     <message numerus="yes">
         <source>%n photos found</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-</context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Pausa</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Reproducir</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Salir</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Anterior</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Siguiente</translation>
+        <translation><numerusform>%n foto encontrada</numerusform><numerusform>%n fotos encontradas</numerusform></translation>
     </message>
 </context>
 <context>
@@ -859,54 +948,11 @@
     </message>
     <message>
         <source>Importing: %1</source>
-        <translation type="unfinished"/>
+        <translation>Importando: %1</translation>
     </message>
     <message>
         <source>Exporting: %1</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Atrás</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Anterior</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Siguiente</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Tamaño 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Ajustar a la ventana</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Girar hacia la izquierda</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Girar hacia la derecha</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Borrar</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Añadir a favoritos</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Quitar de favoritos</translation>
+        <translation>Exportando: %1</translation>
     </message>
 </context>
 <context>
@@ -985,24 +1031,13 @@
     </message>
     <message>
         <source>Video info</source>
-        <translation type="unfinished"/>
+        <translation>Inf de video</translation>
     </message>
     <message>
         <source>days</source>
         <translation>días</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>No se encontraron archivos de imagen</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>No se encontró la foto</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1034,59 +1069,55 @@
     </message>
     <message>
         <source>Codec info</source>
-        <translation type="unfinished"/>
+        <translation>Inf del códec</translation>
     </message>
     <message>
         <source>Audio info</source>
-        <translation type="unfinished"/>
+        <translation>Inf del audio</translation>
     </message>
     <message>
         <source>Video CodecID</source>
-        <translation type="unfinished"/>
+        <translation>CodecID de video</translation>
     </message>
     <message>
         <source>Video CodeRate</source>
-        <translation type="unfinished"/>
+        <translation>CodeRate de video</translation>
     </message>
     <message>
         <source>FPS</source>
-        <translation type="unfinished"/>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>Proportion</source>
-        <translation type="unfinished"/>
+        <translation>Proporción</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished"/>
+        <translation>Resolución</translation>
     </message>
     <message>
         <source>Audio CodecID</source>
-        <translation type="unfinished"/>
+        <translation>CodecID de Audio</translation>
     </message>
     <message>
         <source>Audio CodeRate</source>
-        <translation type="unfinished"/>
+        <translation>CodeRate de audio</translation>
     </message>
     <message>
         <source>Audio digit</source>
-        <translation type="unfinished"/>
+        <translation>Dígito de audio</translation>
     </message>
     <message>
         <source>Channels</source>
-        <translation type="unfinished"/>
+        <translation>Canales</translation>
     </message>
     <message>
         <source>Channel</source>
-        <translation type="unfinished"/>
+        <translation>Canal</translation>
     </message>
     <message>
         <source>Sampling</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Video name</source>
-        <translation type="unfinished"/>
+        <translation>Muestreo</translation>
     </message>
     <message>
         <source>Date modified</source>
@@ -1102,98 +1133,23 @@
     </message>
     <message>
         <source>Duration</source>
-        <translation type="unfinished"/>
+        <translation>Duración</translation>
     </message>
     <message>
         <source>Path</source>
-        <translation type="unfinished"/>
+        <translation>Ruta</translation>
     </message>
     <message>
         <source>Video info</source>
-        <translation type="unfinished"/>
+        <translation>Inf de video</translation>
     </message>
     <message>
         <source>Date captured</source>
         <translation>Fecha de captura</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Añadir al álbum</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Presentación</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Salir de pantalla completa</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantalla completa</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Copiar</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Borrar</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Mostrar panel de navegación</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Ocultar panel de navegación</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Girar hacia la derecha</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Girar hacia la izquierda</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Establecer como fondo de pantalla</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Mostrar en el administrador de archivos</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Exportar</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Quitar de favoritos</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Información de la foto</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Quitar del álbum</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Favorito</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Nuevo álbum</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Imprimir</translation>
+        <source>Name</source>
+        <translation>Nombre</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
