@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Poista</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Koko näyttö</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Diaesitys</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Vie</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Kopioi</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Suosikki</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Käännä myötäpäivään</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Käännä vastapäivään</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Aseta taustakuvaksi</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Näytä tiedostohallinnassa</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Kuvan tiedot</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Videon tiedot</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Palauta</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -7,7 +62,7 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Peru</translation>
+        <translation>Peruuta</translation>
     </message>
     <message>
         <source>Create</source>
@@ -22,7 +77,7 @@
     <name>AlbumDeleteDialog</name>
     <message>
         <source>Cancel</source>
-        <translation>Peru</translation>
+        <translation>Peruuta</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>tai vedä valokuvia tähän</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 kuvaa</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Tuo kaikki</translation>
@@ -100,7 +151,7 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Peru</translation>
+        <translation>Peruuta</translation>
     </message>
     <message>
         <source>Ignore</source>
@@ -111,8 +162,8 @@
         <translation>Ladataan...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation>Tiedostot poistetaan pysyvästi siinä näytetyn päivän jälkeen </translation>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>Tiedostot poistetaan pysyvästi niille annetun päivän jälkeen</translation>
     </message>
 </context>
 <context>
@@ -126,7 +177,7 @@
     <name>CExportImageDialog</name>
     <message>
         <source>Cancel</source>
-        <translation>Peru</translation>
+        <translation>Peruuta</translation>
     </message>
     <message>
         <source>Replace</source>
@@ -201,6 +252,25 @@
         <translation>on jo olemassa, haluatko korvata?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -232,14 +302,7 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Peru</translation>
-    </message>
-</context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Kuvan tiedot</translation>
+        <translation>Peruuta</translation>
     </message>
 </context>
 <context>
@@ -257,7 +320,7 @@
     <name>ImgDeleteDialog</name>
     <message>
         <source>Cancel</source>
-        <translation>Peru</translation>
+        <translation>Peruuta</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Haluatko varmasti poistaa tämän kuvan albumista?</translation>
+        <translation type="vanished">Haluatko varmasti poistaa tämän kuvan albumista?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Haluatko varmasti poistaa %n valokuvaa albumista?</numerusform><numerusform>Haluatko varmasti poistaa %n valokuvaa albumista?</numerusform></translation>
+        <translation type="vanished"><numerusform>Haluatko varmasti poistaa %n valokuvaa albumista?</numerusform><numerusform>Haluatko varmasti poistaa %n valokuvaa albumista?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Haluatko varmasti poistaa tämän videon albumista?</translation>
+        <translation type="vanished">Haluatko varmasti poistaa tämän videon albumista?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Haluatko varmasti poistaa %n videota albumista?</numerusform><numerusform>Haluatko varmasti poistaa %n videota albumista?</numerusform></translation>
+        <translation type="vanished"><numerusform>Haluatko varmasti poistaa %n videota albumista?</numerusform><numerusform>Haluatko varmasti poistaa %n videota albumista?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Haluatko varmasti poistaa %n kohdetta albumista?</numerusform><numerusform>Haluatko varmasti poistaa %n kohdetta albumista?</numerusform></translation>
+        <translation type="vanished"><numerusform>Haluatko varmasti poistaa %n kohdetta albumista?</numerusform><numerusform>Haluatko varmasti poistaa %n kohdetta albumista?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,7 +390,7 @@
         <translation>Yksityiskohdat</translation>
     </message>
     <message>
-        <source>Photo info</source>
+        <source>Image info</source>
         <translation>Kuvan tiedot</translation>
     </message>
 </context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Kaikki kuvat ja videot</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Kuvia tai videoita ei löytynyt</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Uusi albumi</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>Sinulla ei ole oikeuksia katsoa tiedostoa</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Tuo kuvat</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Tuodaan...</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>Valokuva-/videotiedot</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Tuo valokuvia ja videoita</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,7 +756,7 @@
         <translation>Tunniste</translation>
     </message>
     <message>
-        <source>Photo name</source>
+        <source>Name</source>
         <translation>Nimi</translation>
     </message>
 </context>
@@ -698,7 +810,7 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Peru</translation>
+        <translation>Peruuta</translation>
     </message>
     <message>
         <source>Restore</source>
@@ -813,30 +925,7 @@
     </message>
     <message numerus="yes">
         <source>%n photos found</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-</context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Tauko</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Toista</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Poistu</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Edellinen</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Seuraava</translation>
+        <translation><numerusform>%n kuvaa löydetty</numerusform><numerusform>%n kuvaa löydetty</numerusform></translation>
     </message>
 </context>
 <context>
@@ -866,49 +955,6 @@
         <translation>Viedään: %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Takaisin</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Edellinen</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Seuraava</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Koko 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Sovita ikkunaan</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Käännä vastapäivään</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Käännä myötäpäivään</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Poista</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Suosikki</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Inhokki</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>päivää</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Kuvatiedostoja ei löytynyt</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Kuvaa ei löytynyt</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Näytteenotto</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Videon nimi</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Muokattu</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Kuvauspäivä</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Lisää albumiin</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Diaesitys</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Poistu koko näytöstä</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Koko näyttö</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Kopioi</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Poista</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Näytä navigointi-ikkuna</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Piilota navigointi-ikkuna</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Käännä myötäpäivään</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Käännä vastapäivään</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Aseta taustakuvaksi</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Näytä tiedostohallinnassa</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Vie</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Inhokki</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Kuvan tiedot</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Poista albumista</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Suosikki</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Uusi albumi</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Tulosta</translation>
+        <source>Name</source>
+        <translation>Nimi</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
