@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Törlés</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Teljes képernyő</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Diavetítés</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Exportálás</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Másolás</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Kedvenc</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Forgatás az óramutató járásával megegyezően</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Forgatás az óramutató járásával ellentétes irányba</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Beállítás háttérképként</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Megjelenítés a fájlkezelőben</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Kép tulajdonságai</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Videó tulajdonságai</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Helyreállítás</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Vagy húzza a képeket ide</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 kép(ek)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Összes importálása</translation>
@@ -111,7 +162,7 @@
         <translation>Betöltés...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
+        <source>The files will be permanently deleted after the days shown on them</source>
         <translation>A fájlok véglegesen törlődnek a megjelenített napok után</translation>
     </message>
 </context>
@@ -201,6 +252,25 @@
         <translation>Már létezik. Szeretné felülírni?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Mégsem</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Kép tulajdonságai</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Biztos, hogy törölni szeretné ezt a képet az albumból?</translation>
+        <translation type="vanished">Biztos, hogy törölni szeretné ezt a képet az albumból?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Biztos, hogy törölni szeretne %n képet az albumból?</numerusform><numerusform>Biztos, hogy törölni szeretne %n képet az albumból?</numerusform></translation>
+        <translation type="vanished"><numerusform>Biztos, hogy törölni szeretne %n képet az albumból?</numerusform><numerusform>Biztos, hogy törölni szeretne %n képet az albumból?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Biztos, hogy törölni szeretné ezt a videót az albumból?</translation>
+        <translation type="vanished">Biztos, hogy törölni szeretné ezt a videót az albumból?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Biztos, hogy törölni szeretne %n videót az albumból?</numerusform><numerusform>Biztos, hogy törölni szeretne %n videót az albumból?</numerusform></translation>
+        <translation type="vanished"><numerusform>Biztos, hogy törölni szeretne %n videót az albumból?</numerusform><numerusform>Biztos, hogy törölni szeretne %n videót az albumból?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Biztos, hogy törölni szeretne %n elemet az albumból?</numerusform><numerusform>Biztos, hogy törölni szeretne %n elemet az albumból?</numerusform></translation>
+        <translation type="vanished"><numerusform>Biztos, hogy törölni szeretne %n elemet az albumból?</numerusform><numerusform>Biztos, hogy törölni szeretne %n elemet az albumból?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Részletek</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Kép tulajdonságai</translation>
+        <source>Image info</source>
+        <translation>Kép információk</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Összes Kép és Videó</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Nem található kép vagy videó</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Új album</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>Nincs jogosultsága a fájl megtekintésére</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Beállítások</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Képek importálása</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Importálás...</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>Kép/Videó tulajdonságai</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Képek és Videók importálása</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>Címke</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Kép neve</translation>
+        <source>Name</source>
+        <translation>Név</translation>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation><numerusform>%n képe(ke)t sikerült találni</numerusform><numerusform>%n képe(ke)t sikerült találni</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Szüneteltetés</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Lejátszás</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Kilépés</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Előző</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Következő</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>Exportálás: %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Vissza</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Előző</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Következő</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>1:1 méret</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Igazítás az ablakhoz</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Forgatás az óramutató járásával megegyezően</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Törlés</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Kedvenc</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Eltávolítás a kedvencekből</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>napok</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Nem találhatóak képfájlok</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Kép nem található</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Mintavétel</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Videó neve</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Módosítás ideje</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Rögzítés dátuma</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Hozzáadás az albumhoz</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Diavetítés</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Kilépés a teljes képernyős módból</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Teljes képernyő</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Másolás</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Törlés</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Navigációs ablak megjelenítése</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Navigációs ablak elrejtése</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Forgatás az óramutató járásával megegyezően</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Beállítás háttérképként</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Megjelenítés a fájlkezelőben</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Exportálás</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Eltávolítás a kedvencekből</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Kép tulajdonságai</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Eltávolítás az albumból</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Kedvenc</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Új album</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Nyomtatás</translation>
+        <source>Name</source>
+        <translation>Név</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
