@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Verwijderen</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Beeldvullende modus</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Diavoorstelling</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Exporteren</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Kopiëren</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Toev. aan favorieten</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Naar rechts draaien</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Naar links draaien</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Instellen als achtergrond</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Tonen in bestandsbeheerder</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Foto-informatie</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Video-informatie</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Herstellen</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>of sleep foto&apos;s hierheen</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 foto(&apos;s)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Alles importeren</translation>
@@ -111,7 +162,7 @@
         <translation>Bezig met laden…</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
+        <source>The files will be permanently deleted after the days shown on them</source>
         <translation>De bestanden worden verwijderd na het vermelde aantal dagen</translation>
     </message>
 </context>
@@ -201,6 +252,25 @@
         <translation>bestaat al. Wil je deze vervangen?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Annuleren</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Foto-informatie</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Weet je zeker dat je deze foto wilt verwijderen uit het album?</translation>
+        <translation type="vanished">Weet je zeker dat je deze foto wilt verwijderen uit het album?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Weet je zeker dat je %1 foto wilt verwijderen uit albums?</numerusform><numerusform>Weet je zeker dat je %n foto&apos;s wilt verwijderen uit albums?</numerusform></translation>
+        <translation type="vanished"><numerusform>Weet je zeker dat je %1 foto wilt verwijderen uit albums?</numerusform><numerusform>Weet je zeker dat je %n foto&apos;s wilt verwijderen uit albums?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Weet je zeker dat je deze video wilt verwijderen uit het album?</translation>
+        <translation type="vanished">Weet je zeker dat je deze video wilt verwijderen uit het album?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Weet je zeker dat je %n video wilt verwijderen uit albums?</numerusform><numerusform>Weet je zeker dat je %n video&apos;s wilt verwijderen uit albums?</numerusform></translation>
+        <translation type="vanished"><numerusform>Weet je zeker dat je %n video wilt verwijderen uit albums?</numerusform><numerusform>Weet je zeker dat je %n video&apos;s wilt verwijderen uit albums?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Weet je zeker dat je %n item wilt verwijderen uit albums?</numerusform><numerusform>Weet je zeker dat je %n items wilt verwijderen uit albums?</numerusform></translation>
+        <translation type="vanished"><numerusform>Weet je zeker dat je %n item wilt verwijderen uit albums?</numerusform><numerusform>Weet je zeker dat je %n items wilt verwijderen uit albums?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Details</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Foto-informatie</translation>
+        <source>Image info</source>
+        <translation>Afbeeldingsinformatie</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Alle foto&apos;s en video&apos;s</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Geen foto&apos;s of video&apos;s aangetroffen</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Nieuw album</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>Je bent niet bevoegd om dit bestand te bekijken</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Instellingen</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Foto&apos;s importeren</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Bezig met importeren…</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>Foto-/Video-informatie</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Importeer foto&apos;s en video&apos;s</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,7 +756,7 @@
         <translation>Label</translation>
     </message>
     <message>
-        <source>Photo name</source>
+        <source>Name</source>
         <translation>Naam</translation>
     </message>
 </context>
@@ -816,29 +928,6 @@
         <translation><numerusform>%n foto gevonden</numerusform><numerusform>%n foto&apos;s gevonden</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Pauzeren</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Afspelen</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Afsluiten</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Vorige</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Volgende</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>Bezig met exporteren van %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Terug</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Vorige</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Volgende</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Aanpassen aan venster</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Naar links draaien</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Naar rechts draaien</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Verwijderen</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Toev. aan favorieten</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Verw. uit favorieten</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>dagen</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Geen afbeeldingsbestanden aangetroffen</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Foto niet aangetroffen</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Sampling</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Videonaam</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Aangepast op</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Genomen op</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Toevoegen aan album</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Diavoorstelling</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Beeldvullende modus verlaten</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Beeldvullende modus</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Kopiëren</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Verwijderen</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Navigatievenster tonen</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Navigatievenster verbergen</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Naar rechts draaien</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Naar links draaien</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Instellen als achtergrond</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Tonen in bestandsbeheerder</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Exporteren</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Verw. uit favorieten</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Foto-informatie</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Verwijderen uit album</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Toev. aan favorieten</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Nieuw album</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Afdrukken</translation>
+        <source>Name</source>
+        <translation>Naam</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
