@@ -1,9 +1,64 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Usuń</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Pełny ekran</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Pokaz slajdów</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Eksportuj</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Kopiuj</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Ulubione</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Obróć w prawo</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Obróć w lewo</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Ustaw jako tapetę pulpitu</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Wyświetl w menedżerze plików</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Informacje o zdjęciu</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Informacje o filmie</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Przywróć</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
         <source>Unnamed</source>
-        <translation>Nienazwane</translation>
+        <translation>Bez nazwy</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -45,7 +100,7 @@
     </message>
     <message>
         <source>Import</source>
-        <translation>Importuj</translation>
+        <translation>Import</translation>
     </message>
 </context>
 <context>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Lub przeciągnij tutaj zdjęcia</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 zdjęcie(a)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Importuj wszystkie</translation>
@@ -76,7 +127,7 @@
     </message>
     <message>
         <source>Import</source>
-        <translation>Importuj</translation>
+        <translation>Import</translation>
     </message>
     <message>
         <source>System Disk</source>
@@ -108,11 +159,11 @@
     </message>
     <message>
         <source>Loading...</source>
-        <translation type="unfinished"/>
+        <translation>Ładowanie...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation type="unfinished"/>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>Pliki zostaną permanentnie usunięte po dniach, które na nich widnieją </translation>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>już istnieje. Czy chcesz go zastąpić?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -213,7 +283,7 @@
     </message>
     <message>
         <source>%1 Encrypted</source>
-        <translation>Zaszyfrowany %1</translation>
+        <translation>%1 zaszyfrowany</translation>
     </message>
     <message>
         <source>%1 Volume</source>
@@ -235,13 +305,6 @@
         <translation>Anuluj</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Informacje o zdjęciu</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Czy jesteś pewny, że chcesz usunąć to zdjęcie z albumu?</translation>
+        <translation type="vanished">Czy jesteś pewny, że chcesz usunąć to zdjęcie z albumu?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>Czy na pewno chcesz usunąć %n zdjęcie z albumów? </numerusform><numerusform>Czy na pewno chcesz usunąć %n zdjęcia z albumów? </numerusform><numerusform>Czy na pewno chcesz usunąć %n zdjęć z albumów? </numerusform><numerusform>Czy na pewno chcesz usunąć %n zdjęć z albumów? </numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Czy na pewno chcesz usunąć ten film z albumu?</translation>
+        <translation type="vanished">Czy na pewno chcesz usunąć ten film z albumu?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>Czy na pewno chcesz usunąć %n film z albumów? </numerusform><numerusform>Czy na pewno chcesz usunąć %n filmy z albumów? </numerusform><numerusform>Czy na pewno chcesz usunąć %n filmów z albumów? </numerusform><numerusform>Czy na pewno chcesz usunąć %n filmów z albumów? </numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>Czy na pewno chcesz usunąć %n przedmiot z albumów?</numerusform><numerusform>Czy na pewno chcesz usunąć %n przedmioty z albumów?</numerusform><numerusform>Czy na pewno chcesz usunąć %n przedmiotów z albumów?</numerusform><numerusform>Czy na pewno chcesz usunąć %n przedmiotów z albumów?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,7 +390,7 @@
         <translation>Szczegóły</translation>
     </message>
     <message>
-        <source>Photo info</source>
+        <source>Image info</source>
         <translation>Informacje o zdjęciu</translation>
     </message>
 </context>
@@ -303,7 +398,7 @@
     <name>ImportTimeLineView</name>
     <message>
         <source>Import</source>
-        <translation>Importuj</translation>
+        <translation>Import</translation>
     </message>
     <message>
         <source>1 photo</source>
@@ -315,15 +410,15 @@
     </message>
     <message numerus="yes">
         <source>%n photos</source>
-        <translation><numerusform>%n zdjęcie</numerusform><numerusform>%n zdjęć</numerusform><numerusform>%n zdjęć</numerusform><numerusform>%n zdjęć</numerusform></translation>
+        <translation><numerusform>%n zdjęcie</numerusform><numerusform>%n zdjęcia</numerusform><numerusform>%n zdjęć</numerusform><numerusform>%n zdjęć</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n videos</source>
-        <translation><numerusform>%n film</numerusform><numerusform>%n filmów</numerusform><numerusform>%n filmów</numerusform><numerusform>%n filmów</numerusform></translation>
+        <translation><numerusform>%n film</numerusform><numerusform>%n filmy</numerusform><numerusform>%n filmów</numerusform><numerusform>%n filmów</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n items</source>
-        <translation><numerusform>%n przedmiot</numerusform><numerusform>%n przedmiotów</numerusform><numerusform>%n przedmiotów</numerusform><numerusform>%n przedmiotów</numerusform></translation>
+        <translation><numerusform>%n przedmiot</numerusform><numerusform>%n przedmioty</numerusform><numerusform>%n przedmiotów</numerusform><numerusform>%n przedmiotów</numerusform></translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Wszystkie zdjęcia i filmy</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Nie znaleziono zdjęć i filmów</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Nowy album</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -422,11 +514,11 @@
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation>Obróć zgodnie ze wskazówkami zegara</translation>
+        <translation>Obróć w prawo</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation>Obróć przeciwnie do wskazówek zegara</translation>
+        <translation>Obróć w lewo</translation>
     </message>
     <message>
         <source>Previous</source>
@@ -458,23 +550,23 @@
     </message>
     <message>
         <source>Import successful</source>
-        <translation>Import przeprowadzono pomyślnie</translation>
+        <translation>Import zakończony sukcesem</translation>
     </message>
     <message>
         <source>Import failed</source>
-        <translation>Nieudane importowanie</translation>
+        <translation>Eksport zakończony niepowodzeniem</translation>
     </message>
     <message>
         <source>Export failed</source>
-        <translation>Nieudane eksportowanie</translation>
+        <translation>Eksport zakończony niepowodzeniem</translation>
     </message>
     <message>
         <source>Export successful</source>
-        <translation>Eksport przeprowadzono pomyślnie</translation>
+        <translation>Eksport zakończony sukcesem</translation>
     </message>
     <message>
         <source>All Photos</source>
-        <translation>Wszystkie zdjęcia</translation>
+        <translation>Zdjęcia</translation>
     </message>
     <message>
         <source>Timelines</source>
@@ -514,20 +606,16 @@
     </message>
     <message>
         <source>Page up</source>
-        <translation>Strona w górę</translation>
+        <translation>Przewiń stronę w górę</translation>
     </message>
     <message>
         <source>Page down</source>
-        <translation>Strona w dół</translation>
+        <translation>Przewiń stronę w dół</translation>
     </message>
     <message>
         <source>Settings</source>
         <translation>Ustawienia</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Importuj zdjęcia</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Importowanie...</translation>
@@ -546,11 +634,11 @@
     </message>
     <message>
         <source>Export photos</source>
-        <translation type="unfinished"/>
+        <translation>Eksportuj zdjęcia</translation>
     </message>
     <message>
         <source>Import photos/videos</source>
-        <translation type="unfinished"/>
+        <translation>Importuj zdjęcia/wideo</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -558,6 +646,30 @@
     </message>
     <message>
         <source>Photo/Video info</source>
+        <translation>Zdjęcia/Wideo info</translation>
+    </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Importuj zdjęcia i filmy</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -644,8 +756,8 @@
         <translation>Znacznik</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Nazwa zdjęcia</translation>
+        <source>Name</source>
+        <translation>Nazwa</translation>
     </message>
 </context>
 <context>
@@ -730,11 +842,11 @@
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation>Obróć przeciwnie do wskazówek zegara</translation>
+        <translation>Obróć w lewo</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation>Obróć zgodnie ze wskazówkami zegara</translation>
+        <translation>Obróć w prawo</translation>
     </message>
     <message>
         <source>Importing...</source>
@@ -762,19 +874,19 @@
     </message>
     <message>
         <source>The photo/video already exists</source>
-        <translation>To zdjęcie/ten film już istnieje</translation>
+        <translation>To zdjęcie/film już istnieje</translation>
     </message>
     <message numerus="yes">
         <source>%n photos selected</source>
-        <translation><numerusform>Wybrano %n zdjęcie</numerusform><numerusform>Wybrano %n zdjęć</numerusform><numerusform>Wybrano %n zdjęć</numerusform><numerusform>Wybrano %n zdjęć</numerusform></translation>
+        <translation><numerusform>Wybrano %n zdjęcie</numerusform><numerusform>Wybrano %n zdjęcia</numerusform><numerusform>Wybrano %n zdjęć</numerusform><numerusform>Wybrano %n zdjęć</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n videos selected</source>
-        <translation><numerusform>Wybrano %n film</numerusform><numerusform>Wybrano %n filmów</numerusform><numerusform>Wybrano %n filmów</numerusform><numerusform>Wybrano %n filmów</numerusform></translation>
+        <translation><numerusform>Wybrano %n film</numerusform><numerusform>Wybrano %n filmy</numerusform><numerusform>Wybrano %n filmów</numerusform><numerusform>Wybrano %n filmów</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n items selected</source>
-        <translation><numerusform>Wybrano %n przedmiot</numerusform><numerusform>Wybrano %n przedmiotów</numerusform><numerusform>Wybrano %n przedmiotów</numerusform><numerusform>Wybrano %n przedmiotów</numerusform></translation>
+        <translation><numerusform>Wybrano %n przedmiot</numerusform><numerusform>Wybrano %n przedmioty</numerusform><numerusform>Wybrano %n przedmiotów</numerusform><numerusform>Wybrano %n przedmiotów</numerusform></translation>
     </message>
     <message>
         <source>%1 items imported, %2 items exist already</source>
@@ -801,7 +913,7 @@
     </message>
     <message numerus="yes">
         <source>%n videos found</source>
-        <translation><numerusform>Znaleziono %n film</numerusform><numerusform>Znaleziono %n filmów</numerusform><numerusform>Znaleziono %n filmów</numerusform><numerusform>Znaleziono %n filmów</numerusform></translation>
+        <translation><numerusform>Znaleziono %n film</numerusform><numerusform>Znaleziono %n filmy</numerusform><numerusform>Znaleziono %n filmów</numerusform><numerusform>Znaleziono %n filmów</numerusform></translation>
     </message>
     <message>
         <source>1 video found</source>
@@ -809,34 +921,11 @@
     </message>
     <message numerus="yes">
         <source>%n items found</source>
-        <translation><numerusform>Znaleziono %n przedmiot</numerusform><numerusform>Znaleziono %n przedmiotów</numerusform><numerusform>Znaleziono %n przedmiotów</numerusform><numerusform>Znaleziono %n przedmiotów</numerusform></translation>
+        <translation><numerusform>Znaleziono %n przedmiot</numerusform><numerusform>Znaleziono %n przedmioty</numerusform><numerusform>Znaleziono %n przedmiotów</numerusform><numerusform>Znaleziono %n przedmiotów</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n photos found</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-</context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Wstrzymaj</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Odtwarzaj</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Wyjdź</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Poprzedni</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Dalej</translation>
+        <translation><numerusform>%n zdjęcie znaleziono</numerusform><numerusform>%n zdjęcia znaleziono</numerusform><numerusform>%n zdjęć znaleziono</numerusform><numerusform>%n zdjęć znaleziono</numerusform></translation>
     </message>
 </context>
 <context>
@@ -851,62 +940,19 @@
     </message>
     <message numerus="yes">
         <source>%n photos</source>
-        <translation><numerusform>%n zdjęcie</numerusform><numerusform>%n zdjęć</numerusform><numerusform>%n zdjęć</numerusform><numerusform>%n zdjęć</numerusform></translation>
+        <translation><numerusform>%n zdjęcie</numerusform><numerusform>%n zdjęcia</numerusform><numerusform>%n zdjęć</numerusform><numerusform>%n zdjęć</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n videos</source>
-        <translation><numerusform>%n film</numerusform><numerusform>%n filmów</numerusform><numerusform>%n filmów</numerusform><numerusform>%n filmów</numerusform></translation>
+        <translation><numerusform>%n film</numerusform><numerusform>%n filmy</numerusform><numerusform>%n filmów</numerusform><numerusform>%n filmów</numerusform></translation>
     </message>
     <message>
         <source>Importing: %1</source>
-        <translation type="unfinished"/>
+        <translation>Importowanie: %1</translation>
     </message>
     <message>
         <source>Exporting: %1</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Wstecz</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Poprzedni</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Dalej</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Rozmiar 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Dopasuj do okna</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Obróć przeciwnie do wskazówek zegara</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Obróć zgodnie ze wskazówkami zegara</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Usuń</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Ulubione</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Usuń z ulubionych</translation>
+        <translation>Eksportowanie: %1</translation>
     </message>
 </context>
 <context>
@@ -933,11 +979,11 @@
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation>Obróć zgodnie ze wskazówkami zegara</translation>
+        <translation>Obróć w prawo</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation>Obróć przeciwnie do wskazówek zegara</translation>
+        <translation>Obróć w lewo</translation>
     </message>
     <message>
         <source>Display in file manager</source>
@@ -992,17 +1038,6 @@
         <translation>dni</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Nie odnaleziono plików obrazów</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Zdjęcie nie zostało odnalezione</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1015,15 +1050,15 @@
     </message>
     <message numerus="yes">
         <source>%n photos</source>
-        <translation><numerusform>%n zdjęcie</numerusform><numerusform>%n zdjęć</numerusform><numerusform>%n zdjęć</numerusform><numerusform>%n zdjęć</numerusform></translation>
+        <translation><numerusform>%n zdjęcie</numerusform><numerusform>%n zdjęcia</numerusform><numerusform>%n zdjęć</numerusform><numerusform>%n zdjęć</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n videos</source>
-        <translation><numerusform>%n film</numerusform><numerusform>%n filmów</numerusform><numerusform>%n filmów</numerusform><numerusform>%n filmów</numerusform></translation>
+        <translation><numerusform>%n film</numerusform><numerusform>%n filmy</numerusform><numerusform>%n filmów</numerusform><numerusform>%n filmów</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n items</source>
-        <translation><numerusform>%n przedmiot</numerusform><numerusform>%n przedmiotów</numerusform><numerusform>%n przedmiotów</numerusform><numerusform>%n przedmiotów</numerusform></translation>
+        <translation><numerusform>%n przedmiot</numerusform><numerusform>%n przedmioty</numerusform><numerusform>%n przedmiotów</numerusform><numerusform>%n przedmiotów</numerusform></translation>
     </message>
 </context>
 <context>
@@ -1042,7 +1077,7 @@
     </message>
     <message>
         <source>Video CodecID</source>
-        <translation>Video CodecID</translation>
+        <translation>Wideo CodecID</translation>
     </message>
     <message>
         <source>Video CodeRate</source>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Próbowanie</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Nazwa wideo</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Data modyfikacji</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Data uchwycenia</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Dodaj do albumu</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Pokaz slajdów</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Opuść pełny ekran</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pełny ekran</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Kopiuj</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Usuń</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Wyświetl okno nawigacji</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Ukryj okno nawigacji</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Obróć zgodnie ze wskazówkami zegara</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Obróć przeciwnie do wskazówek zegara</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Ustaw jako tapetę pulpitu</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Wyświetl w menedżerze plików</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Eksportuj</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Usuń z ulubionych</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Informacje o zdjęciu</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Usuń z albumu</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Ulubione</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Nowy album</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Drukuj</translation>
+        <source>Name</source>
+        <translation>Nazwa</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
