@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Eliminar</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Ecrã inteiro</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Apresentação</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Exportar</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Copiar</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Adicionar aos favoritos</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Rodar para a direita</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Rodar para a esquerda</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Definir como papel de parede</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Mostrar no gestor de ficheiros</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Informações da foto</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Informação do vídeo</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Restaurar</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Ou arraste fotos para aqui</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 foto(s)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Importar tudo</translation>
@@ -111,8 +162,8 @@
         <translation>A carregar...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation>Os ficheiros serão eliminados permanentemente após os dias aqui mostrados</translation>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>Os ficheiros serão eliminados permanentemente após os dias neles indicados</translation>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>já existe, deseja substituir?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Cancelar</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Informações da foto</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Tem a certeza que deseja eliminar esta foto do álbum?</translation>
+        <translation type="vanished">Tem a certeza que deseja eliminar esta foto do álbum?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Tem a certeza que deseja eliminar %n foto do álbum?</numerusform><numerusform>Tem a certeza que deseja eliminar %n fotos dos álbuns?</numerusform></translation>
+        <translation type="vanished"><numerusform>Tem a certeza que deseja eliminar %n foto do álbum?</numerusform><numerusform>Tem a certeza que deseja eliminar %n fotos dos álbuns?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Tem a certeza que deseja eliminar este vídeo do álbum?</translation>
+        <translation type="vanished">Tem a certeza que deseja eliminar este vídeo do álbum?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Tem a certeza que deseja eliminar %n vídeos do álbum?</numerusform><numerusform>Tem a certeza que deseja eliminar %n vídeos dos álbuns?</numerusform></translation>
+        <translation type="vanished"><numerusform>Tem a certeza que deseja eliminar %n vídeos do álbum?</numerusform><numerusform>Tem a certeza que deseja eliminar %n vídeos dos álbuns?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Tem a certeza que deseja eliminar %n item do álbum?</numerusform><numerusform>Tem a certeza que deseja eliminar %n itens dos álbuns?</numerusform></translation>
+        <translation type="vanished"><numerusform>Tem a certeza que deseja eliminar %n item do álbum?</numerusform><numerusform>Tem a certeza que deseja eliminar %n itens dos álbuns?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Detalhes</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Informações da foto</translation>
+        <source>Image info</source>
+        <translation>Informação da imagem</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Todas as fotos e vídeos</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Não foram encontradas fotos ou vídeos</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Novo álbum</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>Não tem permissão para ver o ficheiro</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Definições</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Importar fotos</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>A importar... </translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>Informação de foto/vídeo</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Importar fotos e vídeos</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>Rótulo</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Nome da foto</translation>
+        <source>Name</source>
+        <translation>Nome</translation>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation><numerusform>%1 foto encontrada</numerusform><numerusform>%1 fotos encontradas</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Pausa</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Reproduzir</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Sair</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Anterior</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Próximo</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>A exportar: %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Voltar</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Anterior</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Próximo</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Tamanho 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Ajustar à janela</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Rodar para a esquerda</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Rodar para a direita</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Eliminar</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Adicionar aos favoritos</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Remover dos favoritos</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>dias</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Nenhuma imagem encontrada</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Foto não encontrada</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Amostragem</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Nome do vídeo</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Data de modificação</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Data de captura</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Adicionar ao álbum</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Apresentação</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Sair de ecrã inteiro</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Ecrã inteiro</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Copiar</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Eliminar</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Mostrar janela de navegação</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Ocultar janela de navegação</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Rodar para a direita</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Rodar para a esquerda</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Definir como papel de parede</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Mostrar no gestor de ficheiros</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Exportar</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Remover dos favoritos</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Informações da foto</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Remover do álbum</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Adicionar aos favoritos</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Novo álbum</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Imprimir</translation>
+        <source>Name</source>
+        <translation>Nome</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
