@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Izbriši</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Celozaslonsko</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Diaprojekcija</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Izvozi</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Kopiraj</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Priljubljeno</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Obrni proti smeri urinega kazalca</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Obrni proti smeri urinega kazalca</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Določi kot ozadje namizja</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Prikaži v upravljalniku datotek</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Podatki o sliki</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Podatki o videu</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Obnovi</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>ali povlecite slike sem</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 slik(a)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Uvozi vse</translation>
@@ -108,11 +159,11 @@
     </message>
     <message>
         <source>Loading...</source>
-        <translation type="unfinished"/>
+        <translation>Nalaganje...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation type="unfinished"/>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>Datoteke bodo trajno izbrisane po preteku prikazanega števila dni</translation>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>že obstaja. Jo želite zamenjati?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Prekini</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Podatki o sliki</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Ali ste prepričani, da želite odstraniti to sliko iz albuma?</translation>
+        <translation type="vanished">Ali ste prepričani, da želite odstraniti to sliko iz albuma?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>Ali res želite izbrisati %n sliko iz albumov?</numerusform><numerusform>Ali res želite izbrisati %n sliki iz albumov?</numerusform><numerusform>Ali res želite izbrisati %n slike iz albumov?</numerusform><numerusform>Ali res želite izbrisati %n slik iz albumov?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation type="unfinished"/>
+        <translation type="vanished">Ali želite izbrisati ta video iz albuma?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>Ali res želite izbrisati %n video iz albumov?</numerusform><numerusform>Ali res želite izbrisati %n videa iz albumov?</numerusform><numerusform>Ali res želite izbrisati %n videe iz albumov?</numerusform><numerusform>Ali res želite izbrisati %n videev iz albumov?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>Ali res želite izbrisati %n predmet iz albumov?</numerusform><numerusform>Ali res želite izbrisati %n predmeta iz albumov?</numerusform><numerusform>Ali res želite izbrisati %n predmete iz albumov?</numerusform><numerusform>Ali res želite izbrisati %n predmetov iz albumov?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,7 +390,7 @@
         <translation>Podrobnosti</translation>
     </message>
     <message>
-        <source>Photo info</source>
+        <source>Image info</source>
         <translation>Podatki o sliki</translation>
     </message>
 </context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Vse slike in videi</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Ni najdenih slik ali videev</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Nov album</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Nastavitve</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Uvozi slike</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Uvažanje...</translation>
@@ -546,11 +634,11 @@
     </message>
     <message>
         <source>Export photos</source>
-        <translation type="unfinished"/>
+        <translation>Izvozi slike</translation>
     </message>
     <message>
         <source>Import photos/videos</source>
-        <translation type="unfinished"/>
+        <translation>Uvozi slike/videe</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -558,6 +646,30 @@
     </message>
     <message>
         <source>Photo/Video info</source>
+        <translation>Podatki o sliki/videu</translation>
+    </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Uvoz slik in videa</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -644,8 +756,8 @@
         <translation>Oznaka</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Ime slike</translation>
+        <source>Name</source>
+        <translation>Ime</translation>
     </message>
 </context>
 <context>
@@ -813,30 +925,7 @@
     </message>
     <message numerus="yes">
         <source>%n photos found</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-</context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Pavza</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Predvajaj</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Izhod</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Nazaj</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Naslednja</translation>
+        <translation><numerusform>%1 najdenih slika</numerusform><numerusform>%1 najdenih sliki</numerusform><numerusform>%1 najdenih slike</numerusform><numerusform>%1 najdenih slik</numerusform></translation>
     </message>
 </context>
 <context>
@@ -859,54 +948,11 @@
     </message>
     <message>
         <source>Importing: %1</source>
-        <translation type="unfinished"/>
+        <translation>Uvažanje: %1</translation>
     </message>
     <message>
         <source>Exporting: %1</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Nazaj</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Nazaj</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Naslednja</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Velikost 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Prilagodi oknu</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Obrni proti smeri urinega kazalca</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Obrni proti smeri urinega kazalca</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Izbriši</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Priljubljeno</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Nepriljubljeno</translation>
+        <translation>Izvažanje: %1</translation>
     </message>
 </context>
 <context>
@@ -985,24 +1031,13 @@
     </message>
     <message>
         <source>Video info</source>
-        <translation type="unfinished"/>
+        <translation>Podatki o videu</translation>
     </message>
     <message>
         <source>days</source>
         <translation>dni</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>ni najdenih slik</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Slika ni bila najdena</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1034,59 +1069,55 @@
     </message>
     <message>
         <source>Codec info</source>
-        <translation type="unfinished"/>
+        <translation>Podatki o kodeku</translation>
     </message>
     <message>
         <source>Audio info</source>
-        <translation type="unfinished"/>
+        <translation>Podatki o zvoku</translation>
     </message>
     <message>
         <source>Video CodecID</source>
-        <translation type="unfinished"/>
+        <translation>Video naziv kodeka</translation>
     </message>
     <message>
         <source>Video CodeRate</source>
-        <translation type="unfinished"/>
+        <translation>Video kakovost kodeka</translation>
     </message>
     <message>
         <source>FPS</source>
-        <translation type="unfinished"/>
+        <translation>Slik/s</translation>
     </message>
     <message>
         <source>Proportion</source>
-        <translation type="unfinished"/>
+        <translation>Razmerje</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished"/>
+        <translation>Ločljivost</translation>
     </message>
     <message>
         <source>Audio CodecID</source>
-        <translation type="unfinished"/>
+        <translation>Zvok naziv kodeka</translation>
     </message>
     <message>
         <source>Audio CodeRate</source>
-        <translation type="unfinished"/>
+        <translation>Zvok kakovost kodeka</translation>
     </message>
     <message>
         <source>Audio digit</source>
-        <translation type="unfinished"/>
+        <translation>Zvok decimalke</translation>
     </message>
     <message>
         <source>Channels</source>
-        <translation type="unfinished"/>
+        <translation>ali</translation>
     </message>
     <message>
         <source>Channel</source>
-        <translation type="unfinished"/>
+        <translation>Kanal</translation>
     </message>
     <message>
         <source>Sampling</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Video name</source>
-        <translation type="unfinished"/>
+        <translation>Vzorčenje</translation>
     </message>
     <message>
         <source>Date modified</source>
@@ -1102,98 +1133,23 @@
     </message>
     <message>
         <source>Duration</source>
-        <translation type="unfinished"/>
+        <translation>Čas trajanja</translation>
     </message>
     <message>
         <source>Path</source>
-        <translation type="unfinished"/>
+        <translation>Pot</translation>
     </message>
     <message>
         <source>Video info</source>
-        <translation type="unfinished"/>
+        <translation>Podatki o videu</translation>
     </message>
     <message>
         <source>Date captured</source>
         <translation>Datum snemanja</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Dodaj v album</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Diaprojekcija</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Zapri celozaslonski način</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Celozaslonsko</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Kopiraj</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Izbriši</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Prikaži navigacijsko okno</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Skrij navigacijsko okno</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Obrni proti smeri urinega kazalca</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Obrni proti smeri urinega kazalca</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Določi kot ozadje namizja</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Prikaži v upravljalniku datotek</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Izvozi</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Nepriljubljeno</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Podatki o sliki</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Odstrani iz albuma</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Priljubljeno</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Nov album</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Tiskanje</translation>
+        <source>Name</source>
+        <translation>Ime</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
