@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Fshije</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Sa krejt ekrani</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Shfaqje si diapozitiva</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Eksporto</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Kopjoje</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Vëre si të parapëlqyer</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Rrotulloje në kahun orar</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Rrotulloje në kahun anti-orar</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Vëre si sfond</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Shfaqe te përgjegjës kartelash</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Të dhëna fotoje</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Hollësi videoje</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Riktheje</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Ose tërhiqni foto këtu</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 foto(t)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Importoji Krejt</translation>
@@ -111,8 +162,8 @@
         <translation>Po ngarkohet…</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation>Pas ditëve të shfaqura në të, kartelat do të fshihen përgjithmonë</translation>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>Kartelat do të fshihen përgjithmonë, pas ditëve të treguara në to</translation>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>ekziston tashmë. Doni të zëvendësohet?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Anuloje</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Të dhëna fotoje</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Jeni i sigurt se doni të fshihet kjo foto nga albumi?</translation>
+        <translation type="vanished">Jeni i sigurt se doni të fshihet kjo foto nga albumi?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Jeni i sigurt se doni të fshihen %n foto prej albumesh?</numerusform><numerusform>Jeni i sigurt se doni të fshihen %n foto prej albumesh?</numerusform></translation>
+        <translation type="vanished"><numerusform>Jeni i sigurt se doni të fshihen %n foto prej albumesh?</numerusform><numerusform>Jeni i sigurt se doni të fshihen %n foto prej albumesh?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Jeni i sigurt se doni të fshihet kjo video prej albumit?</translation>
+        <translation type="vanished">Jeni i sigurt se doni të fshihet kjo video prej albumit?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Jeni i sigurt se doni të fshihet %n video prej albumesh?</numerusform><numerusform>Jeni i sigurt se doni të fshihen %n video prej albumesh?</numerusform></translation>
+        <translation type="vanished"><numerusform>Jeni i sigurt se doni të fshihet %n video prej albumesh?</numerusform><numerusform>Jeni i sigurt se doni të fshihen %n video prej albumesh?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Jeni i sigurt se doni të fshihen %n objekt prej albumesh?</numerusform><numerusform>Jeni i sigurt se doni të fshihen %n objekte prej albumesh?</numerusform></translation>
+        <translation type="vanished"><numerusform>Jeni i sigurt se doni të fshihen %n objekt prej albumesh?</numerusform><numerusform>Jeni i sigurt se doni të fshihen %n objekte prej albumesh?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Hollësi</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Të dhëna fotoje</translation>
+        <source>Image info</source>
+        <translation>Hollësi figure</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Krejt fotot dhe videot</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>S’u gjetën foto ose video</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Album i ri</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>S’keni leje të shihni kartelën</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Rregullime</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Importo foto</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Po importohet…</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>Hollësi fotosh/videosh</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Importoni foto dhe video</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>Etiketë</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Emër fotoje</translation>
+        <source>Name</source>
+        <translation>Emër</translation>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation><numerusform>U gjet %n foto</numerusform><numerusform>U gjetën %n foto</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Pauzë</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Luaje</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Dalje</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>E mëparshmja</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Pasuesja</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>Po eksportohet: %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Mbrapsht</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>E mëparshmja</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Pasuesja</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Në madhësinë 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Sa dritarja</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Rrotulloje në kahun anti-orar</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Rrotulloje në kahun orar</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Fshije</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Vëre si të parapëlqyer</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Hiqe nga të parapëlqyerat</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>ditë</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>S’u gjetën kartela figurash</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>S’u gjet foto</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Emër videoje</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Datë e ndryshimit</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Datë e bërjes</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Shto te albumi</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Shfaqje si diapozitiva</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Dil nga mënyra Sa krejt ekrani</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Sa krejt ekrani</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Kopjoje</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Fshije</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Shfaq dritare lëvizjesh</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Fshih dritare lëvizjesh</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Rrotulloje në kahun orar</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Rrotulloje në kahun anti-orar</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Vëre si sfond</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Shfaqe te përgjegjës kartelash</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Eksporto</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Hiqe nga të parapëlqyerat</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Të dhëna fotoje</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Hiqe nga albumi</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Vëre si të parapëlqyer</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Album i ri</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Shtype</translation>
+        <source>Name</source>
+        <translation>Emër</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
