@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Sil</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Tam ekran</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Slayt gösterisi</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Dışa aktar</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Kopyala</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Favori</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Saat yönünde döndür</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Saat yönünün tersine döndür</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Duvar kağıdı yap</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Dosya yöneticisinde görüntüle</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Fotoğraf bilgisi</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Video bilgisi</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Kurtar</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Veya fotoğrafları buraya sürükle</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 fotoğraf</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Tümünü İçe Aktar</translation>
@@ -111,8 +162,8 @@
         <translation>Yükleniyor...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation>Dosyalar, üzerinde gösterilen günlerden sonra kalıcı olarak silinecek</translation>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>Dosyalar, üzerlerinde gösterilen günlerden sonra kalıcı olarak silinecek</translation>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>zaten var, değiştirmek istiyor musun?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>İptal</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Fotoğraf bilgisi</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Bu fotoğrafı albümden silmek istediğinizden emin misiniz?</translation>
+        <translation type="vanished">Bu fotoğrafı albümden silmek istediğinizden emin misiniz?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>%n fotoğrafı albümlerden silmek istediğinizden emin misiniz?</numerusform><numerusform>%n fotoğrafı albümlerden silmek istediğinizden emin misiniz?</numerusform></translation>
+        <translation type="vanished"><numerusform>%n fotoğrafı albümlerden silmek istediğinizden emin misiniz?</numerusform><numerusform>%n fotoğrafı albümlerden silmek istediğinizden emin misiniz?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Bu videoyu albümden silmek istediğinizden emin misiniz?</translation>
+        <translation type="vanished">Bu videoyu albümden silmek istediğinizden emin misiniz?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Albümlerden %n video silmek istediğinizden emin misiniz?</numerusform><numerusform>Albümlerden %n video silmek istediğinizden emin misiniz?</numerusform></translation>
+        <translation type="vanished"><numerusform>Albümlerden %n video silmek istediğinizden emin misiniz?</numerusform><numerusform>Albümlerden %n video silmek istediğinizden emin misiniz?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Albümlerden %n öğe silmek istediğinizden emin misiniz?</numerusform><numerusform>Albümlerden %n öğe silmek istediğinizden emin misiniz?</numerusform></translation>
+        <translation type="vanished"><numerusform>Albümlerden %n öğe silmek istediğinizden emin misiniz?</numerusform><numerusform>Albümlerden %n öğe silmek istediğinizden emin misiniz?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Ayrıntılar</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Fotoğraf bilgisi</translation>
+        <source>Image info</source>
+        <translation>Resim bilgisi</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Tüm fotoğraflar ve videolar</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Fotoğraf veya video bulunamadı</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Yeni albüm</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>Dosyayı görüntüleme izniniz yok</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Ayarlar</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Fotoğrafları içe aktar</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>İçe aktarılıyor...</translation>
@@ -546,11 +634,11 @@
     </message>
     <message>
         <source>Export photos</source>
-        <translation type="unfinished"/>
+        <translation>Fotoğrafları dışa aktar</translation>
     </message>
     <message>
         <source>Import photos/videos</source>
-        <translation type="unfinished"/>
+        <translation>Fotoğrafları/videoları içe aktar</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -558,6 +646,30 @@
     </message>
     <message>
         <source>Photo/Video info</source>
+        <translation>Fotoğraf/Video bilgisi</translation>
+    </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Fotoğrafları ve videoları içe aktarın</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -644,8 +756,8 @@
         <translation>Etiket</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Fotoğraf adı</translation>
+        <source>Name</source>
+        <translation>İsim</translation>
     </message>
 </context>
 <context>
@@ -813,30 +925,7 @@
     </message>
     <message numerus="yes">
         <source>%n photos found</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-</context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Duraklat</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Oynat</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Çıkış</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Önceki</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Sonraki</translation>
+        <translation><numerusform>%n fotoğraf bulundu</numerusform><numerusform>%n fotoğraf bulundu</numerusform></translation>
     </message>
 </context>
 <context>
@@ -866,49 +955,6 @@
         <translation>Dışa aktarılıyor: %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Geri</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Önceki</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Sonraki</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>1:1 Boyut</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Pencereye sığdır</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Saat yönünün tersine döndür</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Saat yönünde döndür</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Sil</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Favori</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Favori değil</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>gün</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Görüntü dosyası bulunamadı</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Fotoğraf bulunamadı</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Örnekleme</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Viideo adı</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Değiştirilme tarihi</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Alındığı tarih</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Albüme ekle</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Slayt gösterisi</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Tam ekrandan çık</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Tam ekran</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Kopyala</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Sil</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Gezinme penceresini göster</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Gezinme penceresini gizle</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Saat yönünde döndür</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Saat yönünün tersine döndür</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Duvar kağıdı yap</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Dosya yöneticisinde göster</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Dışa aktar</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Favori değil</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Fotoğraf bilgisi</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Albümden kaldır</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Favori</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Yeni albüm</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Yazdır</translation>
+        <source>Name</source>
+        <translation>İsim</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
