@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">ئۆچۈرۈش</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">تولۇق ئېكران</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">تام تەسۋىر</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">چىقىرىش</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">كۆچۈرۈش</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">ياقتۇرغانلىرىم</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">سائەت يۆنىلىشىدە ئايلاندۇرۇش</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">سائەتكە قارشى يۆنىلىشنى ئايلاندۇرۇش</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">تام قەغىزى قىلىپ تەڭشەڭ</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">ھۆججەت باشقۇرغۇچتا كۆرسىتىلىدۇ</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">سۈرەت ئۇچۇرى</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">سىن ئۇچۇرى</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">ئەسلىگە كەلتۈرۈش</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>رەسىملەرنى بۇيەرگە سۆرەپ ئەكىرىڭ</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 رەسىم(s)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>ھەممىنى ئەكىرىش</translation>
@@ -111,7 +162,7 @@
         <translation>يۈكلىنىۋاتىدۇ، سەل ساقلاڭ...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
+        <source>The files will be permanently deleted after the days shown on them</source>
         <translation>ھۆججەت ئۆچۈرۈلۈشتىن بۇرۇن ئېشىپ قالغان كۈن سانى كۆرۈنىدۇ، كېيىن مەڭگۈلۈك ئۆچۈرۈلىدۇ</translation>
     </message>
 </context>
@@ -201,6 +252,25 @@
         <translation>ئۈسكىنىڭىزدە مەۋجۈتكەن ،ئالماشتۇرامسىز ؟</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>ئەمەلدىن قالدۇرۇش</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>سۈرەت ئۇچۇرى</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>بۇ رەسىمنى دىسكىدىن ئۆچۈرمەكچىمۇ؟</translation>
+        <translation type="vanished">بۇ رەسىمنى دىسكىدىن ئۆچۈرمەكچىمۇ؟</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>ئالبومدىن بۇ %n پارچە سۈرەتنى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform><numerusform>ئالبومدىن بۇ %n پارچە سۈرەتنى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform></translation>
+        <translation type="vanished"><numerusform>ئالبومدىن بۇ %n پارچە سۈرەتنى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform><numerusform>ئالبومدىن بۇ %n پارچە سۈرەتنى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>ئالبومدىن بۇ سىننى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</translation>
+        <translation type="vanished">ئالبومدىن بۇ سىننى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>ئالبومدىن بۇ %n سىننى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform><numerusform>ئالبومدىن بۇ %n سىننى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform></translation>
+        <translation type="vanished"><numerusform>ئالبومدىن بۇ %n سىننى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform><numerusform>ئالبومدىن بۇ %n سىننى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>ئالبومدىن بۇ %n تۈرنى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform><numerusform>ئالبومدىن بۇ %n تۈرنى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform></translation>
+        <translation type="vanished"><numerusform>ئالبومدىن بۇ %n تۈرنى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform><numerusform>ئالبومدىن بۇ %n تۈرنى ئۆچۈرۈشنى جەزىملەشتۈرەلەمسىز؟</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>تەپسىلاتى</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>سۈرەت ئۇچۇرى</translation>
+        <source>Image info</source>
+        <translation>رەسىم ئۇچۇرى</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>بارلىق سۈرەت ۋە سىن</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>سۈرەت ياكى سىن ھۆججىتى بايقالمىدى</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>يىڭى ئالبۇم</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>بۇ ھۆججەتنى كۆرۈش ھوقۇقىڭىز يوق</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>تەڭشەك</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>رەسىملەرنى ئەكىرىڭ</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>ئەكىرۋاتىدۇ...</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>سۈرەت/سىن ئۇچۇرى</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>سۈرەت ۋە سىن كىرگۈزۈش</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>خەتكۈچ</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>رەسىم نامى</translation>
+        <source>Name</source>
+        <translation>نامى</translation>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation><numerusform>1 پارچە سۈرەت بايقالدى</numerusform><numerusform>%n رەسىم تېپىلدى</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>توختىتىش</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>قويۇش</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>چېكىنىش</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>ئالدىنقى</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>كىيىنكى</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>چىقىرىۋاتىدۇ: %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>قايتىش</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>ئالدىنقى</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>كىيىنكى</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>1:1 كۆرۈنۈش</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>ماس كۆزنەك</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>سائەتكە قارشى يۆنىلىشنى ئايلاندۇرۇڭ</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>سائەت يۆنىلىشىدە ئايلىنىدۇ</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>ئۆچۈرۈش</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>ياقتۇرغانلىرىم</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>ياقمىغانلىرى</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>كۈن</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>رەسىم ھۆججىتى تېپىلمىدى</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>سۈرەت تېپىلمىدى</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>نۇسخا ئېلىش سانى</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>سىن نامى</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>ئۆزگەرتىلگەن چېسلا</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>تارتىلغان ۋاقىت</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>ئالبومغا قوشۇش</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>تام تەسۋىر</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>پۈتۈن ئېكراندىن چېكىنىش</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>تولۇق ئېكران</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>كۆچۈرۈش</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>ئۆچۈرۈش</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>يول باشلاش كۆزنىكىنى كۆرسەتسۇن</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>يول باشلاش كۆزنىكىنى يوشۇرۇش</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>سائەت يۆنىلىشىدە ئايلىنىدۇ</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>سائەتكە قارشى يۆنىلىشنى ئايلاندۇرۇڭ</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>تام قەغىزى قىلىپ تەڭشەڭ</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>ھۆججەت باشقۇرغۇچتا كۆرسىتىلىدۇ</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>چىقىرىش</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>ياقمىغانلىرى</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>سۈرەت ئۇچۇرى</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>ئالبومغا قايتا نام بېرىش</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>ياقتۇرغانلىرىم</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>يىڭى ئالبۇم</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>بېسىپ چىقىرىش</translation>
+        <source>Name</source>
+        <translation>نامى</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
