@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Вилучити</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">На весь екран</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Показ слайдів</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Експортувати</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Копіювати</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Додати до вибраних</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Обертати за годинниковою стрілкою</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Обертати проти годинникової стрілки</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Встановити зображенням тла</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Показати у менеджері файлів</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Дані щодо фотографії</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Дані щодо відео</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Відновити</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Або перетягніть сюди фотографії</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 фотографії</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Імпортувати все</translation>
@@ -111,7 +162,7 @@
         <translation>Завантаження…</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
+        <source>The files will be permanently deleted after the days shown on them</source>
         <translation>Кількість днів, за яку файли буде остаточно вилучено, показано на мініатюрах</translation>
     </message>
 </context>
@@ -201,6 +252,25 @@
         <translation>вже існує. Хочете замінити його?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Скасувати</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Дані щодо фотографії</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Ви справді хочете вилучити цю фотографію з альбому?</translation>
+        <translation type="vanished">Ви справді хочете вилучити цю фотографію з альбому?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Ви справді хочете вилучити цю %n фотографію з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n фотографії з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n фотографій з альбомів?</numerusform><numerusform>Ви справді хочете вилучити цю %n фотографію з альбомів?</numerusform></translation>
+        <translation type="vanished"><numerusform>Ви справді хочете вилучити цю %n фотографію з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n фотографії з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n фотографій з альбомів?</numerusform><numerusform>Ви справді хочете вилучити цю %n фотографію з альбомів?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Ви справді хочете вилучити це відео з альбому?</translation>
+        <translation type="vanished">Ви справді хочете вилучити це відео з альбому?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Ви справді хочете вилучити це %n відео з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n відео з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n відео з альбомів?</numerusform><numerusform>Ви справді хочете вилучити це %n відео з альбомів?</numerusform></translation>
+        <translation type="vanished"><numerusform>Ви справді хочете вилучити це %n відео з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n відео з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n відео з альбомів?</numerusform><numerusform>Ви справді хочете вилучити це %n відео з альбомів?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Ви справді хочете вилучити цей %n запис з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n записи з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n записів з альбомів?</numerusform><numerusform>Ви справді хочете вилучити цей %n запис з альбомів?</numerusform></translation>
+        <translation type="vanished"><numerusform>Ви справді хочете вилучити цей %n запис з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n записи з альбомів?</numerusform><numerusform>Ви справді хочете вилучити ці %n записів з альбомів?</numerusform><numerusform>Ви справді хочете вилучити цей %n запис з альбомів?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Подробиці</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Дані щодо фотографії</translation>
+        <source>Image info</source>
+        <translation>Дані щодо зображення</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Усі фотографії і відео</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Не знайдено жодної фотографії або відео</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Новий альбом</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>У вас немає прав доступу до перегляду цього файла</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Параметри</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Імпортувати фотографії</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Імпортування…</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>Дані щодо фотографій/відео</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Імпортуйте фотографії та відео</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>Мітка</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Назва фотографії</translation>
+        <source>Name</source>
+        <translation>Назва</translation>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation><numerusform>Знайдено %n фотографію</numerusform><numerusform>Знайдено %n фотографії</numerusform><numerusform>Знайдено %n фотографій</numerusform><numerusform>Знайдено %n фотографію</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Пауза</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Відтворити</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Вийти</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Назад</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Далі</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>Експортування: %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Назад</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Назад</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Далі</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Розмір 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Вмістити у вікно</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Обертати проти годинникової стрілки</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Обертати за годинниковою стрілкою</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Вилучити</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Додати до вибраних</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Вилучити з вибраних</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>днів</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Файлів зображень не знайдено</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Фотографії не знайдено</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Дискретизація</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Назва відео</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Дата зміни</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Дата створення</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Додати до альбому</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Показ слайдів</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Звичайний режим</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>На весь екран</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Копіювати</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Вилучити</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Показати навігаційне вікно</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Приховати навігаційне вікно</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Обертати за годинниковою стрілкою</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Обертати проти годинникової стрілки</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Встановити зображенням тла</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Показати у менеджері файлів</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Експортувати</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Вилучити з вибраних</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Дані щодо фотографії</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Вилучити з альбому</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Додати до вибраних</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Новий альбом</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Надрукувати</translation>
+        <source>Name</source>
+        <translation>Назва</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
