@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">刪除</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">全屏</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">幻燈片放映</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">導出</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">複製</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">收藏</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">順時針旋轉</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">逆時針旋轉</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">設為壁紙</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">在檔案管理員中顯示</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">照片訊息</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">影片訊息</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">恢復</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>您也可以拖拽照片到此</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1張照片</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>全部導入</translation>
@@ -111,7 +162,7 @@
         <translation>正在加載，請稍候...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
+        <source>The files will be permanently deleted after the days shown on them</source>
         <translation>文件在刪除前會顯示剩餘天數，之後將永久刪除</translation>
     </message>
 </context>
@@ -201,6 +252,25 @@
         <translation>已存在，您是否要替換？</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>截圖錄屏</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>相機</translation>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation>畫板</translation>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation>(副本)</translation>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>取消</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>照片訊息</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>您確定要從相冊中刪除此照片嗎？</translation>
+        <translation type="vanished">您確定要從相冊中刪除此照片嗎？</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>您確定要從相冊中刪除這%n張照片嗎？</numerusform></translation>
+        <translation type="vanished"><numerusform>您確定要從相冊中刪除這%n張照片嗎？</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>您確定要從相冊中刪除此影片嗎？</translation>
+        <translation type="vanished">您確定要從相冊中刪除此影片嗎？</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>您確定要從相冊中刪除這%n個影片嗎？</numerusform></translation>
+        <translation type="vanished"><numerusform>您確定要從相冊中刪除這%n個影片嗎？</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>您確定要從相冊中刪除這%n個項目嗎？</numerusform></translation>
+        <translation type="vanished"><numerusform>您確定要從相冊中刪除這%n個項目嗎？</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation>您確定要永久刪除此文件嗎？</translation>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation>刪除後不可恢復</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation>您確定要永久刪除這%1個文件嗎？</translation>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation>刪除後不可恢復</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation>您確定要從本地刪除此文件嗎？</translation>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation>您可以在“最近刪除”中進行恢復</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation>您確定要從本地刪除這%1個文件嗎？</translation>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation>您可以在“最近刪除”中進行恢復</translation>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>詳細訊息</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>照片訊息</translation>
+        <source>Image info</source>
+        <translation>圖片訊息</translation>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>所有照片和影片</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>未發現照片或影片文件</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>新建相冊</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>您沒有權限查看此文件</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,13 +616,9 @@
         <source>Settings</source>
         <translation>設置</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>導入照片</translation>
-    </message>
     <message>
         <source>Importing...</source>
-        <translation>正在導入照片，請稍候...</translation>
+        <translation>正在導入，請稍候...</translation>
     </message>
     <message>
         <source>All photos and videos</source>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>照片/影片訊息</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>導入照片和影片</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation>從文件夾導入</translation>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation>導入中斷</translation>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation>不支持此路徑，請嘗試其他路徑</translation>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation>路徑已存在</translation>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation>%1個文件恢復失敗，文件名過長</translation>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>標記</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>照片名稱</translation>
+        <source>Name</source>
+        <translation>名稱</translation>
     </message>
 </context>
 <context>
@@ -818,29 +930,6 @@
         <translation><numerusform>共找到%n張照片</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>暫停</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>播放</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>退出</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>上一張</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>下一張</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -868,49 +957,6 @@
         <translation>正在導出：%1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>返回</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>上一張</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>下一張</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>1:1視圖</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>適應窗口</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>逆時針旋轉</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>順時針旋轉</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>刪除</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>收藏</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>取消收藏</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -994,17 +1040,6 @@
         <translation>天</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>未找到圖片文件</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>未發現照片文件</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1086,10 +1121,6 @@
         <source>Sampling</source>
         <translation>採樣數</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>影片名稱</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>修改日期</translation>
@@ -1118,84 +1149,9 @@
         <source>Date captured</source>
         <translation>拍攝日期</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>添加到相冊</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>幻燈片放映</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>退出全屏</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>全屏</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>複製</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>刪除</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>顯示導航窗口</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>隱藏導航窗口</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>順時針旋轉</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>逆時針旋轉</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>設為壁紙</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>在檔案管理員中顯示</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>導出</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>取消收藏</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>照片訊息</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>從相冊中移除</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>收藏</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>新建相冊</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>打印</translation>
+        <source>Name</source>
+        <translation>名稱</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
